/**
 * Copyright (c) 2024 Enzien Audio, Ltd.
 * 
 * Redistribution and use in source and binary forms, with or without modification,
 * are permitted provided that the following conditions are met:
 * 
 * 1. Redistributions of source code must retain the above copyright notice,
 *    this list of conditions, and the following disclaimer.
 * 
 * 2. Redistributions in binary form must reproduce the phrase "powered by heavy",
 *    the heavy logo, and a hyperlink to https://enzienaudio.com, all in a visible
 *    form.
 * 
 *   2.1 If the Application is distributed in a store system (for example,
 *       the Apple "App Store" or "Google Play"), the phrase "powered by heavy"
 *       shall be included in the app description or the copyright text as well as
 *       the in the app itself. The heavy logo will shall be visible in the app
 *       itself as well.
 * 
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
 * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
 * CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
 * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 * 
 */

#include "Heavy_WSTD_DL3Y.hpp"

#include <new>

#define Context(_c) static_cast<Heavy_WSTD_DL3Y *>(_c)


/*
 * C Functions
 */

extern "C" {
  HV_EXPORT HeavyContextInterface *hv_WSTD_DL3Y_new(double sampleRate) {
    // allocate aligned memory
    void *ptr = hv_malloc(sizeof(Heavy_WSTD_DL3Y));
    // ensure non-null
    if (!ptr) return nullptr;
    // call constructor
    new(ptr) Heavy_WSTD_DL3Y(sampleRate);
    return Context(ptr);
  }

  HV_EXPORT HeavyContextInterface *hv_WSTD_DL3Y_new_with_options(double sampleRate,
      int poolKb, int inQueueKb, int outQueueKb) {
    // allocate aligned memory
    void *ptr = hv_malloc(sizeof(Heavy_WSTD_DL3Y));
    // ensure non-null
    if (!ptr) return nullptr;
    // call constructor
    new(ptr) Heavy_WSTD_DL3Y(sampleRate, poolKb, inQueueKb, outQueueKb);
    return Context(ptr);
  }

  HV_EXPORT void hv_WSTD_DL3Y_free(HeavyContextInterface *instance) {
    // call destructor
    Context(instance)->~Heavy_WSTD_DL3Y();
    // free memory
    hv_free(instance);
  }
} // extern "C"







/*
 * Class Functions
 */

Heavy_WSTD_DL3Y::Heavy_WSTD_DL3Y(double sampleRate, int poolKb, int inQueueKb, int outQueueKb)
    : HeavyContext(sampleRate, poolKb, inQueueKb, outQueueKb) {
  numBytes += sLine_init(&sLine_tjfMe9MM);
  numBytes += sLine_init(&sLine_JszJzhD3);
  numBytes += sLine_init(&sLine_1cY06L9c);
  numBytes += sLine_init(&sLine_odFAHwqt);
  numBytes += sLine_init(&sLine_OADUECBA);
  numBytes += sBiquad_init(&sBiquad_s_j4t94Qad);
  numBytes += sLine_init(&sLine_UzeoFWxP);
  numBytes += sLine_init(&sLine_IQU3wBHz);
  numBytes += sLine_init(&sLine_1LOJxDlL);
  numBytes += sLine_init(&sLine_yL4tFpa4);
  numBytes += sBiquad_init(&sBiquad_s_48Rnkgld);
  numBytes += sLine_init(&sLine_TX5FwKcn);
  numBytes += sLine_init(&sLine_h0IeafQ6);
  numBytes += sLine_init(&sLine_MOlsDCY7);
  numBytes += sLine_init(&sLine_8V9qDnPH);
  numBytes += sLine_init(&sLine_eKThul0W);
  numBytes += sBiquad_init(&sBiquad_s_JYhdy2an);
  numBytes += sLine_init(&sLine_e4l34zLo);
  numBytes += sLine_init(&sLine_74OVcwmx);
  numBytes += sLine_init(&sLine_DmJbhTzl);
  numBytes += sLine_init(&sLine_IoxMYnli);
  numBytes += sLine_init(&sLine_8wRhMg5R);
  numBytes += sBiquad_init(&sBiquad_s_qq8kE3iG);
  numBytes += sLine_init(&sLine_WSbGCUen);
  numBytes += sLine_init(&sLine_aiG7Wo9E);
  numBytes += sLine_init(&sLine_GCNwH7nM);
  numBytes += sLine_init(&sLine_uWJ4q7ai);
  numBytes += sBiquad_init(&sBiquad_s_kRYFXd5Z);
  numBytes += sLine_init(&sLine_FkpjCQMp);
  numBytes += sLine_init(&sLine_QfM97MBT);
  numBytes += sLine_init(&sLine_ynWr6gfT);
  numBytes += sLine_init(&sLine_GhL00Fps);
  numBytes += sLine_init(&sLine_gF7VB4kZ);
  numBytes += sBiquad_init(&sBiquad_s_GADxgPxw);
  numBytes += sLine_init(&sLine_HbbFySTt);
  numBytes += sTabread_init(&sTabread_kJnvbcXU, &hTable_7x0B2Fxc, true);
  numBytes += sLine_init(&sLine_KF6LAt22);
  numBytes += sLine_init(&sLine_2LHj6sON);
  numBytes += sTabread_init(&sTabread_KkngDjR1, &hTable_I5cfsGR3, true);
  numBytes += sLine_init(&sLine_TLi70L90);
  numBytes += sRPole_init(&sRPole_SqhSUZKF);
  numBytes += sDel1_init(&sDel1_CPcUJVcf);
  numBytes += sTabwrite_init(&sTabwrite_zzG54XvL, &hTable_7x0B2Fxc);
  numBytes += sRPole_init(&sRPole_f0ECCss9);
  numBytes += sDel1_init(&sDel1_evHjKKSU);
  numBytes += sTabwrite_init(&sTabwrite_tuJIgAub, &hTable_I5cfsGR3);
  numBytes += sLine_init(&sLine_3lgQADRC);
  numBytes += sLine_init(&sLine_DZzF4tV1);
  numBytes += sRPole_init(&sRPole_vYYUGeTX);
  numBytes += sEnv_init(&sEnv_nf33n1xb, 1024, 512);
  numBytes += sRPole_init(&sRPole_MqvbMT1E);
  numBytes += sLine_init(&sLine_Sb1FCag7);
  numBytes += sLine_init(&sLine_5X6xXqd8);
  numBytes += sRPole_init(&sRPole_ZiJtyvuT);
  numBytes += sEnv_init(&sEnv_rVYbO1Pz, 1024, 512);
  numBytes += sRPole_init(&sRPole_LuqvCwv1);
  numBytes += sLine_init(&sLine_4NLpwP81);
  numBytes += sTabread_init(&sTabread_9U3UNaf4, &hTable_ow1qv5O7, true);
  numBytes += sLine_init(&sLine_lG3rgYD3);
  numBytes += sLine_init(&sLine_UHsZQEzP);
  numBytes += sTabread_init(&sTabread_Dvq8t9cv, &hTable_VKt3CZZ8, true);
  numBytes += sLine_init(&sLine_dEN3YcaK);
  numBytes += sRPole_init(&sRPole_MvllcLAh);
  numBytes += sDel1_init(&sDel1_46CzA2P5);
  numBytes += sTabwrite_init(&sTabwrite_os7u61NE, &hTable_ow1qv5O7);
  numBytes += sRPole_init(&sRPole_VTvBRWRu);
  numBytes += sDel1_init(&sDel1_TQ0W0e97);
  numBytes += sTabwrite_init(&sTabwrite_srYT0sgZ, &hTable_VKt3CZZ8);
  numBytes += sLine_init(&sLine_00kD6lPp);
  numBytes += sLine_init(&sLine_FPo8vF8m);
  numBytes += sRPole_init(&sRPole_8xOUH3TC);
  numBytes += sEnv_init(&sEnv_gUwuReQU, 1024, 512);
  numBytes += sRPole_init(&sRPole_SMfPgQoe);
  numBytes += sLine_init(&sLine_sOPCuOLk);
  numBytes += sLine_init(&sLine_5USDLik8);
  numBytes += sRPole_init(&sRPole_kLF3ennw);
  numBytes += sEnv_init(&sEnv_hzBDacSm, 1024, 512);
  numBytes += sRPole_init(&sRPole_Y7mHBm8F);
  numBytes += sLine_init(&sLine_9mRyU1XX);
  numBytes += sTabread_init(&sTabread_Ki66563G, &hTable_IrqxgK4k, true);
  numBytes += sLine_init(&sLine_niE7Roxi);
  numBytes += sLine_init(&sLine_SVK5Lfak);
  numBytes += sTabread_init(&sTabread_eB7Wnq0r, &hTable_sMKT60V5, true);
  numBytes += sLine_init(&sLine_x8L4Bppn);
  numBytes += sRPole_init(&sRPole_Y91ChJN6);
  numBytes += sDel1_init(&sDel1_dyouIC2W);
  numBytes += sTabwrite_init(&sTabwrite_y4gtSZuo, &hTable_IrqxgK4k);
  numBytes += sRPole_init(&sRPole_szZkRM8a);
  numBytes += sDel1_init(&sDel1_xSqjcFj9);
  numBytes += sTabwrite_init(&sTabwrite_mx78SL2d, &hTable_sMKT60V5);
  numBytes += sLine_init(&sLine_RyNHE90j);
  numBytes += sLine_init(&sLine_OoW2tnBA);
  numBytes += sRPole_init(&sRPole_cmWcM0yl);
  numBytes += sEnv_init(&sEnv_Fc2FwUTu, 1024, 512);
  numBytes += sRPole_init(&sRPole_ljg6sXjS);
  numBytes += sLine_init(&sLine_a4uwy9Q6);
  numBytes += sLine_init(&sLine_kaN9YYzc);
  numBytes += sRPole_init(&sRPole_3YeNkbzb);
  numBytes += sEnv_init(&sEnv_dgyvxZWQ, 1024, 512);
  numBytes += sRPole_init(&sRPole_eRdSJTgG);
  numBytes += cVar_init_f(&cVar_CAfcGm5J, 0.0f);
  numBytes += cVar_init_f(&cVar_Nsfw9KW9, 0.0f);
  numBytes += cVar_init_f(&cVar_I1b5BD5b, 0.0f);
  numBytes += cVar_init_f(&cVar_RbeHcJn5, 0.0f);
  numBytes += cSlice_init(&cSlice_iGbrKtnK, 1, -1);
  numBytes += cVar_init_f(&cVar_FairG79L, 1337.0f);
  numBytes += cVar_init_f(&cVar_p04F4Mlz, 0.0f);
  numBytes += cIf_init(&cIf_7uPFdJjW, false);
  numBytes += cIf_init(&cIf_kHGKfNqa, false);
  numBytes += cBinop_init(&cBinop_5BmiZ0A7, 0.0f); // __pow
  numBytes += cIf_init(&cIf_iHAFA5AY, false);
  numBytes += cBinop_init(&cBinop_JIbmVMGy, 0.0f); // __add
  numBytes += cBinop_init(&cBinop_ECxwfRV9, -15.0f); // __gt
  numBytes += cBinop_init(&cBinop_ikPzBPKm, -15.0f); // __eq
  numBytes += cVar_init_f(&cVar_mPZrHPlA, 0.0f);
  numBytes += cIf_init(&cIf_YW1OLzGs, false);
  numBytes += cIf_init(&cIf_9uiy8oWz, false);
  numBytes += cBinop_init(&cBinop_QFYUE18v, 0.0f); // __pow
  numBytes += cIf_init(&cIf_eJz3uBfC, false);
  numBytes += cBinop_init(&cBinop_Ef8KsS5z, 0.0f); // __add
  numBytes += cBinop_init(&cBinop_wo6trCyy, -15.0f); // __gt
  numBytes += cBinop_init(&cBinop_4IcFkJue, -15.0f); // __eq
  numBytes += cVar_init_f(&cVar_GduW3tXB, 0.0f);
  numBytes += cIf_init(&cIf_MtiKp0FK, false);
  numBytes += cIf_init(&cIf_vNXMo38n, false);
  numBytes += cBinop_init(&cBinop_qAtlo54T, 0.0f); // __pow
  numBytes += cIf_init(&cIf_5Uh0wf6P, false);
  numBytes += cBinop_init(&cBinop_6nNCdaqT, 0.0f); // __add
  numBytes += cBinop_init(&cBinop_fM8JOhB0, -15.0f); // __gt
  numBytes += cBinop_init(&cBinop_ac5lbwC6, -15.0f); // __eq
  numBytes += cIf_init(&cIf_QRC5EdWI, false);
  numBytes += cSlice_init(&cSlice_NjFioaOG, 1, -1);
  numBytes += cVar_init_f(&cVar_RIr92EVA, 0.0f);
  numBytes += cSlice_init(&cSlice_fy92pdSO, 1, -1);
  numBytes += cVar_init_f(&cVar_UZMfdMEz, 0.0f);
  numBytes += cSlice_init(&cSlice_TlpGHYYK, 1, -1);
  numBytes += cVar_init_f(&cVar_brksgLME, 0.0f);
  numBytes += cSlice_init(&cSlice_qq182tn0, 1, -1);
  numBytes += cVar_init_f(&cVar_ZDCxYx3o, 0.313f);
  numBytes += cBinop_init(&cBinop_eABtQfiN, 44100.0f); // __div
  numBytes += cBinop_init(&cBinop_fZIx0FAn, 0.0f); // __mul
  numBytes += cVar_init_f(&cVar_xT1lZ4YB, 0.0f);
  numBytes += cVar_init_f(&cVar_ZfiLw1Az, 1337.0f);
  numBytes += cVar_init_f(&cVar_xoh9dAoS, 0.3f);
  numBytes += cBinop_init(&cBinop_Nq5h7LD2, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_3lMhlDRi, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_MfDdsGy0, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_ntowPjob, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_yzdYPL6U, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_bB0QW9ZW, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_K3jLt9ZZ, 44100.0f); // __div
  numBytes += cBinop_init(&cBinop_QqrpqIHk, 0.0f); // __mul
  numBytes += cVar_init_f(&cVar_Ou1SW9Kg, 0.0f);
  numBytes += cVar_init_f(&cVar_xg37TT1N, 1337.0f);
  numBytes += cVar_init_f(&cVar_WUJWUTk1, 0.313f);
  numBytes += cBinop_init(&cBinop_kI17YiMS, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_kJrp69nj, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_G3XUiOR6, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_eyGZil9v, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_m9jm4EI2, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_U0j64Xjt, 44100.0f); // __div
  numBytes += cBinop_init(&cBinop_vmHY4wMU, 0.0f); // __mul
  numBytes += cVar_init_f(&cVar_G7obZzs2, 0.0f);
  numBytes += cVar_init_f(&cVar_eZ0ffdbI, 1037.0f);
  numBytes += cVar_init_f(&cVar_iAhlAYL8, 0.4f);
  numBytes += cBinop_init(&cBinop_CZOdrmYS, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_pOfo2KaY, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_Lw63qwWk, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_7bkaSXyg, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_hvtHFVp5, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_JtJobCu8, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_B5voVTaw, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_lCe4YhGH, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_WsH2Fj1A, 0.0f, 0.0f, false);
  numBytes += cSlice_init(&cSlice_Q4L27Vtq, 1, -1);
  numBytes += cVar_init_f(&cVar_WGfMUszf, 1337.0f);
  numBytes += cVar_init_f(&cVar_pwe93PqJ, 0.0f);
  numBytes += cIf_init(&cIf_oN9t3Tmk, false);
  numBytes += cIf_init(&cIf_nYs12wey, false);
  numBytes += cBinop_init(&cBinop_Th5Bg8bu, 0.0f); // __pow
  numBytes += cIf_init(&cIf_xcua7GcH, false);
  numBytes += cBinop_init(&cBinop_EysYsmYG, 0.0f); // __add
  numBytes += cBinop_init(&cBinop_LH1FCjnm, -15.0f); // __gt
  numBytes += cBinop_init(&cBinop_fAnLej0i, -15.0f); // __eq
  numBytes += cVar_init_f(&cVar_qkcK6T8f, 0.0f);
  numBytes += cIf_init(&cIf_Fsb3dljh, false);
  numBytes += cIf_init(&cIf_ETkKcKu2, false);
  numBytes += cBinop_init(&cBinop_Sxe1Rne9, 0.0f); // __pow
  numBytes += cIf_init(&cIf_4xXuUCLU, false);
  numBytes += cBinop_init(&cBinop_UYZBWfaN, 0.0f); // __add
  numBytes += cBinop_init(&cBinop_Lu3GglP0, -15.0f); // __gt
  numBytes += cBinop_init(&cBinop_pDDQ1mmP, -15.0f); // __eq
  numBytes += cVar_init_f(&cVar_N3ZDDLnB, 0.0f);
  numBytes += cIf_init(&cIf_Lv5EeKne, false);
  numBytes += cIf_init(&cIf_2br6tstG, false);
  numBytes += cBinop_init(&cBinop_vbI4yZXw, 0.0f); // __pow
  numBytes += cIf_init(&cIf_P8Yr9PST, false);
  numBytes += cBinop_init(&cBinop_V0wcLLzw, 0.0f); // __add
  numBytes += cBinop_init(&cBinop_FG8yUNHh, -15.0f); // __gt
  numBytes += cBinop_init(&cBinop_I6UscKDt, -15.0f); // __eq
  numBytes += cIf_init(&cIf_DNjaXpKc, false);
  numBytes += cSlice_init(&cSlice_9VovVso8, 1, -1);
  numBytes += cVar_init_f(&cVar_1oFbqSzK, 0.0f);
  numBytes += cSlice_init(&cSlice_lVK46kvI, 1, -1);
  numBytes += cVar_init_f(&cVar_LECxQEL8, 0.0f);
  numBytes += cSlice_init(&cSlice_jndiSF42, 1, -1);
  numBytes += cVar_init_f(&cVar_Rzf9ZZA3, 0.0f);
  numBytes += cSlice_init(&cSlice_jAQittxU, 1, -1);
  numBytes += cVar_init_f(&cVar_ob9UE0Ca, 0.313f);
  numBytes += cBinop_init(&cBinop_fCNng0nv, 44100.0f); // __div
  numBytes += cBinop_init(&cBinop_Se6xbuK6, 0.0f); // __mul
  numBytes += cVar_init_f(&cVar_gKSe4JZ5, 0.0f);
  numBytes += cVar_init_f(&cVar_sQ0Mn5p5, 1337.0f);
  numBytes += cVar_init_f(&cVar_lHb4owyq, 0.3f);
  numBytes += cBinop_init(&cBinop_6IsKqxwJ, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_9FVKRNur, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_QeYYQh5B, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_t5h3xhxt, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_WgujFuwL, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_791HvfbQ, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_ulgFWccZ, 44100.0f); // __div
  numBytes += cBinop_init(&cBinop_yaFruEEd, 0.0f); // __mul
  numBytes += cVar_init_f(&cVar_BDrKMkJF, 0.0f);
  numBytes += cVar_init_f(&cVar_QhKAWvsg, 1337.0f);
  numBytes += cVar_init_f(&cVar_GuDBhog1, 0.313f);
  numBytes += cBinop_init(&cBinop_zUL40tdL, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_zYbTzzYB, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_9HARUeHK, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_tPy92p9v, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_wmrEmbys, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_HzWfJH3S, 44100.0f); // __div
  numBytes += cBinop_init(&cBinop_yEgs45cU, 0.0f); // __mul
  numBytes += cVar_init_f(&cVar_8FaHJs76, 0.0f);
  numBytes += cVar_init_f(&cVar_JtZDGlrz, 1037.0f);
  numBytes += cVar_init_f(&cVar_eLTp1060, 0.4f);
  numBytes += cBinop_init(&cBinop_OMghttiD, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_UG0YmsRq, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_yhMzCCcv, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_h73UZXW5, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_KhDvGpim, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_1LeuviZ4, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_6eWypeeA, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_QiLGSnW6, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_GtLHt4EO, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_dHQVFpkQ, 5705.6f);
  numBytes += cVar_init_f(&cVar_M7MwY8Wb, 313.3f);
  numBytes += cBinop_init(&cBinop_GkcaojIW, 0.0f); // __div
  numBytes += cBinop_init(&cBinop_TYFKHpmx, 0.0f); // __div
  numBytes += cBinop_init(&cBinop_zvo1Ct3S, 0.0f); // __div
  numBytes += cVar_init_f(&cVar_brJ0rktj, 0.0f);
  numBytes += cVar_init_f(&cVar_9YoovCgO, 0.0f);
  numBytes += cVar_init_f(&cVar_2zFWbvLP, 0.0f);
  numBytes += cVar_init_f(&cVar_igu0BTw1, 0.0f);
  numBytes += cVar_init_f(&cVar_utldGmWc, 0.0f);
  numBytes += cVar_init_f(&cVar_Oj2gIYut, 0.0f);
  numBytes += cVar_init_f(&cVar_AgaacGEk, 0.0f);
  numBytes += cVar_init_f(&cVar_CzXRd8w7, 0.0f);
  numBytes += cVar_init_f(&cVar_u5wTkiVb, 0.0f);
  numBytes += cVar_init_f(&cVar_GLlfoVCt, 0.0f);
  numBytes += cVar_init_f(&cVar_YPtaGY32, 0.0f);
  numBytes += cVar_init_f(&cVar_RMfHDcbx, 0.0f);
  numBytes += cSlice_init(&cSlice_ez8w0VYx, 1, -1);
  numBytes += cVar_init_f(&cVar_kGqaLbxA, 0.5f);
  numBytes += cSlice_init(&cSlice_JITWoRKU, 1, -1);
  numBytes += cVar_init_f(&cVar_uRDYsgWq, 0.2f);
  numBytes += cSlice_init(&cSlice_93r9i9zd, 1, -1);
  numBytes += cVar_init_f(&cVar_vDfSlMcQ, 500.0f);
  numBytes += sVarf_init(&sVarf_Mi1zyoxV, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_rsqM1cht, 600.0f);
  numBytes += cBinop_init(&cBinop_Oq26CBMo, 0.0f); // __div
  numBytes += sVarf_init(&sVarf_N4HLeqZs, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_fWUdcIdS, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_lLSy9atD, 600.0f);
  numBytes += cBinop_init(&cBinop_ivPYvZIw, 0.0f); // __div
  numBytes += sVarf_init(&sVarf_6R98Giqd, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_GkfmpG8l, 4000.0f);
  numBytes += cBinop_init(&cBinop_HiQkSmH3, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_kjuXP6lV, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_5vvyGBBx, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_ciq8E9C3, 4000.0f);
  numBytes += cBinop_init(&cBinop_dFO95vjC, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_6ABURnfh, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_f9bgea55, 0.0f, 0.0f, false);
  numBytes += cIf_init(&cIf_WvTra8Se, false);
  numBytes += cBinop_init(&cBinop_ErQ5fErU, 0.0f); // __pow
  numBytes += cVar_init_f(&cVar_WWPjSuvk, 20.0f);
  numBytes += cBinop_init(&cBinop_IdKvyeJI, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_u841L0ya, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_wIXjPGFB, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_lBmUzBZX, 0.0f, 0.0f, false);
  numBytes += cIf_init(&cIf_MbTQvfOi, false);
  numBytes += cBinop_init(&cBinop_DyaGL7tn, 0.0f); // __pow
  numBytes += cVar_init_f(&cVar_Z8jQ3ioI, 20.0f);
  numBytes += cBinop_init(&cBinop_pcAa7J2r, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_StyVyNVt, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_l5ZeRrZt, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_eXOR32gl, 0.0f, 0.0f, false);
  numBytes += cSlice_init(&cSlice_I48CQQv9, 1, -1);
  numBytes += cVar_init_f(&cVar_Q7WTkLnO, 0.25f);
  numBytes += cDelay_init(this, &cDelay_Dkc5HOOv, 0.0f);
  numBytes += cDelay_init(this, &cDelay_7o17fACz, 0.0f);
  numBytes += hTable_init(&hTable_7x0B2Fxc, 256);
  numBytes += cTabhead_init(&cTabhead_Val5Nhh7, &hTable_7x0B2Fxc);
  numBytes += cVar_init_s(&cVar_lV6Yu5SE, "del-1349-delayL");
  numBytes += cDelay_init(this, &cDelay_Cwd9s4Kc, 0.0f);
  numBytes += cDelay_init(this, &cDelay_DulcciMx, 0.0f);
  numBytes += cBinop_init(&cBinop_yqebyBIR, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_VcH3Y18J, 0.0f); // __sub
  numBytes += cBinop_init(&cBinop_FAETmBqC, 0.0f); // __max
  numBytes += cBinop_init(&cBinop_rShAskdf, 0.0f); // __sub
  numBytes += cDelay_init(this, &cDelay_2wsHuuO9, 0.0f);
  numBytes += cDelay_init(this, &cDelay_Y0IojV5f, 0.0f);
  numBytes += hTable_init(&hTable_I5cfsGR3, 256);
  numBytes += cTabhead_init(&cTabhead_TZiWyNYt, &hTable_I5cfsGR3);
  numBytes += cVar_init_s(&cVar_yWl4KRIG, "del-1349-delayR");
  numBytes += cDelay_init(this, &cDelay_n1w8audf, 0.0f);
  numBytes += cDelay_init(this, &cDelay_6I8sI1gE, 0.0f);
  numBytes += cBinop_init(&cBinop_uDiiH0hO, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_GukUANOf, 0.0f); // __sub
  numBytes += cBinop_init(&cBinop_yVX6n3Sw, 0.0f); // __max
  numBytes += cBinop_init(&cBinop_dZWCteqB, 0.0f); // __sub
  numBytes += sVarf_init(&sVarf_r2mW0Z2a, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_RdVPLh9F, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_rsnEfAuG, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_htdgGcY3, 0.0f, 0.0f, false);
  numBytes += cSlice_init(&cSlice_vhpxAoW8, 1, -1);
  numBytes += cVar_init_f(&cVar_RZS7IiRM, 0.5f);
  numBytes += cSlice_init(&cSlice_O9VblBZy, 1, -1);
  numBytes += cVar_init_f(&cVar_tCSYAsV6, 0.2f);
  numBytes += cSlice_init(&cSlice_TWf10aQb, 1, -1);
  numBytes += cVar_init_f(&cVar_JTOxxBwX, 500.0f);
  numBytes += sVarf_init(&sVarf_01hyF3K3, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_2KOQ69tv, 600.0f);
  numBytes += cBinop_init(&cBinop_CtyhQUb2, 0.0f); // __div
  numBytes += sVarf_init(&sVarf_4iI4RvEg, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_G6r8JQDK, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_PWHgirq6, 600.0f);
  numBytes += cBinop_init(&cBinop_bSk8iR2z, 0.0f); // __div
  numBytes += sVarf_init(&sVarf_hmcEjZuy, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_oycvtVJP, 4000.0f);
  numBytes += cBinop_init(&cBinop_ow8O1xDd, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_Vwah0IL2, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_6EUbuRpa, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_6bveOwfp, 4000.0f);
  numBytes += cBinop_init(&cBinop_mGE52jIA, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_bg7wtqrx, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_fgYSlY9V, 0.0f, 0.0f, false);
  numBytes += cIf_init(&cIf_tSW2bhWQ, false);
  numBytes += cBinop_init(&cBinop_cgwvja55, 0.0f); // __pow
  numBytes += cVar_init_f(&cVar_yckCdJYg, 20.0f);
  numBytes += cBinop_init(&cBinop_MhVBxCYa, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_p9NAi40S, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_bIUv0IGp, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_sAJwsfF7, 0.0f, 0.0f, false);
  numBytes += cIf_init(&cIf_tsPvoHks, false);
  numBytes += cBinop_init(&cBinop_385enrn2, 0.0f); // __pow
  numBytes += cVar_init_f(&cVar_rOmtiryS, 20.0f);
  numBytes += cBinop_init(&cBinop_6O0v284K, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_Z4KtHpa4, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_FzIY2RNJ, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_xMCqYZ1U, 0.0f, 0.0f, false);
  numBytes += cSlice_init(&cSlice_q8AXAQCf, 1, -1);
  numBytes += cVar_init_f(&cVar_tVDPxd2z, 0.25f);
  numBytes += cDelay_init(this, &cDelay_kMS6F6e3, 0.0f);
  numBytes += cDelay_init(this, &cDelay_5nUSdKE2, 0.0f);
  numBytes += hTable_init(&hTable_ow1qv5O7, 256);
  numBytes += cTabhead_init(&cTabhead_yOj6zCUq, &hTable_ow1qv5O7);
  numBytes += cVar_init_s(&cVar_7BXFbOSu, "del-1428-delayL");
  numBytes += cDelay_init(this, &cDelay_z592QUMT, 0.0f);
  numBytes += cDelay_init(this, &cDelay_6a36MpoM, 0.0f);
  numBytes += cBinop_init(&cBinop_qCLGO9Ve, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_utsHsSCz, 0.0f); // __sub
  numBytes += cBinop_init(&cBinop_6ghhxEwN, 0.0f); // __max
  numBytes += cBinop_init(&cBinop_1MnTlNtJ, 0.0f); // __sub
  numBytes += cDelay_init(this, &cDelay_tH1gKy6k, 0.0f);
  numBytes += cDelay_init(this, &cDelay_ipycJOdv, 0.0f);
  numBytes += hTable_init(&hTable_VKt3CZZ8, 256);
  numBytes += cTabhead_init(&cTabhead_xfLdtVPh, &hTable_VKt3CZZ8);
  numBytes += cVar_init_s(&cVar_PMcml0Ud, "del-1428-delayR");
  numBytes += cDelay_init(this, &cDelay_uqJ3GMbB, 0.0f);
  numBytes += cDelay_init(this, &cDelay_qtzD9LWm, 0.0f);
  numBytes += cBinop_init(&cBinop_C0FcKmSr, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_8CSthkTu, 0.0f); // __sub
  numBytes += cBinop_init(&cBinop_VwAYUUU0, 0.0f); // __max
  numBytes += cBinop_init(&cBinop_G2GOFdn4, 0.0f); // __sub
  numBytes += sVarf_init(&sVarf_39LPmYJg, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_sRGoMECO, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_UOaBr7wU, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_jTrTK7X9, 0.0f, 0.0f, false);
  numBytes += cSlice_init(&cSlice_Qd9xMcl5, 1, -1);
  numBytes += cVar_init_f(&cVar_O3SWsKV3, 0.5f);
  numBytes += cSlice_init(&cSlice_CmiZXgTL, 1, -1);
  numBytes += cVar_init_f(&cVar_HYHTTl66, 0.2f);
  numBytes += cSlice_init(&cSlice_14hrt0rU, 1, -1);
  numBytes += cVar_init_f(&cVar_sgG0Cozu, 500.0f);
  numBytes += sVarf_init(&sVarf_Nxn0n1oa, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_p9gpRiwY, 600.0f);
  numBytes += cBinop_init(&cBinop_vDZyFtWU, 0.0f); // __div
  numBytes += sVarf_init(&sVarf_bz7rz5MB, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_pSVQhfr7, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_f5fsM5bC, 600.0f);
  numBytes += cBinop_init(&cBinop_dteBWwG6, 0.0f); // __div
  numBytes += sVarf_init(&sVarf_XjlIYitk, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_0NC68WAx, 4000.0f);
  numBytes += cBinop_init(&cBinop_zvBW6ryn, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_sWh8fXlY, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_vnAo5vvj, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_kHK4nvmN, 4000.0f);
  numBytes += cBinop_init(&cBinop_2ntUgqOq, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_rSNdaVjm, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_AuPyjV2m, 0.0f, 0.0f, false);
  numBytes += cIf_init(&cIf_TIMND7dA, false);
  numBytes += cBinop_init(&cBinop_Tmo1tkRM, 0.0f); // __pow
  numBytes += cVar_init_f(&cVar_i07OGQvF, 20.0f);
  numBytes += cBinop_init(&cBinop_SYsS9lrs, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_cm0Aqeru, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_p5sKIF0t, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_9js6lp04, 0.0f, 0.0f, false);
  numBytes += cIf_init(&cIf_ng40fHrz, false);
  numBytes += cBinop_init(&cBinop_CkY2Xpwr, 0.0f); // __pow
  numBytes += cVar_init_f(&cVar_Nw1VAyFT, 20.0f);
  numBytes += cBinop_init(&cBinop_uXDiHPaY, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_Jskw2RVu, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_oMwLJBxs, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_Oil0y0OV, 0.0f, 0.0f, false);
  numBytes += cSlice_init(&cSlice_QXsvNn6o, 1, -1);
  numBytes += cVar_init_f(&cVar_6kgkAgWl, 0.25f);
  numBytes += cDelay_init(this, &cDelay_eya7hvUT, 0.0f);
  numBytes += cDelay_init(this, &cDelay_RAeUuBFj, 0.0f);
  numBytes += hTable_init(&hTable_IrqxgK4k, 256);
  numBytes += cTabhead_init(&cTabhead_YTww5dEa, &hTable_IrqxgK4k);
  numBytes += cVar_init_s(&cVar_M2Z2Bdn6, "del-1507-delayL");
  numBytes += cDelay_init(this, &cDelay_xH7p8J9Q, 0.0f);
  numBytes += cDelay_init(this, &cDelay_XQI9J9TW, 0.0f);
  numBytes += cBinop_init(&cBinop_HPAs9n7R, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_zYzmTOnc, 0.0f); // __sub
  numBytes += cBinop_init(&cBinop_TxkTUEJS, 0.0f); // __max
  numBytes += cBinop_init(&cBinop_jozbxScZ, 0.0f); // __sub
  numBytes += cDelay_init(this, &cDelay_ZR4WWq5R, 0.0f);
  numBytes += cDelay_init(this, &cDelay_sVHWU3FX, 0.0f);
  numBytes += hTable_init(&hTable_sMKT60V5, 256);
  numBytes += cTabhead_init(&cTabhead_AB0EoVQC, &hTable_sMKT60V5);
  numBytes += cVar_init_s(&cVar_GCGxyoU0, "del-1507-delayR");
  numBytes += cDelay_init(this, &cDelay_zhVvmoWd, 0.0f);
  numBytes += cDelay_init(this, &cDelay_gnGXyKri, 0.0f);
  numBytes += cBinop_init(&cBinop_xqtIj8qn, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_lFerc9rX, 0.0f); // __sub
  numBytes += cBinop_init(&cBinop_n5l7yLAb, 0.0f); // __max
  numBytes += cBinop_init(&cBinop_RYzivXuw, 0.0f); // __sub
  numBytes += sVarf_init(&sVarf_JrWHm98Q, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_8CgbArhg, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_cIcOzDUx, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_HusMana9, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_kIXdwy0B, 1.0f);
  numBytes += cIf_init(&cIf_4E0mx7xZ, false);
  numBytes += cIf_init(&cIf_cYbjIEwg, false);
  numBytes += cVar_init_f(&cVar_bygDHTwS, 0.0f);
  numBytes += cVar_init_f(&cVar_5OeLi2PR, 0.0f);
  numBytes += cVar_init_f(&cVar_w0UJb77V, 1.0f);
  numBytes += cIf_init(&cIf_UGKlxazr, false);
  numBytes += cIf_init(&cIf_DRtmG87B, false);
  numBytes += cVar_init_f(&cVar_mBcpjVe2, 0.0f);
  numBytes += cVar_init_f(&cVar_mmbbtOih, 0.0f);
  numBytes += cVar_init_f(&cVar_cbvDoQC5, 1.0f);
  numBytes += cIf_init(&cIf_gRaeQ2EU, false);
  numBytes += cIf_init(&cIf_w0pkS7Na, false);
  numBytes += cVar_init_f(&cVar_QtEArDxH, 0.0f);
  numBytes += cVar_init_f(&cVar_uIFXUWX6, 0.0f);
  numBytes += cVar_init_f(&cVar_9TDEEqkB, 60000.0f);
  numBytes += cVar_init_f(&cVar_tUXcndqK, 500.0f);
  numBytes += cSlice_init(&cSlice_UhiVaR2m, 1, -1);
  numBytes += cSlice_init(&cSlice_8rUGmXSw, 1, -1);
  numBytes += cVar_init_f(&cVar_wK93Cuqb, 0.0f);
  numBytes += cIf_init(&cIf_fNJUTMgA, false);
  numBytes += cBinop_init(&cBinop_oQ5TJkgY, 0.0f); // __neq
  numBytes += cVar_init_f(&cVar_RiZ9gdfi, 120.0f);
  numBytes += cBinop_init(&cBinop_jqHJQteq, 0.0f); // __div
  numBytes += cBinop_init(&cBinop_b7b1yUvH, 0.0f); // __mul
  numBytes += cVar_init_f(&cVar_jYcs3olk, 60000.0f);
  numBytes += cVar_init_f(&cVar_clTJRlkJ, 500.0f);
  numBytes += cSlice_init(&cSlice_duQdGCpt, 1, -1);
  numBytes += cSlice_init(&cSlice_HhiJU4ZA, 1, -1);
  numBytes += cVar_init_f(&cVar_S2l4jjOH, 0.0f);
  numBytes += cIf_init(&cIf_EweT7bkT, false);
  numBytes += cBinop_init(&cBinop_R0MTo50K, 0.0f); // __neq
  numBytes += cVar_init_f(&cVar_ZIJljrpu, 120.0f);
  numBytes += cBinop_init(&cBinop_CuUXefTh, 0.0f); // __div
  numBytes += cBinop_init(&cBinop_q0bELRkH, 0.0f); // __mul
  numBytes += cVar_init_f(&cVar_bKxZotT7, 60000.0f);
  numBytes += cVar_init_f(&cVar_R61GhKrT, 500.0f);
  numBytes += cSlice_init(&cSlice_K0qn4FB5, 1, -1);
  numBytes += cSlice_init(&cSlice_D2kzrYKa, 1, -1);
  numBytes += cVar_init_f(&cVar_2Dnnx7oU, 0.0f);
  numBytes += cIf_init(&cIf_8h2gezBs, false);
  numBytes += cBinop_init(&cBinop_gtkwbS5i, 0.0f); // __neq
  numBytes += cVar_init_f(&cVar_5YQWFGru, 120.0f);
  numBytes += cBinop_init(&cBinop_nkyi6NUG, 0.0f); // __div
  numBytes += cBinop_init(&cBinop_pJz6ph0a, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_E3UXRSkI, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_AOOThPd4, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_CygDMB68, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_lIBMxhwc, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_8zNzq4nt, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_6NKVfdrQ, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_UmstNUUV, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_HPbTXpUq, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_61cSWSu8, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_CV3Bov5P, 0.0f, 0.0f, false);
  
  // schedule a message to trigger all loadbangs via the __hv_init receiver
  scheduleMessageForReceiver(0xCE5CC65B, msg_initWithBang(HV_MESSAGE_ON_STACK(1), 0));
}

Heavy_WSTD_DL3Y::~Heavy_WSTD_DL3Y() {
  sEnv_free(&sEnv_nf33n1xb);
  sEnv_free(&sEnv_rVYbO1Pz);
  sEnv_free(&sEnv_gUwuReQU);
  sEnv_free(&sEnv_hzBDacSm);
  sEnv_free(&sEnv_Fc2FwUTu);
  sEnv_free(&sEnv_dgyvxZWQ);
  hTable_free(&hTable_7x0B2Fxc);
  hTable_free(&hTable_I5cfsGR3);
  hTable_free(&hTable_ow1qv5O7);
  hTable_free(&hTable_VKt3CZZ8);
  hTable_free(&hTable_IrqxgK4k);
  hTable_free(&hTable_sMKT60V5);
}

HvTable *Heavy_WSTD_DL3Y::getTableForHash(hv_uint32_t tableHash) {switch (tableHash) {
    case 0x29B74AF: return &hTable_7x0B2Fxc; // del-1349-delayL
    case 0x19A00729: return &hTable_I5cfsGR3; // del-1349-delayR
    case 0x584C8281: return &hTable_ow1qv5O7; // del-1428-delayL
    case 0x54BF59F6: return &hTable_VKt3CZZ8; // del-1428-delayR
    case 0xBCE693A: return &hTable_IrqxgK4k; // del-1507-delayL
    case 0x95A380B3: return &hTable_sMKT60V5; // del-1507-delayR
    default: return nullptr;
  }
}

void Heavy_WSTD_DL3Y::scheduleMessageForReceiver(hv_uint32_t receiverHash, HvMessage *m) {
  switch (receiverHash) {
    case 0xC9CE7B11: { // High
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_DhnmRIRV_sendMessage);
      break;
    }
    case 0xBB584857: { // High_Cross
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_rW434mHn_sendMessage);
      break;
    }
    case 0xACE44B9C: { // High_Feedback
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_pXqmSSZT_sendMessage);
      break;
    }
    case 0xAC5FA57F: { // High_Mix
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_CXQe01Wr_sendMessage);
      break;
    }
    case 0xDD62B09F: { // High_Sync
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_ALH1b96t_sendMessage);
      break;
    }
    case 0xABB0CBCF: { // High_Time
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_jty99IHw_sendMessage);
      break;
    }
    case 0xAE942A2: { // High_TimeSync
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_nqS75B1s_sendMessage);
      break;
    }
    case 0x87744544: { // Low
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_DxIYaIkG_sendMessage);
      break;
    }
    case 0xA2D68920: { // Low_Cross
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_e4D4sKeu_sendMessage);
      break;
    }
    case 0xDDAB7A0: { // Low_Feedback
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_GTcwaMnS_sendMessage);
      break;
    }
    case 0x91FEF7A: { // Low_Mix
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_1aYFykwI_sendMessage);
      break;
    }
    case 0xFFFEE96: { // Low_Sync
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_Jbt7g7ZB_sendMessage);
      break;
    }
    case 0xA3BD8A20: { // Low_Time
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_tDZitFhc_sendMessage);
      break;
    }
    case 0x67F58CFB: { // Low_TimeSync
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_bZsHUM84_sendMessage);
      break;
    }
    case 0xBFDC48B6: { // Mid
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_1UxWgfmE_sendMessage);
      break;
    }
    case 0x59607D3: { // Mid_Cross
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_wTO2NOAl_sendMessage);
      break;
    }
    case 0x9B44FA2D: { // Mid_Feedback
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_m3M5Hrcr_sendMessage);
      break;
    }
    case 0x59CF21AC: { // Mid_Freq
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_BxsoSdTy_sendMessage);
      break;
    }
    case 0x676FE235: { // Mid_Mix
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_akd8OWiH_sendMessage);
      break;
    }
    case 0x96E19510: { // Mid_Sync
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_wmwjU7mo_sendMessage);
      break;
    }
    case 0xE1DB1774: { // Mid_Time
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_zXvb9OLs_sendMessage);
      break;
    }
    case 0xDB67B94E: { // Mid_TimeSync
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_RXiQNpFQ_sendMessage);
      break;
    }
    case 0x24295C10: { // 1010-highvol
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_AmcmQOld_sendMessage);
      break;
    }
    case 0x3649681E: { // 1010-lowvol
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_XPf1l4OY_sendMessage);
      break;
    }
    case 0xD5A8E74D: { // 1010-midfreq
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_8ybRmWrE_sendMessage);
      break;
    }
    case 0x60D6F65: { // 1010-midq
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_KNUZbcmp_sendMessage);
      break;
    }
    case 0x37E92263: { // 1010-midvol
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_zn8Hzm46_sendMessage);
      break;
    }
    case 0x2271964: { // 1069-alpha
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_gEJSWdty_sendMessage);
      break;
    }
    case 0xA61C5543: { // 1069-wcos
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_TV0wocMk_sendMessage);
      break;
    }
    case 0x1E13C49D: { // 1069-wsin
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_XSYU8plZ_sendMessage);
      break;
    }
    case 0xE7448D12: { // 1110-alpha
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_wCwVem92_sendMessage);
      break;
    }
    case 0x5F31ED81: { // 1110-wcos
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_bHuX3FnE_sendMessage);
      break;
    }
    case 0xC3520438: { // 1110-wsin
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_tckQtwuy_sendMessage);
      break;
    }
    case 0xB2DA8F9A: { // 1151-alpha
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_4BmdDKkp_sendMessage);
      break;
    }
    case 0x668DC2C1: { // 1151-wcos
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_PCs5kunQ_sendMessage);
      break;
    }
    case 0x413B9F30: { // 1151-wsin
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_7Howap1y_sendMessage);
      break;
    }
    case 0x845815A0: { // 1163-highvol
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_rR0BErhZ_sendMessage);
      break;
    }
    case 0x5CD8AF91: { // 1163-lowvol
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_lFGs1qrT_sendMessage);
      break;
    }
    case 0x188BB7A0: { // 1163-midfreq
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_VaDMT3H0_sendMessage);
      break;
    }
    case 0xE3BB13E4: { // 1163-midq
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_b4NkUvVP_sendMessage);
      break;
    }
    case 0x3693B415: { // 1163-midvol
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_ClgD7JLd_sendMessage);
      break;
    }
    case 0x1A14721E: { // 1222-alpha
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_Jr9PoLQS_sendMessage);
      break;
    }
    case 0x446DC164: { // 1222-wcos
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_9ZHmxuev_sendMessage);
      break;
    }
    case 0x32F45A8B: { // 1222-wsin
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_QEadFXLQ_sendMessage);
      break;
    }
    case 0x1286072C: { // 1263-alpha
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_vHn8kUZN_sendMessage);
      break;
    }
    case 0x7902A17C: { // 1263-wcos
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_bHLlHYrN_sendMessage);
      break;
    }
    case 0x7A57C19C: { // 1263-wsin
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_DVuiQCqz_sendMessage);
      break;
    }
    case 0x170C9887: { // 1304-alpha
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_ObnoyJWH_sendMessage);
      break;
    }
    case 0xED0CBA1C: { // 1304-wcos
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_9yWBWtPf_sendMessage);
      break;
    }
    case 0xDA3A818C: { // 1304-wsin
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_deQuS1az_sendMessage);
      break;
    }
    case 0x9FC1C9E5: { // 1349-cross
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_ozcDJoBX_sendMessage);
      break;
    }
    case 0x5D7BD4E9: { // 1349-feedback
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_gEkbwGam_sendMessage);
      break;
    }
    case 0x371A347A: { // 1349-mix
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_oWkHAwNv_sendMessage);
      break;
    }
    case 0x810E74BC: { // 1349-time
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_hqHZwhBR_sendMessage);
      break;
    }
    case 0xCC56B3CF: { // 1428-cross
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_AaZVT2lV_sendMessage);
      break;
    }
    case 0x499A953B: { // 1428-feedback
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_VQM9ZWSq_sendMessage);
      break;
    }
    case 0xE0E7225B: { // 1428-mix
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_fUAyzHnZ_sendMessage);
      break;
    }
    case 0xE6486F5F: { // 1428-time
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_riZFAJzg_sendMessage);
      break;
    }
    case 0xF65E8330: { // 1507-cross
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_nj5fstQ3_sendMessage);
      break;
    }
    case 0x3B8B5FB8: { // 1507-feedback
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_gCesg3MU_sendMessage);
      break;
    }
    case 0xE5F26E0D: { // 1507-mix
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_4ULDuD1x_sendMessage);
      break;
    }
    case 0xFDAB8735: { // 1507-time
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_FqGBO4JI_sendMessage);
      break;
    }
    case 0xDF8C2721: { // __hv_dpf_bpm
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_PiMhcv4x_sendMessage);
      break;
    }
    case 0xCE5CC65B: { // __hv_init
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_6LRog841_sendMessage);
      break;
    }
    default: return;
  }
}

int Heavy_WSTD_DL3Y::getParameterInfo(int index, HvParameterInfo *info) {
  if (info != nullptr) {
    switch (index) {
      case 0: {
        info->name = "High";
        info->hash = 0xC9CE7B11;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = -15.0f;
        info->maxVal = 15.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 1: {
        info->name = "High_Cross";
        info->hash = 0xBB584857;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 100.0f;
        info->defaultVal = 20.0f;
        break;
      }
      case 2: {
        info->name = "High_Feedback";
        info->hash = 0xACE44B9C;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 100.0f;
        info->defaultVal = 25.0f;
        break;
      }
      case 3: {
        info->name = "High_Mix";
        info->hash = 0xAC5FA57F;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 100.0f;
        info->defaultVal = 50.0f;
        break;
      }
      case 4: {
        info->name = "High_Sync";
        info->hash = 0xDD62B09F;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 1.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 5: {
        info->name = "High_Time";
        info->hash = 0xABB0CBCF;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 50.0f;
        info->maxVal = 5000.0f;
        info->defaultVal = 500.0f;
        break;
      }
      case 6: {
        info->name = "High_TimeSync";
        info->hash = 0xAE942A2;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 12.0f;
        info->defaultVal = 6.0f;
        break;
      }
      case 7: {
        info->name = "Low";
        info->hash = 0x87744544;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = -15.0f;
        info->maxVal = 15.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 8: {
        info->name = "Low_Cross";
        info->hash = 0xA2D68920;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 100.0f;
        info->defaultVal = 20.0f;
        break;
      }
      case 9: {
        info->name = "Low_Feedback";
        info->hash = 0xDDAB7A0;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 100.0f;
        info->defaultVal = 25.0f;
        break;
      }
      case 10: {
        info->name = "Low_Mix";
        info->hash = 0x91FEF7A;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 100.0f;
        info->defaultVal = 50.0f;
        break;
      }
      case 11: {
        info->name = "Low_Sync";
        info->hash = 0xFFFEE96;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 1.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 12: {
        info->name = "Low_Time";
        info->hash = 0xA3BD8A20;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 50.0f;
        info->maxVal = 5000.0f;
        info->defaultVal = 500.0f;
        break;
      }
      case 13: {
        info->name = "Low_TimeSync";
        info->hash = 0x67F58CFB;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 12.0f;
        info->defaultVal = 6.0f;
        break;
      }
      case 14: {
        info->name = "Mid";
        info->hash = 0xBFDC48B6;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = -15.0f;
        info->maxVal = 15.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 15: {
        info->name = "Mid_Cross";
        info->hash = 0x59607D3;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 100.0f;
        info->defaultVal = 20.0f;
        break;
      }
      case 16: {
        info->name = "Mid_Feedback";
        info->hash = 0x9B44FA2D;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 100.0f;
        info->defaultVal = 25.0f;
        break;
      }
      case 17: {
        info->name = "Mid_Freq";
        info->hash = 0x59CF21AC;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 313.3f;
        info->maxVal = 5705.6f;
        info->defaultVal = 1337.0f;
        break;
      }
      case 18: {
        info->name = "Mid_Mix";
        info->hash = 0x676FE235;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 100.0f;
        info->defaultVal = 50.0f;
        break;
      }
      case 19: {
        info->name = "Mid_Sync";
        info->hash = 0x96E19510;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 1.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 20: {
        info->name = "Mid_Time";
        info->hash = 0xE1DB1774;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 50.0f;
        info->maxVal = 5000.0f;
        info->defaultVal = 500.0f;
        break;
      }
      case 21: {
        info->name = "Mid_TimeSync";
        info->hash = 0xDB67B94E;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 12.0f;
        info->defaultVal = 6.0f;
        break;
      }
      default: {
        info->name = "invalid parameter index";
        info->hash = 0;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 0.0f;
        info->defaultVal = 0.0f;
        break;
      }
    }
  }
  return 22;
}



/*
 * Send Function Implementations
 */


void Heavy_WSTD_DL3Y::cVar_CAfcGm5J_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_LhJwYxV7_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cVar_Nsfw9KW9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_uxijuReR_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cVar_I1b5BD5b_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_C2zxQfrF_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cVar_RbeHcJn5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_4mpoI0A4_sendMessage(_c, 0, m);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_7i2gXh2f_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_DCIqxx7W_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_K0sAYNTt_sendMessage);
}

void Heavy_WSTD_DL3Y::cSwitchcase_aO3T8oW5_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xE9AAC520: { // "midfreq"
      cSlice_onMessage(_c, &Context(_c)->cSlice_iGbrKtnK, 0, m, &cSlice_iGbrKtnK_sendMessage);
      break;
    }
    default: {
      cSwitchcase_HnQPKVZG_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_DL3Y::cSlice_iGbrKtnK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_PUpC7SIQ_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_PUpC7SIQ_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cVar_FairG79L_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_PUpC7SIQ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSend_PUpC7SIQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_8ybRmWrE_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cVar_p04F4Mlz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_6tqwYqAI_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_7uPFdJjW, 0, m, &cIf_7uPFdJjW_sendMessage);
}

void Heavy_WSTD_DL3Y::cIf_7uPFdJjW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_JXmhKcR2_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cIf_kHGKfNqa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_6SCEqc9E_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 485.0f, 0, m, &cBinop_5vdMlf4j_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cMsg_Qpq25b9Q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 10.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_5BmiZ0A7, HV_BINOP_POW, 0, m, &cBinop_5BmiZ0A7_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_5BmiZ0A7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_iHAFA5AY, 0, m, &cIf_iHAFA5AY_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_y1v6341Y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 20.0f, 0, m, &cBinop_qHSW8gKK_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_FONckFoe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_kHGKfNqa, 0, m, &cIf_kHGKfNqa_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_ds5TGmZ3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_vWCuYdrn_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_vWCuYdrn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_kHGKfNqa, 1, m, &cIf_kHGKfNqa_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_5vdMlf4j_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 100.0f, 0, m, &cBinop_y1v6341Y_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_6SCEqc9E_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_iHAFA5AY, 0, m, &cIf_iHAFA5AY_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_qHSW8gKK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_5BmiZ0A7, HV_BINOP_POW, 1, m, &cBinop_5BmiZ0A7_sendMessage);
  cMsg_Qpq25b9Q_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cIf_iHAFA5AY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      sVarf_onMessage(_c, &Context(_c)->sVarf_B5voVTaw, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cBinop_6tqwYqAI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_7uPFdJjW, 1, m, &cIf_7uPFdJjW_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_JXmhKcR2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_ECxwfRV9, HV_BINOP_GREATER_THAN, 1, m, &cBinop_ECxwfRV9_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_ikPzBPKm, HV_BINOP_EQ, 1, m, &cBinop_ikPzBPKm_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_WOZOdWfe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_JIbmVMGy, HV_BINOP_ADD, 0, m, &cBinop_JIbmVMGy_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_JIbmVMGy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_ds5TGmZ3_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_FONckFoe_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_ECxwfRV9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_iHAFA5AY, 1, m, &cIf_iHAFA5AY_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_ikPzBPKm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_24rvWub9_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cMsg_24rvWub9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  sVarf_onMessage(_c, &Context(_c)->sVarf_B5voVTaw, m);
}

void Heavy_WSTD_DL3Y::cCast_CNYnHq3B_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_JIbmVMGy, HV_BINOP_ADD, 1, m, &cBinop_JIbmVMGy_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_ECxwfRV9, HV_BINOP_GREATER_THAN, 0, m, &cBinop_ECxwfRV9_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_ikPzBPKm, HV_BINOP_EQ, 0, m, &cBinop_ikPzBPKm_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_CM4syyST_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_p04F4Mlz, 0, m, &cVar_p04F4Mlz_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_pQlRLWsr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_WOZOdWfe_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cVar_mPZrHPlA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_mAeJT6Hv_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_YW1OLzGs, 0, m, &cIf_YW1OLzGs_sendMessage);
}

void Heavy_WSTD_DL3Y::cIf_YW1OLzGs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_u7xt3Kn9_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cIf_9uiy8oWz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_YKxSDnNr_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 485.0f, 0, m, &cBinop_0CI7XbAN_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cMsg_nYEZTbZH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 10.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_QFYUE18v, HV_BINOP_POW, 0, m, &cBinop_QFYUE18v_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_QFYUE18v_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_eJz3uBfC, 0, m, &cIf_eJz3uBfC_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_qqPOxlOF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 20.0f, 0, m, &cBinop_n4CKyPlZ_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_9NqtWja4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_9uiy8oWz, 0, m, &cIf_9uiy8oWz_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_Y9XVKujN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_oBTiMJJb_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_oBTiMJJb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_9uiy8oWz, 1, m, &cIf_9uiy8oWz_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_0CI7XbAN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 100.0f, 0, m, &cBinop_qqPOxlOF_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_YKxSDnNr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_eJz3uBfC, 0, m, &cIf_eJz3uBfC_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_n4CKyPlZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_QFYUE18v, HV_BINOP_POW, 1, m, &cBinop_QFYUE18v_sendMessage);
  cMsg_nYEZTbZH_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cIf_eJz3uBfC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_04i9nfIO_sendMessage);
      cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_21QLNiIE_sendMessage);
      cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 0.0313f, 0, m, &cBinop_KBYO68J9_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cBinop_mAeJT6Hv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_YW1OLzGs, 1, m, &cIf_YW1OLzGs_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_u7xt3Kn9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_wo6trCyy, HV_BINOP_GREATER_THAN, 1, m, &cBinop_wo6trCyy_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_4IcFkJue, HV_BINOP_EQ, 1, m, &cBinop_4IcFkJue_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_5nHyXtfE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_Ef8KsS5z, HV_BINOP_ADD, 0, m, &cBinop_Ef8KsS5z_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_Ef8KsS5z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Y9XVKujN_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_9NqtWja4_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_wo6trCyy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_eJz3uBfC, 1, m, &cIf_eJz3uBfC_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_4IcFkJue_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_ASe8aEAw_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cMsg_ASe8aEAw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_04i9nfIO_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_21QLNiIE_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 0.0313f, 0, m, &cBinop_KBYO68J9_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_vaNngLpu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Ef8KsS5z, HV_BINOP_ADD, 1, m, &cBinop_Ef8KsS5z_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_wo6trCyy, HV_BINOP_GREATER_THAN, 0, m, &cBinop_wo6trCyy_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_4IcFkJue, HV_BINOP_EQ, 0, m, &cBinop_4IcFkJue_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_Ga9aeSqU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_mPZrHPlA, 0, m, &cVar_mPZrHPlA_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_81O73lrT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_5nHyXtfE_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cVar_GduW3tXB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_qd7ASYjl_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_MtiKp0FK, 0, m, &cIf_MtiKp0FK_sendMessage);
}

void Heavy_WSTD_DL3Y::cIf_MtiKp0FK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_3eRIZR0I_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cIf_vNXMo38n_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_LG6SIYiL_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 485.0f, 0, m, &cBinop_bzh83CEr_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cMsg_x8rwwqZb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 10.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_qAtlo54T, HV_BINOP_POW, 0, m, &cBinop_qAtlo54T_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_qAtlo54T_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_5Uh0wf6P, 0, m, &cIf_5Uh0wf6P_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_qofwqcYN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 20.0f, 0, m, &cBinop_cWcYnnQI_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_EAIkSh4K_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_vNXMo38n, 0, m, &cIf_vNXMo38n_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_m96PjL5o_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_ScRu1eL5_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_ScRu1eL5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_vNXMo38n, 1, m, &cIf_vNXMo38n_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_bzh83CEr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 100.0f, 0, m, &cBinop_qofwqcYN_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_LG6SIYiL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_5Uh0wf6P, 0, m, &cIf_5Uh0wf6P_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_cWcYnnQI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_qAtlo54T, HV_BINOP_POW, 1, m, &cBinop_qAtlo54T_sendMessage);
  cMsg_x8rwwqZb_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cIf_5Uh0wf6P_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      sVarf_onMessage(_c, &Context(_c)->sVarf_WsH2Fj1A, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cBinop_qd7ASYjl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_MtiKp0FK, 1, m, &cIf_MtiKp0FK_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_3eRIZR0I_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_fM8JOhB0, HV_BINOP_GREATER_THAN, 1, m, &cBinop_fM8JOhB0_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_ac5lbwC6, HV_BINOP_EQ, 1, m, &cBinop_ac5lbwC6_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_TBFnHBXa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_6nNCdaqT, HV_BINOP_ADD, 0, m, &cBinop_6nNCdaqT_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_6nNCdaqT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_m96PjL5o_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_EAIkSh4K_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_fM8JOhB0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_5Uh0wf6P, 1, m, &cIf_5Uh0wf6P_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_ac5lbwC6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_tGGPl2ix_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cMsg_tGGPl2ix_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  sVarf_onMessage(_c, &Context(_c)->sVarf_WsH2Fj1A, m);
}

void Heavy_WSTD_DL3Y::cCast_PrcC6E73_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_6nNCdaqT, HV_BINOP_ADD, 1, m, &cBinop_6nNCdaqT_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_fM8JOhB0, HV_BINOP_GREATER_THAN, 0, m, &cBinop_fM8JOhB0_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_ac5lbwC6, HV_BINOP_EQ, 0, m, &cBinop_ac5lbwC6_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_aD1fRhhh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_GduW3tXB, 0, m, &cVar_GduW3tXB_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_ro1HN8Vj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_TBFnHBXa_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cIf_QRC5EdWI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      sVarf_onMessage(_c, &Context(_c)->sVarf_lCe4YhGH, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cSwitchcase_Amd4Up9p_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x58220DA4: { // "highvol"
      cSlice_onMessage(_c, &Context(_c)->cSlice_NjFioaOG, 0, m, &cSlice_NjFioaOG_sendMessage);
      break;
    }
    default: {
      cSwitchcase_wYicThMz_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_DL3Y::cSlice_NjFioaOG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_UGJ5eMi6_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_UGJ5eMi6_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cVar_RIr92EVA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_UGJ5eMi6_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSend_UGJ5eMi6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_AmcmQOld_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSwitchcase_wYicThMz_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xBDABF734: { // "midvol"
      cSlice_onMessage(_c, &Context(_c)->cSlice_fy92pdSO, 0, m, &cSlice_fy92pdSO_sendMessage);
      break;
    }
    default: {
      cSwitchcase_aO3T8oW5_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_DL3Y::cSlice_fy92pdSO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_F3zZgCAW_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_F3zZgCAW_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cVar_UZMfdMEz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_F3zZgCAW_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSend_F3zZgCAW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_zn8Hzm46_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSwitchcase_HnQPKVZG_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x1FF74688: { // "lowvol"
      cSlice_onMessage(_c, &Context(_c)->cSlice_TlpGHYYK, 0, m, &cSlice_TlpGHYYK_sendMessage);
      break;
    }
    default: {
      cSwitchcase_WlZsqVFV_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_DL3Y::cSlice_TlpGHYYK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_GMBfH1Cs_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_GMBfH1Cs_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cVar_brksgLME_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_GMBfH1Cs_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSend_GMBfH1Cs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_XPf1l4OY_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSwitchcase_WlZsqVFV_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x98D37786: { // "midq"
      cSlice_onMessage(_c, &Context(_c)->cSlice_qq182tn0, 0, m, &cSlice_qq182tn0_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_DL3Y::cSlice_qq182tn0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_0NxCSoeC_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_0NxCSoeC_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cVar_ZDCxYx3o_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_0NxCSoeC_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSend_0NxCSoeC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_KNUZbcmp_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cMsg_P2SKXXGn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_tjfMe9MM, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_6VbMOdk4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_JszJzhD3, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_Ko7RQfsd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_1cY06L9c, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_4Y3Q4wqq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_odFAHwqt, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_Hy9jj2xl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_OADUECBA, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_6ES6gOO3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_VbfnVDdo_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_VbfnVDdo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_eABtQfiN, HV_BINOP_DIVIDE, 1, m, &cBinop_eABtQfiN_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_gJVfX1AB_sendMessage);
}

void Heavy_WSTD_DL3Y::cUnop_tM3IRDKL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 8.0f, 0, m, &cBinop_n1JsgbN2_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_AU1nt1RL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cUnop_onMessage(_c, HV_UNOP_ATAN, m, &cUnop_tM3IRDKL_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_n1JsgbN2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_eABtQfiN, HV_BINOP_DIVIDE, 0, m, &cBinop_eABtQfiN_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_gJVfX1AB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_AU1nt1RL_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_eABtQfiN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_fZIx0FAn, HV_BINOP_MULTIPLY, 1, m, &cBinop_fZIx0FAn_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_fZIx0FAn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Fb6HHQZB_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_8oaDBAX9_sendMessage);
}

void Heavy_WSTD_DL3Y::cUnop_xxXFY0w1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_ToVau5c0_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cUnop_zi5OcSDQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_yYkjWGqD_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_mSKQ7Azd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 20.0f, 0, m, &cBinop_B1XhOHAB_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_B1XhOHAB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_fZIx0FAn, HV_BINOP_MULTIPLY, 0, m, &cBinop_fZIx0FAn_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_VuocJpIW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.1f, 0, m, &cBinop_eubsh6nq_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_eubsh6nq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_ur6g4fbv_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_giNEn7A4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_xT1lZ4YB, 1, m, &cVar_xT1lZ4YB_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_xT1lZ4YB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_ZEvuMoJh_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_zYMgR65U_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_3lMhlDRi, HV_BINOP_MULTIPLY, 1, m, &cBinop_3lMhlDRi_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_wWpu8Kf8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_zYMgR65U_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_Txp41rW8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_GeECznFq_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_GeECznFq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_MfDdsGy0, HV_BINOP_MULTIPLY, 1, m, &cBinop_MfDdsGy0_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_8V4Asffc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_ntowPjob, HV_BINOP_MULTIPLY, 1, m, &cBinop_ntowPjob_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_VcPMgCJS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_8V4Asffc_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_fAcZqEYY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_yzdYPL6U, HV_BINOP_MULTIPLY, 1, m, &cBinop_yzdYPL6U_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_lTxwcg08_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_JS3rhGO2_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_JS3rhGO2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_bB0QW9ZW, HV_BINOP_MULTIPLY, 1, m, &cBinop_bB0QW9ZW_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_ZfiLw1Az_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_0lSPy1hv_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 20000.0f, 0, m, &cBinop_mSKQ7Azd_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_rkTLpdD5_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_xoh9dAoS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_VuocJpIW_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_Fb6HHQZB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SIN, m, &cUnop_xxXFY0w1_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_8oaDBAX9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_COS, m, &cUnop_zi5OcSDQ_sendMessage);
}

void Heavy_WSTD_DL3Y::cSend_ToVau5c0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_XSYU8plZ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSend_yYkjWGqD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_TV0wocMk_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSend_GpIWvqDt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_gEJSWdty_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cMsg_ur6g4fbv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_IWvJ0ol5_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_IWvJ0ol5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Nq5h7LD2, HV_BINOP_MULTIPLY, 1, m, &cBinop_Nq5h7LD2_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_Nq5h7LD2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_iHbF6pTk_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_iHbF6pTk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_GpIWvqDt_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cMsg_ZEvuMoJh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_MQ9MLrzp_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_MQ9MLrzp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_U6OjZ4pP_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_pDBPlJtw_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_P4GHXid8_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_loj5QziJ_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_0DwsYMaz_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_hh7uEihg_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_3lMhlDRi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_P2SKXXGn_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_MfDdsGy0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_6VbMOdk4_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_ntowPjob_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Ko7RQfsd_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_yzdYPL6U_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_4Y3Q4wqq_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_bB0QW9ZW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Hy9jj2xl_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_rOYWB5KY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_ZfiLw1Az, 0, m, &cVar_ZfiLw1Az_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_6JDfuVbU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_xoh9dAoS, 1, m, &cVar_xoh9dAoS_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_loj5QziJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_ntowPjob, HV_BINOP_MULTIPLY, 0, m, &cBinop_ntowPjob_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_U6OjZ4pP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
}

void Heavy_WSTD_DL3Y::cCast_hh7uEihg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_3lMhlDRi, HV_BINOP_MULTIPLY, 0, m, &cBinop_3lMhlDRi_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_P4GHXid8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_yzdYPL6U, HV_BINOP_MULTIPLY, 0, m, &cBinop_yzdYPL6U_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_0DwsYMaz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_MfDdsGy0, HV_BINOP_MULTIPLY, 0, m, &cBinop_MfDdsGy0_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_pDBPlJtw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_bB0QW9ZW, HV_BINOP_MULTIPLY, 0, m, &cBinop_bB0QW9ZW_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_rkTLpdD5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_xT1lZ4YB, 0, m, &cVar_xT1lZ4YB_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_0lSPy1hv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_xoh9dAoS, 0, m, &cVar_xoh9dAoS_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_LLsrFfYr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_UzeoFWxP, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_EofSxJXR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_IQU3wBHz, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_GJ3C3hiQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_1LOJxDlL, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_29M7zStI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_yL4tFpa4, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_4mwT0bWP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_lmVR3uCF_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_lmVR3uCF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_K3jLt9ZZ, HV_BINOP_DIVIDE, 1, m, &cBinop_K3jLt9ZZ_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_8mH0KH90_sendMessage);
}

void Heavy_WSTD_DL3Y::cUnop_8RjwNSSQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 8.0f, 0, m, &cBinop_VhTmIS7t_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_ff3bEQXX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cUnop_onMessage(_c, HV_UNOP_ATAN, m, &cUnop_8RjwNSSQ_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_VhTmIS7t_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_K3jLt9ZZ, HV_BINOP_DIVIDE, 0, m, &cBinop_K3jLt9ZZ_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_8mH0KH90_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_ff3bEQXX_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_K3jLt9ZZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_QqrpqIHk, HV_BINOP_MULTIPLY, 1, m, &cBinop_QqrpqIHk_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_QqrpqIHk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_LRmUlnDc_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_L2uu7JWh_sendMessage);
}

void Heavy_WSTD_DL3Y::cUnop_5XeApl16_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_8ygDqGPi_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cUnop_9qED97ef_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_gcU2W8oG_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_OjCtCX35_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 20.0f, 0, m, &cBinop_q3piFEn5_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_q3piFEn5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_QqrpqIHk, HV_BINOP_MULTIPLY, 0, m, &cBinop_QqrpqIHk_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_bzgs0czI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.1f, 0, m, &cBinop_dfmCYKXu_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_dfmCYKXu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_sHHUVzb0_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_YurfGrt3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_G3XUiOR6, HV_BINOP_MULTIPLY, 1, m, &cBinop_G3XUiOR6_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_8nXgBrLd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_Ou1SW9Kg, 1, m, &cVar_Ou1SW9Kg_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_NewkBQfR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_eyGZil9v, HV_BINOP_MULTIPLY, 1, m, &cBinop_eyGZil9v_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_OZ5cl7l3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_5JstV3pD_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_5JstV3pD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_m9jm4EI2, HV_BINOP_MULTIPLY, 1, m, &cBinop_m9jm4EI2_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_Ou1SW9Kg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_YzqeNQAk_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cVar_xg37TT1N_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_tijCCL8t_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 20000.0f, 0, m, &cBinop_OjCtCX35_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_LXWmk2y3_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_WUJWUTk1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_bzgs0czI_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_L2uu7JWh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_COS, m, &cUnop_9qED97ef_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_LRmUlnDc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SIN, m, &cUnop_5XeApl16_sendMessage);
}

void Heavy_WSTD_DL3Y::cSend_8ygDqGPi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_tckQtwuy_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSend_gcU2W8oG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_bHuX3FnE_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSend_5mfDdmkn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_wCwVem92_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cMsg_sHHUVzb0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_Phsk8fdu_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_Phsk8fdu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_kI17YiMS, HV_BINOP_MULTIPLY, 1, m, &cBinop_kI17YiMS_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_kI17YiMS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_0mOUcnW2_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_0mOUcnW2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_5mfDdmkn_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cMsg_YzqeNQAk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_0uL4kzF2_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_0uL4kzF2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_JNwlD3XN_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_XgLjyqKB_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_XaYTxiXP_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_yO6CnOBR_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_kJrp69nj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_LLsrFfYr_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_G3XUiOR6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_EofSxJXR_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_eyGZil9v_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_GJ3C3hiQ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_m9jm4EI2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_29M7zStI_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_4kDXypRM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_WUJWUTk1, 1, m, &cVar_WUJWUTk1_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_iqSM28aH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_xg37TT1N, 0, m, &cVar_xg37TT1N_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_tijCCL8t_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_WUJWUTk1, 0, m, &cVar_WUJWUTk1_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_LXWmk2y3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_Ou1SW9Kg, 0, m, &cVar_Ou1SW9Kg_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_XgLjyqKB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_eyGZil9v, HV_BINOP_MULTIPLY, 0, m, &cBinop_eyGZil9v_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_yO6CnOBR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_kJrp69nj, HV_BINOP_MULTIPLY, 0, m, &cBinop_kJrp69nj_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_JNwlD3XN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_m9jm4EI2, HV_BINOP_MULTIPLY, 0, m, &cBinop_m9jm4EI2_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_XaYTxiXP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_G3XUiOR6, HV_BINOP_MULTIPLY, 0, m, &cBinop_G3XUiOR6_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_0TUD5lna_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_TX5FwKcn, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_3SllgfNt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_h0IeafQ6, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_LPjgePSG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_MOlsDCY7, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_MGM4CtlZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_8V9qDnPH, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_81OYEj0B_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_eKThul0W, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_t1v1n1Rn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_PmcGe76w_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_PmcGe76w_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_U0j64Xjt, HV_BINOP_DIVIDE, 1, m, &cBinop_U0j64Xjt_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_skxuOVYj_sendMessage);
}

void Heavy_WSTD_DL3Y::cUnop_BP4BlVmD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 8.0f, 0, m, &cBinop_Z6sJxaJp_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_cvCvYxJP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cUnop_onMessage(_c, HV_UNOP_ATAN, m, &cUnop_BP4BlVmD_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_Z6sJxaJp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_U0j64Xjt, HV_BINOP_DIVIDE, 0, m, &cBinop_U0j64Xjt_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_skxuOVYj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_cvCvYxJP_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_U0j64Xjt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_vmHY4wMU, HV_BINOP_MULTIPLY, 1, m, &cBinop_vmHY4wMU_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_vmHY4wMU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_LndRrlqB_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_bXj1uFgC_sendMessage);
}

void Heavy_WSTD_DL3Y::cUnop_f7oEU6Jq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_3OsemOEj_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cUnop_5r0xgdy6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_aug8PdSd_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_XHfXSrUl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 20.0f, 0, m, &cBinop_2L4BUQZT_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_2L4BUQZT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_vmHY4wMU, HV_BINOP_MULTIPLY, 0, m, &cBinop_vmHY4wMU_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_ZWVtYNoS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.1f, 0, m, &cBinop_bl7CBzOJ_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_bl7CBzOJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_YvbL7GYw_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_nzrAJIwc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_pOfo2KaY, HV_BINOP_MULTIPLY, 1, m, &cBinop_pOfo2KaY_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_EvHTMKEu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_3npfqrfH_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_3npfqrfH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_nzrAJIwc_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_8g09ynOl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_b9L4Td5Q_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_b9L4Td5Q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Lw63qwWk, HV_BINOP_MULTIPLY, 1, m, &cBinop_Lw63qwWk_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_je5AMUrU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_7bkaSXyg, HV_BINOP_MULTIPLY, 1, m, &cBinop_7bkaSXyg_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_mlyejNnr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_J3Vs5vVY_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_J3Vs5vVY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_je5AMUrU_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_lPXdikb1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_G7obZzs2, 1, m, &cVar_G7obZzs2_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_dX2V9rxQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_hvtHFVp5, HV_BINOP_MULTIPLY, 1, m, &cBinop_hvtHFVp5_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_He8rX0Jt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_XKBk8zZt_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_XKBk8zZt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_JtJobCu8, HV_BINOP_MULTIPLY, 1, m, &cBinop_JtJobCu8_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_G7obZzs2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_2fhmP4no_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cVar_eZ0ffdbI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_IcU5ahq8_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 20000.0f, 0, m, &cBinop_XHfXSrUl_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_pCRPgMvG_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_iAhlAYL8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_ZWVtYNoS_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_bXj1uFgC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_COS, m, &cUnop_5r0xgdy6_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_LndRrlqB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SIN, m, &cUnop_f7oEU6Jq_sendMessage);
}

void Heavy_WSTD_DL3Y::cSend_3OsemOEj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_7Howap1y_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSend_aug8PdSd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_PCs5kunQ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSend_pUO9C4hw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_4BmdDKkp_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cMsg_YvbL7GYw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_XcbmdOqr_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_XcbmdOqr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_CZOdrmYS, HV_BINOP_MULTIPLY, 1, m, &cBinop_CZOdrmYS_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_CZOdrmYS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_A2GYpp0a_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_A2GYpp0a_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_pUO9C4hw_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cMsg_2fhmP4no_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_bSL0JkZV_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_bSL0JkZV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_TQwmDbtF_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_cmD1czB3_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_tBlb18LN_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_aec7a3eV_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_g5FQu7VQ_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_8teVMRZL_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_pOfo2KaY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_0TUD5lna_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_Lw63qwWk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_3SllgfNt_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_7bkaSXyg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_LPjgePSG_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_hvtHFVp5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_MGM4CtlZ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_JtJobCu8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_81OYEj0B_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_1RHpAkHI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_eZ0ffdbI, 0, m, &cVar_eZ0ffdbI_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_iePVFtZV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_iAhlAYL8, 1, m, &cVar_iAhlAYL8_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_aec7a3eV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_7bkaSXyg, HV_BINOP_MULTIPLY, 0, m, &cBinop_7bkaSXyg_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_TQwmDbtF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
}

void Heavy_WSTD_DL3Y::cCast_8teVMRZL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_pOfo2KaY, HV_BINOP_MULTIPLY, 0, m, &cBinop_pOfo2KaY_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_tBlb18LN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_hvtHFVp5, HV_BINOP_MULTIPLY, 0, m, &cBinop_hvtHFVp5_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_g5FQu7VQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Lw63qwWk, HV_BINOP_MULTIPLY, 0, m, &cBinop_Lw63qwWk_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_cmD1czB3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_JtJobCu8, HV_BINOP_MULTIPLY, 0, m, &cBinop_JtJobCu8_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_pCRPgMvG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_G7obZzs2, 0, m, &cVar_G7obZzs2_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_IcU5ahq8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_iAhlAYL8, 0, m, &cVar_iAhlAYL8_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_04i9nfIO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_QRC5EdWI, 1, m, &cIf_QRC5EdWI_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_j0hqLkxv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  sVarf_onMessage(_c, &Context(_c)->sVarf_lCe4YhGH, m);
}

void Heavy_WSTD_DL3Y::cBinop_21QLNiIE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_j0hqLkxv_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_KBYO68J9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_QRC5EdWI, 0, m, &cIf_QRC5EdWI_sendMessage);
}

void Heavy_WSTD_DL3Y::cSwitchcase_v6SqH6re_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xE9AAC520: { // "midfreq"
      cSlice_onMessage(_c, &Context(_c)->cSlice_Q4L27Vtq, 0, m, &cSlice_Q4L27Vtq_sendMessage);
      break;
    }
    default: {
      cSwitchcase_2heqN2Me_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_DL3Y::cSlice_Q4L27Vtq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_6MiY3Sx2_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_6MiY3Sx2_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cVar_WGfMUszf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_6MiY3Sx2_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSend_6MiY3Sx2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_VaDMT3H0_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cVar_pwe93PqJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_mcVvtceE_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_oN9t3Tmk, 0, m, &cIf_oN9t3Tmk_sendMessage);
}

void Heavy_WSTD_DL3Y::cIf_oN9t3Tmk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_LKIT40pm_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cIf_nYs12wey_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_NRmtN0Kh_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 485.0f, 0, m, &cBinop_rlCiTyID_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cMsg_qvvF3JQ8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 10.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_Th5Bg8bu, HV_BINOP_POW, 0, m, &cBinop_Th5Bg8bu_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_Th5Bg8bu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_xcua7GcH, 0, m, &cIf_xcua7GcH_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_U5ZDopmT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 20.0f, 0, m, &cBinop_kG6ne4oD_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_2ZaiIWqA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_UpoCddcR_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_SK9TND7A_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_nYs12wey, 0, m, &cIf_nYs12wey_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_UpoCddcR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_nYs12wey, 1, m, &cIf_nYs12wey_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_rlCiTyID_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 100.0f, 0, m, &cBinop_U5ZDopmT_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_NRmtN0Kh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_xcua7GcH, 0, m, &cIf_xcua7GcH_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_kG6ne4oD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Th5Bg8bu, HV_BINOP_POW, 1, m, &cBinop_Th5Bg8bu_sendMessage);
  cMsg_qvvF3JQ8_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cIf_xcua7GcH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      sVarf_onMessage(_c, &Context(_c)->sVarf_6eWypeeA, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cBinop_mcVvtceE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_oN9t3Tmk, 1, m, &cIf_oN9t3Tmk_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_LKIT40pm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_LH1FCjnm, HV_BINOP_GREATER_THAN, 1, m, &cBinop_LH1FCjnm_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_fAnLej0i, HV_BINOP_EQ, 1, m, &cBinop_fAnLej0i_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_oy42ZhYK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_EysYsmYG, HV_BINOP_ADD, 0, m, &cBinop_EysYsmYG_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_EysYsmYG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_2ZaiIWqA_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_SK9TND7A_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_LH1FCjnm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_xcua7GcH, 1, m, &cIf_xcua7GcH_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_fAnLej0i_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_JeS4LOCN_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cMsg_JeS4LOCN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  sVarf_onMessage(_c, &Context(_c)->sVarf_6eWypeeA, m);
}

void Heavy_WSTD_DL3Y::cCast_PvyKmKBh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_pwe93PqJ, 0, m, &cVar_pwe93PqJ_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_YP4ZCnIR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_oy42ZhYK_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_BmrZrW5d_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_EysYsmYG, HV_BINOP_ADD, 1, m, &cBinop_EysYsmYG_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_LH1FCjnm, HV_BINOP_GREATER_THAN, 0, m, &cBinop_LH1FCjnm_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_fAnLej0i, HV_BINOP_EQ, 0, m, &cBinop_fAnLej0i_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_qkcK6T8f_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_62K5mdtb_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_Fsb3dljh, 0, m, &cIf_Fsb3dljh_sendMessage);
}

void Heavy_WSTD_DL3Y::cIf_Fsb3dljh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_ZQ7qS0vb_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cIf_ETkKcKu2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_amSUdbqM_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 485.0f, 0, m, &cBinop_Pt6zKTln_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cMsg_VogMTcVz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 10.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_Sxe1Rne9, HV_BINOP_POW, 0, m, &cBinop_Sxe1Rne9_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_Sxe1Rne9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_4xXuUCLU, 0, m, &cIf_4xXuUCLU_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_9AVQ5U1l_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 20.0f, 0, m, &cBinop_vfDGTggt_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_g5AeaU4a_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_GA9C4Dzc_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_LfYfjNpg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_ETkKcKu2, 0, m, &cIf_ETkKcKu2_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_GA9C4Dzc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_ETkKcKu2, 1, m, &cIf_ETkKcKu2_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_Pt6zKTln_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 100.0f, 0, m, &cBinop_9AVQ5U1l_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_amSUdbqM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_4xXuUCLU, 0, m, &cIf_4xXuUCLU_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_vfDGTggt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Sxe1Rne9, HV_BINOP_POW, 1, m, &cBinop_Sxe1Rne9_sendMessage);
  cMsg_VogMTcVz_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cIf_4xXuUCLU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_hNwxmHDn_sendMessage);
      cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_WCqfN2iF_sendMessage);
      cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 0.0313f, 0, m, &cBinop_bK0wJc3t_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cBinop_62K5mdtb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_Fsb3dljh, 1, m, &cIf_Fsb3dljh_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_ZQ7qS0vb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Lu3GglP0, HV_BINOP_GREATER_THAN, 1, m, &cBinop_Lu3GglP0_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_pDDQ1mmP, HV_BINOP_EQ, 1, m, &cBinop_pDDQ1mmP_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_TlSIMdiQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_UYZBWfaN, HV_BINOP_ADD, 0, m, &cBinop_UYZBWfaN_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_UYZBWfaN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_g5AeaU4a_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_LfYfjNpg_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_Lu3GglP0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_4xXuUCLU, 1, m, &cIf_4xXuUCLU_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_pDDQ1mmP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_yTcAVMDg_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cMsg_yTcAVMDg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_hNwxmHDn_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_WCqfN2iF_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 0.0313f, 0, m, &cBinop_bK0wJc3t_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_TdyOeeA1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_TlSIMdiQ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_pm2qkVoh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_UYZBWfaN, HV_BINOP_ADD, 1, m, &cBinop_UYZBWfaN_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_Lu3GglP0, HV_BINOP_GREATER_THAN, 0, m, &cBinop_Lu3GglP0_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_pDDQ1mmP, HV_BINOP_EQ, 0, m, &cBinop_pDDQ1mmP_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_1ehz1sNW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_qkcK6T8f, 0, m, &cVar_qkcK6T8f_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_N3ZDDLnB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_GbU3DVlG_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_Lv5EeKne, 0, m, &cIf_Lv5EeKne_sendMessage);
}

void Heavy_WSTD_DL3Y::cIf_Lv5EeKne_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_LjDwRtD3_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cIf_2br6tstG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_eRl82LFV_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 485.0f, 0, m, &cBinop_lbb0T3T8_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cMsg_A6caho9V_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 10.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_vbI4yZXw, HV_BINOP_POW, 0, m, &cBinop_vbI4yZXw_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_vbI4yZXw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_P8Yr9PST, 0, m, &cIf_P8Yr9PST_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_RjzzMYqE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 20.0f, 0, m, &cBinop_tn5r2XRJ_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_bl6BIIwL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_dCqLnh8R_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_mTIJmFKd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_2br6tstG, 0, m, &cIf_2br6tstG_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_dCqLnh8R_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_2br6tstG, 1, m, &cIf_2br6tstG_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_lbb0T3T8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 100.0f, 0, m, &cBinop_RjzzMYqE_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_eRl82LFV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_P8Yr9PST, 0, m, &cIf_P8Yr9PST_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_tn5r2XRJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_vbI4yZXw, HV_BINOP_POW, 1, m, &cBinop_vbI4yZXw_sendMessage);
  cMsg_A6caho9V_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cIf_P8Yr9PST_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      sVarf_onMessage(_c, &Context(_c)->sVarf_GtLHt4EO, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cBinop_GbU3DVlG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_Lv5EeKne, 1, m, &cIf_Lv5EeKne_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_LjDwRtD3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_FG8yUNHh, HV_BINOP_GREATER_THAN, 1, m, &cBinop_FG8yUNHh_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_I6UscKDt, HV_BINOP_EQ, 1, m, &cBinop_I6UscKDt_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_c14YYoAa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_V0wcLLzw, HV_BINOP_ADD, 0, m, &cBinop_V0wcLLzw_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_V0wcLLzw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_bl6BIIwL_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_mTIJmFKd_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_FG8yUNHh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_P8Yr9PST, 1, m, &cIf_P8Yr9PST_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_I6UscKDt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_FM51oY23_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cMsg_FM51oY23_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  sVarf_onMessage(_c, &Context(_c)->sVarf_GtLHt4EO, m);
}

void Heavy_WSTD_DL3Y::cCast_IKU40CNa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_N3ZDDLnB, 0, m, &cVar_N3ZDDLnB_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_LkW8Gvby_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_c14YYoAa_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_zsZm9StH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_V0wcLLzw, HV_BINOP_ADD, 1, m, &cBinop_V0wcLLzw_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_FG8yUNHh, HV_BINOP_GREATER_THAN, 0, m, &cBinop_FG8yUNHh_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_I6UscKDt, HV_BINOP_EQ, 0, m, &cBinop_I6UscKDt_sendMessage);
}

void Heavy_WSTD_DL3Y::cIf_DNjaXpKc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      sVarf_onMessage(_c, &Context(_c)->sVarf_QiLGSnW6, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cSwitchcase_YIA9jJ1e_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x58220DA4: { // "highvol"
      cSlice_onMessage(_c, &Context(_c)->cSlice_9VovVso8, 0, m, &cSlice_9VovVso8_sendMessage);
      break;
    }
    default: {
      cSwitchcase_HPNZHwBD_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_DL3Y::cSlice_9VovVso8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_DmixhLzz_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_DmixhLzz_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cVar_1oFbqSzK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_DmixhLzz_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSend_DmixhLzz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_rR0BErhZ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSwitchcase_HPNZHwBD_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xBDABF734: { // "midvol"
      cSlice_onMessage(_c, &Context(_c)->cSlice_lVK46kvI, 0, m, &cSlice_lVK46kvI_sendMessage);
      break;
    }
    default: {
      cSwitchcase_v6SqH6re_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_DL3Y::cSlice_lVK46kvI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_XOZM2Y86_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_XOZM2Y86_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cVar_LECxQEL8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_XOZM2Y86_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSend_XOZM2Y86_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_ClgD7JLd_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSwitchcase_2heqN2Me_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x1FF74688: { // "lowvol"
      cSlice_onMessage(_c, &Context(_c)->cSlice_jndiSF42, 0, m, &cSlice_jndiSF42_sendMessage);
      break;
    }
    default: {
      cSwitchcase_prvl1Mc8_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_DL3Y::cSlice_jndiSF42_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_qdgvfuJn_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_qdgvfuJn_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cVar_Rzf9ZZA3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_qdgvfuJn_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSend_qdgvfuJn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_lFGs1qrT_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSwitchcase_prvl1Mc8_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x98D37786: { // "midq"
      cSlice_onMessage(_c, &Context(_c)->cSlice_jAQittxU, 0, m, &cSlice_jAQittxU_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_DL3Y::cSlice_jAQittxU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_e5J6PUor_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_e5J6PUor_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cVar_ob9UE0Ca_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_e5J6PUor_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSend_e5J6PUor_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_b4NkUvVP_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cMsg_5pzwYIYK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_e4l34zLo, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_GgqzvyJS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_74OVcwmx, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_zciJSMwW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_DmJbhTzl, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_CeUuvO6r_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_IoxMYnli, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_98B2g8du_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_8wRhMg5R, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_Y9CAuthn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_U9BY3aND_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_U9BY3aND_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_fCNng0nv, HV_BINOP_DIVIDE, 1, m, &cBinop_fCNng0nv_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_C18PRrXS_sendMessage);
}

void Heavy_WSTD_DL3Y::cUnop_9KuEP8nX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 8.0f, 0, m, &cBinop_wnehvfWd_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_3G7eJulW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cUnop_onMessage(_c, HV_UNOP_ATAN, m, &cUnop_9KuEP8nX_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_wnehvfWd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_fCNng0nv, HV_BINOP_DIVIDE, 0, m, &cBinop_fCNng0nv_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_C18PRrXS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_3G7eJulW_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_fCNng0nv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Se6xbuK6, HV_BINOP_MULTIPLY, 1, m, &cBinop_Se6xbuK6_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_Se6xbuK6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Tij5ZFpm_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_DN3jodtJ_sendMessage);
}

void Heavy_WSTD_DL3Y::cUnop_PdugZJon_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_tQIMW4vj_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cUnop_5Mef4xH0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_QGfBDEgD_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_mTilJwdd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 20.0f, 0, m, &cBinop_6mO8LImS_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_6mO8LImS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Se6xbuK6, HV_BINOP_MULTIPLY, 0, m, &cBinop_Se6xbuK6_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_etBaBLAw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.1f, 0, m, &cBinop_ONYOX95e_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_ONYOX95e_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_RxTSGNns_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_UqgHXaXv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_gKSe4JZ5, 1, m, &cVar_gKSe4JZ5_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_gKSe4JZ5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_NgDY1bmL_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_TigF4VEg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_9FVKRNur, HV_BINOP_MULTIPLY, 1, m, &cBinop_9FVKRNur_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_HQyGWfHH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_TigF4VEg_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_P4CfTBKH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_C24p10hE_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_C24p10hE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_QeYYQh5B, HV_BINOP_MULTIPLY, 1, m, &cBinop_QeYYQh5B_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_Yxok4s7c_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_t5h3xhxt, HV_BINOP_MULTIPLY, 1, m, &cBinop_t5h3xhxt_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_wyVZyaiT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_Yxok4s7c_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_iYpRLzNu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_WgujFuwL, HV_BINOP_MULTIPLY, 1, m, &cBinop_WgujFuwL_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_izeJwmCt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_mJ1dawPy_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_mJ1dawPy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_791HvfbQ, HV_BINOP_MULTIPLY, 1, m, &cBinop_791HvfbQ_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_sQ0Mn5p5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_cHCgAw6U_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 20000.0f, 0, m, &cBinop_mTilJwdd_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_leqZEw8k_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_lHb4owyq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_etBaBLAw_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_Tij5ZFpm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SIN, m, &cUnop_PdugZJon_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_DN3jodtJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_COS, m, &cUnop_5Mef4xH0_sendMessage);
}

void Heavy_WSTD_DL3Y::cSend_tQIMW4vj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_QEadFXLQ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSend_QGfBDEgD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_9ZHmxuev_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSend_P4P6ekcn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_Jr9PoLQS_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cMsg_RxTSGNns_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_B7vkKgAb_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_B7vkKgAb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_6IsKqxwJ, HV_BINOP_MULTIPLY, 1, m, &cBinop_6IsKqxwJ_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_6IsKqxwJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_3hNqTtLr_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_3hNqTtLr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_P4P6ekcn_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cMsg_NgDY1bmL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_DLgGB72H_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_DLgGB72H_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_acnNZA3H_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_ySNCRKKt_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_68nuYUJc_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_tpy6nCwy_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_QPm5oIAv_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_3xYzpHEN_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_9FVKRNur_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_5pzwYIYK_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_QeYYQh5B_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_GgqzvyJS_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_t5h3xhxt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_zciJSMwW_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_WgujFuwL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_CeUuvO6r_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_791HvfbQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_98B2g8du_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_YJfr5boN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_sQ0Mn5p5, 0, m, &cVar_sQ0Mn5p5_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_71jaPLpA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_lHb4owyq, 1, m, &cVar_lHb4owyq_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_3xYzpHEN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_9FVKRNur, HV_BINOP_MULTIPLY, 0, m, &cBinop_9FVKRNur_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_tpy6nCwy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_t5h3xhxt, HV_BINOP_MULTIPLY, 0, m, &cBinop_t5h3xhxt_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_acnNZA3H_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
}

void Heavy_WSTD_DL3Y::cCast_QPm5oIAv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_QeYYQh5B, HV_BINOP_MULTIPLY, 0, m, &cBinop_QeYYQh5B_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_68nuYUJc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_WgujFuwL, HV_BINOP_MULTIPLY, 0, m, &cBinop_WgujFuwL_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_ySNCRKKt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_791HvfbQ, HV_BINOP_MULTIPLY, 0, m, &cBinop_791HvfbQ_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_leqZEw8k_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_gKSe4JZ5, 0, m, &cVar_gKSe4JZ5_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_cHCgAw6U_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_lHb4owyq, 0, m, &cVar_lHb4owyq_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_2xVFWEdL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_WSbGCUen, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_qjqNIMkf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_aiG7Wo9E, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_MrhKAQv9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_GCNwH7nM, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_bH4m3Bv8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_uWJ4q7ai, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_FBuYZNZB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_6ybEZEtO_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_6ybEZEtO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_ulgFWccZ, HV_BINOP_DIVIDE, 1, m, &cBinop_ulgFWccZ_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_6fQHw7Fy_sendMessage);
}

void Heavy_WSTD_DL3Y::cUnop_hlRQhWYx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 8.0f, 0, m, &cBinop_XohgFluO_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_ML1Mfp8j_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cUnop_onMessage(_c, HV_UNOP_ATAN, m, &cUnop_hlRQhWYx_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_XohgFluO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_ulgFWccZ, HV_BINOP_DIVIDE, 0, m, &cBinop_ulgFWccZ_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_6fQHw7Fy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_ML1Mfp8j_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_ulgFWccZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_yaFruEEd, HV_BINOP_MULTIPLY, 1, m, &cBinop_yaFruEEd_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_yaFruEEd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_RIGFLDkC_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_MqfNNgXU_sendMessage);
}

void Heavy_WSTD_DL3Y::cUnop_xC5DG9l6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_j3lsCdTy_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cUnop_FVervmh5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_6BqZ4Gwq_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_wkBhR1MN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 20.0f, 0, m, &cBinop_1oC9KUgV_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_1oC9KUgV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_yaFruEEd, HV_BINOP_MULTIPLY, 0, m, &cBinop_yaFruEEd_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_GzSoVAaj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.1f, 0, m, &cBinop_KjuSg5MJ_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_KjuSg5MJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_F3BUZLHf_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_VQtpWLPA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_9HARUeHK, HV_BINOP_MULTIPLY, 1, m, &cBinop_9HARUeHK_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_h4qUCRqY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_BDrKMkJF, 1, m, &cVar_BDrKMkJF_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_j3tqZgxb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_tPy92p9v, HV_BINOP_MULTIPLY, 1, m, &cBinop_tPy92p9v_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_L4bQmfDt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_gV026sTz_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_gV026sTz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_wmrEmbys, HV_BINOP_MULTIPLY, 1, m, &cBinop_wmrEmbys_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_BDrKMkJF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Mzq5og3D_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cVar_QhKAWvsg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_XT3pWuSD_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 20000.0f, 0, m, &cBinop_wkBhR1MN_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_bCCNxcP8_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_GuDBhog1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_GzSoVAaj_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_MqfNNgXU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_COS, m, &cUnop_FVervmh5_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_RIGFLDkC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SIN, m, &cUnop_xC5DG9l6_sendMessage);
}

void Heavy_WSTD_DL3Y::cSend_j3lsCdTy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_DVuiQCqz_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSend_6BqZ4Gwq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_bHLlHYrN_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSend_fqVBdgQV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_vHn8kUZN_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cMsg_F3BUZLHf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_NPM3v5c9_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_NPM3v5c9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_zUL40tdL, HV_BINOP_MULTIPLY, 1, m, &cBinop_zUL40tdL_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_zUL40tdL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_F1dhIjRF_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_F1dhIjRF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_fqVBdgQV_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cMsg_Mzq5og3D_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_OSFn2094_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_OSFn2094_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_3BBiFmAG_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_NRFoMqH8_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_F2nTVEtC_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_STg7wDer_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_zYbTzzYB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_2xVFWEdL_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_9HARUeHK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_qjqNIMkf_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_tPy92p9v_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_MrhKAQv9_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_wmrEmbys_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_bH4m3Bv8_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_w6gifh4V_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_GuDBhog1, 1, m, &cVar_GuDBhog1_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_q5iXHNv5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_QhKAWvsg, 0, m, &cVar_QhKAWvsg_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_XT3pWuSD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_GuDBhog1, 0, m, &cVar_GuDBhog1_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_bCCNxcP8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_BDrKMkJF, 0, m, &cVar_BDrKMkJF_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_NRFoMqH8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_tPy92p9v, HV_BINOP_MULTIPLY, 0, m, &cBinop_tPy92p9v_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_STg7wDer_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_zYbTzzYB, HV_BINOP_MULTIPLY, 0, m, &cBinop_zYbTzzYB_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_3BBiFmAG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_wmrEmbys, HV_BINOP_MULTIPLY, 0, m, &cBinop_wmrEmbys_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_F2nTVEtC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_9HARUeHK, HV_BINOP_MULTIPLY, 0, m, &cBinop_9HARUeHK_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_d3E6Opke_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_FkpjCQMp, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_QyriHgGq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_QfM97MBT, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_r8pKlpdj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_ynWr6gfT, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_3UeDzqJv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_GhL00Fps, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_EcaZFNEI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_gF7VB4kZ, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_9CzImQ3O_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_ek7wDVCa_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_ek7wDVCa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_HzWfJH3S, HV_BINOP_DIVIDE, 1, m, &cBinop_HzWfJH3S_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_ddYi34Od_sendMessage);
}

void Heavy_WSTD_DL3Y::cUnop_eez5v8wj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 8.0f, 0, m, &cBinop_LtvLGatF_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_60lGQRca_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cUnop_onMessage(_c, HV_UNOP_ATAN, m, &cUnop_eez5v8wj_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_LtvLGatF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_HzWfJH3S, HV_BINOP_DIVIDE, 0, m, &cBinop_HzWfJH3S_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_ddYi34Od_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_60lGQRca_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_HzWfJH3S_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_yEgs45cU, HV_BINOP_MULTIPLY, 1, m, &cBinop_yEgs45cU_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_yEgs45cU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_7FeCpKrP_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_aEDZlOzA_sendMessage);
}

void Heavy_WSTD_DL3Y::cUnop_guRYSUOe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_GTARTh7J_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cUnop_IetReaHY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_EP5Zls2C_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_0nGqmXyy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 20.0f, 0, m, &cBinop_QyudTxEf_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_QyudTxEf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_yEgs45cU, HV_BINOP_MULTIPLY, 0, m, &cBinop_yEgs45cU_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_5X5fctOB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.1f, 0, m, &cBinop_6QIT4pif_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_6QIT4pif_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_tC7KObPB_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_m6SJQv3S_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_UG0YmsRq, HV_BINOP_MULTIPLY, 1, m, &cBinop_UG0YmsRq_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_kS8PDLiy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_nR1huEqa_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_nR1huEqa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_m6SJQv3S_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_9ldVb87g_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_ClZsLNE9_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_ClZsLNE9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_yhMzCCcv, HV_BINOP_MULTIPLY, 1, m, &cBinop_yhMzCCcv_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_xUtxdSRp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_h73UZXW5, HV_BINOP_MULTIPLY, 1, m, &cBinop_h73UZXW5_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_ElG0Rcu9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_XDkE9Njr_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_XDkE9Njr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_xUtxdSRp_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_qOi5ofqH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_8FaHJs76, 1, m, &cVar_8FaHJs76_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_Xt7U4IDL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_KhDvGpim, HV_BINOP_MULTIPLY, 1, m, &cBinop_KhDvGpim_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_cFQ2Yn1j_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_8wxtAM6l_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_8wxtAM6l_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_1LeuviZ4, HV_BINOP_MULTIPLY, 1, m, &cBinop_1LeuviZ4_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_8FaHJs76_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_pKdMCsJD_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cVar_JtZDGlrz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_ONb7AzAu_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 20000.0f, 0, m, &cBinop_0nGqmXyy_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_mWfWdjw9_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_eLTp1060_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_5X5fctOB_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_aEDZlOzA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_COS, m, &cUnop_IetReaHY_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_7FeCpKrP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SIN, m, &cUnop_guRYSUOe_sendMessage);
}

void Heavy_WSTD_DL3Y::cSend_GTARTh7J_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_deQuS1az_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSend_EP5Zls2C_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_9yWBWtPf_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSend_1LwwbaBd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_ObnoyJWH_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cMsg_tC7KObPB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_mhJJKCuO_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_mhJJKCuO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_OMghttiD, HV_BINOP_MULTIPLY, 1, m, &cBinop_OMghttiD_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_OMghttiD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_37xY3oT5_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_37xY3oT5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_1LwwbaBd_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cMsg_pKdMCsJD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_5CuwV762_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_5CuwV762_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_JuQirufp_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_sCJb8IfY_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_XXdKXvID_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_rdk4NxzP_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_hs6NmVcV_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_BFTdzTkE_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_UG0YmsRq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_d3E6Opke_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_yhMzCCcv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_QyriHgGq_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_h73UZXW5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_r8pKlpdj_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_KhDvGpim_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_3UeDzqJv_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_1LeuviZ4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_EcaZFNEI_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_MlbBOHJw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_JtZDGlrz, 0, m, &cVar_JtZDGlrz_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_AqHfVvDa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_eLTp1060, 1, m, &cVar_eLTp1060_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_rdk4NxzP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_h73UZXW5, HV_BINOP_MULTIPLY, 0, m, &cBinop_h73UZXW5_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_JuQirufp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
}

void Heavy_WSTD_DL3Y::cCast_BFTdzTkE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_UG0YmsRq, HV_BINOP_MULTIPLY, 0, m, &cBinop_UG0YmsRq_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_XXdKXvID_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_KhDvGpim, HV_BINOP_MULTIPLY, 0, m, &cBinop_KhDvGpim_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_hs6NmVcV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_yhMzCCcv, HV_BINOP_MULTIPLY, 0, m, &cBinop_yhMzCCcv_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_sCJb8IfY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_1LeuviZ4, HV_BINOP_MULTIPLY, 0, m, &cBinop_1LeuviZ4_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_mWfWdjw9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_8FaHJs76, 0, m, &cVar_8FaHJs76_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_ONb7AzAu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_eLTp1060, 0, m, &cVar_eLTp1060_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_hNwxmHDn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_DNjaXpKc, 1, m, &cIf_DNjaXpKc_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_A4p1sVqU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  sVarf_onMessage(_c, &Context(_c)->sVarf_QiLGSnW6, m);
}

void Heavy_WSTD_DL3Y::cBinop_WCqfN2iF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_A4p1sVqU_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_bK0wJc3t_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_DNjaXpKc, 0, m, &cIf_DNjaXpKc_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_dHQVFpkQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_TYFKHpmx, HV_BINOP_DIVIDE, 0, m, &cBinop_TYFKHpmx_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_M7MwY8Wb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_GkcaojIW, HV_BINOP_DIVIDE, 1, m, &cBinop_GkcaojIW_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_TYFKHpmx, HV_BINOP_DIVIDE, 1, m, &cBinop_TYFKHpmx_sendMessage);
}

void Heavy_WSTD_DL3Y::cUnop_WBw46yYS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_zvo1Ct3S, HV_BINOP_DIVIDE, 0, m, &cBinop_zvo1Ct3S_sendMessage);
}

void Heavy_WSTD_DL3Y::cUnop_lnebxtNa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_zvo1Ct3S, HV_BINOP_DIVIDE, 1, m, &cBinop_zvo1Ct3S_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_DCIqxx7W_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_dHQVFpkQ, 0, m, &cVar_dHQVFpkQ_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_7i2gXh2f_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_M7MwY8Wb, 0, m, &cVar_M7MwY8Wb_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_K0sAYNTt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_GkcaojIW, HV_BINOP_DIVIDE, 0, m, &cBinop_GkcaojIW_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_GkcaojIW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_LOG, m, &cUnop_WBw46yYS_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_TYFKHpmx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_LOG, m, &cUnop_lnebxtNa_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_zvo1Ct3S_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 2.0f, 0, m, &cBinop_RIh99n1Z_sendMessage);
}

void Heavy_WSTD_DL3Y::cUnop_7nmdOx6O_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 0.313f, 0, m, &cBinop_SRzNIEyj_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_GjjBiSiN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.313f, 0, m, &cBinop_GJ6FySDZ_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_RIh99n1Z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_GjjBiSiN_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_GJ6FySDZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_ABS, m, &cUnop_7nmdOx6O_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_SRzNIEyj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_8iXIUQVu_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cVar_brJ0rktj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_So4MoX0j_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cVar_9YoovCgO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_vDyNm3w3_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cVar_2zFWbvLP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_LGwr6hdG_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cVar_igu0BTw1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_hI6xNjxN_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cVar_utldGmWc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_9kVKMcGz_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cVar_Oj2gIYut_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_WUI9ScYI_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cVar_AgaacGEk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_WGmRTWur_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cVar_CzXRd8w7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_slgu9tjq_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cVar_u5wTkiVb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_9um9APAF_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cVar_GLlfoVCt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_nfk2HlP0_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cVar_YPtaGY32_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_i7Y7nMeF_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cVar_RMfHDcbx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_5X0sM6NA_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSwitchcase_oiAdYZSx_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x764F1C36: { // "mix"
      cSlice_onMessage(_c, &Context(_c)->cSlice_ez8w0VYx, 0, m, &cSlice_ez8w0VYx_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_DL3Y::cSlice_ez8w0VYx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_ABjh804c_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_ABjh804c_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cVar_kGqaLbxA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_ABjh804c_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSend_ABjh804c_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_oWkHAwNv_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSwitchcase_PnARe7p9_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xC8CCFEC1: { // "cross"
      cSlice_onMessage(_c, &Context(_c)->cSlice_JITWoRKU, 0, m, &cSlice_JITWoRKU_sendMessage);
      break;
    }
    default: {
      cSwitchcase_EeXH1btI_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_DL3Y::cSlice_JITWoRKU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_qsWKDeuQ_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_qsWKDeuQ_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cVar_uRDYsgWq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_qsWKDeuQ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSend_qsWKDeuQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_ozcDJoBX_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSwitchcase_obt2GcEt_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x8E55AA5F: { // "time"
      cSlice_onMessage(_c, &Context(_c)->cSlice_93r9i9zd, 0, m, &cSlice_93r9i9zd_sendMessage);
      break;
    }
    default: {
      cSwitchcase_oiAdYZSx_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_DL3Y::cSlice_93r9i9zd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_pMLxE7Jt_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_pMLxE7Jt_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cVar_vDfSlMcQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_pMLxE7Jt_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSend_pMLxE7Jt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_hqHZwhBR_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_6OCZnXuU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_xwjmjyHt_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_xwjmjyHt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 2.0f, 0, m, &cBinop_ulQFKAjD_sendMessage);
}

void Heavy_WSTD_DL3Y::cUnop_24UugVLc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Gfp3cq1g_sendMessage(_c, 0, m);
  cMsg_QfKwLLzo_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cUnop_3SWJ91d6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_sSwzKSk1_sendMessage(_c, 0, m);
  cMsg_Z9XTCbkG_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_ulQFKAjD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_7ZLqfBNi_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_7ZLqfBNi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_PZdQlJzt_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_nPuM5VoD_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_nPuM5VoD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_iIy8CGU2_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_PZdQlJzt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_zgJSRhFb_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_zgJSRhFb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_qu67ySH0_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_iIy8CGU2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_VOKaYp4L_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_VOKaYp4L_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_egffQlh7_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_qu67ySH0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SQRT, m, &cUnop_24UugVLc_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_egffQlh7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SQRT, m, &cUnop_3SWJ91d6_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_GpKcERsw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_MG2H7glC_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_MG2H7glC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 2.0f, 0, m, &cBinop_FevD7L3Q_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_FevD7L3Q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_dMSbu71P_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_dMSbu71P_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_O7oaLqrn_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_bPsw2YhA_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_bPsw2YhA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_SAEZfXL4_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_O7oaLqrn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_GU1OeJOB_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_GU1OeJOB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_eprXfAmz_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_SAEZfXL4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_HFsuQOYO_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_HFsuQOYO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_o8DKtjgt_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_o8DKtjgt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_UONza08j_sendMessage(_c, 0, m);
  cMsg_9lgv19Lz_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_eprXfAmz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_iGDrQQbQ_sendMessage(_c, 0, m);
  cMsg_ASDr0czB_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_aTcMNIg9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_4WN9dGyY_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_4WN9dGyY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_7yw9QqtY_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_wFnsjWDN_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_rsqM1cht_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 1.0f, 0, m, &cBinop_yOOFOSiA_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_IWeqdoDW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_UeQ6z7Xu_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_UeQ6z7Xu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Oq26CBMo, HV_BINOP_DIVIDE, 1, m, &cBinop_Oq26CBMo_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_7yw9QqtY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_zI734BUb_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_zI734BUb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_N4HLeqZs, m);
}

void Heavy_WSTD_DL3Y::cMsg_2M4H750R_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_1s0Dg9zl_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_1s0Dg9zl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_aTcMNIg9_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_wFnsjWDN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_Mi1zyoxV, m);
}

void Heavy_WSTD_DL3Y::cBinop_yOOFOSiA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 6.28319f, 0, m, &cBinop_XdH6AWvQ_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_XdH6AWvQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Oq26CBMo, HV_BINOP_DIVIDE, 0, m, &cBinop_Oq26CBMo_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_Oq26CBMo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_2M4H750R_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_pDoqlrxc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_qMi32yNv_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_qMi32yNv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_RGBF7cqj_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_A9mPv9cy_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_lLSy9atD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 1.0f, 0, m, &cBinop_2O0TsMXz_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_UWjuzYGn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_fZsTYF7g_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_fZsTYF7g_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_ivPYvZIw, HV_BINOP_DIVIDE, 1, m, &cBinop_ivPYvZIw_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_RGBF7cqj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_ZsDK22jD_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_ZsDK22jD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_6R98Giqd, m);
}

void Heavy_WSTD_DL3Y::cMsg_8SbhUBK1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_1XXVgDPy_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_1XXVgDPy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_pDoqlrxc_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_A9mPv9cy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_fWUdcIdS, m);
}

void Heavy_WSTD_DL3Y::cBinop_2O0TsMXz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 6.28319f, 0, m, &cBinop_wnZ45joT_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_wnZ45joT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_ivPYvZIw, HV_BINOP_DIVIDE, 0, m, &cBinop_ivPYvZIw_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_ivPYvZIw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_8SbhUBK1_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cVar_GkfmpG8l_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_HiQkSmH3, HV_BINOP_MULTIPLY, 0, m, &cBinop_HiQkSmH3_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_UeS28Aw9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_i8W9GvNS_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_i8W9GvNS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_LqtFVM2i_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_HiQkSmH3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_jQ4p3TEa_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_GYqghwlp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_HiQkSmH3, HV_BINOP_MULTIPLY, 1, m, &cBinop_HiQkSmH3_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_LqtFVM2i_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 6.28319f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_GYqghwlp_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_jQ4p3TEa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_x3uFGsxl_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_x3uFGsxl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_FycilMx7_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_5vvyGBBx, m);
}

void Heavy_WSTD_DL3Y::cBinop_FycilMx7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_kjuXP6lV, m);
}

void Heavy_WSTD_DL3Y::cVar_ciq8E9C3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_dFO95vjC, HV_BINOP_MULTIPLY, 0, m, &cBinop_dFO95vjC_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_yJ8BrWp2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_HonGnpRn_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_HonGnpRn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_b0jksyWL_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_dFO95vjC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_hbUmdtHh_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_UrMRHlFu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_dFO95vjC, HV_BINOP_MULTIPLY, 1, m, &cBinop_dFO95vjC_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_b0jksyWL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 6.28319f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_UrMRHlFu_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_hbUmdtHh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_Xhcsgfg9_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_Xhcsgfg9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_e31DN8aD_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_f9bgea55, m);
}

void Heavy_WSTD_DL3Y::cBinop_e31DN8aD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_6ABURnfh, m);
}

void Heavy_WSTD_DL3Y::sEnv_nf33n1xb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_TofrCQsK_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_NiiuPOP1_sendMessage);
}

void Heavy_WSTD_DL3Y::cIf_WvTra8Se_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_SF9yRDYy_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 485.0f, 0, m, &cBinop_P8Rrgx8Q_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cMsg_rltlTuDX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 10.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_ErQ5fErU, HV_BINOP_POW, 0, m, &cBinop_ErQ5fErU_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_ErQ5fErU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_0Neqq152_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_XbMEEQca_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 20.0f, 0, m, &cBinop_ZUKzuvcQ_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_NiiuPOP1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_WvTra8Se, 0, m, &cIf_WvTra8Se_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_TofrCQsK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_92LPSRY4_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_92LPSRY4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_WvTra8Se, 1, m, &cIf_WvTra8Se_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_P8Rrgx8Q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 100.0f, 0, m, &cBinop_XbMEEQca_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_SF9yRDYy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cMsg_0Neqq152_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_ZUKzuvcQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_ErQ5fErU, HV_BINOP_POW, 1, m, &cBinop_ErQ5fErU_sendMessage);
  cMsg_rltlTuDX_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cVar_WWPjSuvk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_IdKvyeJI, HV_BINOP_MULTIPLY, 0, m, &cBinop_IdKvyeJI_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_nSEJxKG5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_NaGHI0pC_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_NaGHI0pC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_ugndLSAx_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_IdKvyeJI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_YwrHyJnd_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_wAcy0GFR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_IdKvyeJI, HV_BINOP_MULTIPLY, 1, m, &cBinop_IdKvyeJI_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_ugndLSAx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 6.28319f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_wAcy0GFR_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_YwrHyJnd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_LZD6SUxO_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_LZD6SUxO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_uTdPHUOm_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_wIXjPGFB, m);
}

void Heavy_WSTD_DL3Y::cBinop_uTdPHUOm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_u841L0ya, m);
}

void Heavy_WSTD_DL3Y::cMsg_0Neqq152_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_HMkRcQAU_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_HMkRcQAU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_lBmUzBZX, m);
}

void Heavy_WSTD_DL3Y::sEnv_rVYbO1Pz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_u2tvRsBy_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_ez9kaoTI_sendMessage);
}

void Heavy_WSTD_DL3Y::cIf_MbTQvfOi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_RUjOROHL_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 485.0f, 0, m, &cBinop_XHoWc8A4_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cMsg_JnLBGMFm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 10.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_DyaGL7tn, HV_BINOP_POW, 0, m, &cBinop_DyaGL7tn_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_DyaGL7tn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_4P4l6Sdo_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_aOqc567E_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 20.0f, 0, m, &cBinop_VOmNZDj5_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_ez9kaoTI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_MbTQvfOi, 0, m, &cIf_MbTQvfOi_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_u2tvRsBy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_Zb8ORUQ0_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_Zb8ORUQ0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_MbTQvfOi, 1, m, &cIf_MbTQvfOi_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_XHoWc8A4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 100.0f, 0, m, &cBinop_aOqc567E_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_RUjOROHL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cMsg_4P4l6Sdo_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_VOmNZDj5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_DyaGL7tn, HV_BINOP_POW, 1, m, &cBinop_DyaGL7tn_sendMessage);
  cMsg_JnLBGMFm_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cVar_Z8jQ3ioI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_pcAa7J2r, HV_BINOP_MULTIPLY, 0, m, &cBinop_pcAa7J2r_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_rjEOSTA6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_NE0FQ2J3_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_NE0FQ2J3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_SUCHpbMt_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_pcAa7J2r_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_0aLPMVN1_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_Kkvr6xaL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_pcAa7J2r, HV_BINOP_MULTIPLY, 1, m, &cBinop_pcAa7J2r_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_SUCHpbMt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 6.28319f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_Kkvr6xaL_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_0aLPMVN1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_KXqx6khm_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_KXqx6khm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_fTIOcEjR_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_l5ZeRrZt, m);
}

void Heavy_WSTD_DL3Y::cBinop_fTIOcEjR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_StyVyNVt, m);
}

void Heavy_WSTD_DL3Y::cMsg_4P4l6Sdo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_awZxQCQf_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_awZxQCQf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_eXOR32gl, m);
}

void Heavy_WSTD_DL3Y::cSwitchcase_EeXH1btI_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xF1E7CD16: { // "feedback"
      cSlice_onMessage(_c, &Context(_c)->cSlice_I48CQQv9, 0, m, &cSlice_I48CQQv9_sendMessage);
      break;
    }
    default: {
      cSwitchcase_obt2GcEt_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_DL3Y::cSlice_I48CQQv9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_TfNUPORN_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_TfNUPORN_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cVar_Q7WTkLnO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_TfNUPORN_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSend_TfNUPORN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_gEkbwGam_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cMsg_f1bGUor2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_NNVrSzvc_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_NNVrSzvc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_7CBl4pYV_sendMessage);
}

void Heavy_WSTD_DL3Y::cDelay_Dkc5HOOv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_Dkc5HOOv, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_7o17fACz, 0, m, &cDelay_7o17fACz_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_Dkc5HOOv, 0, m, &cDelay_Dkc5HOOv_sendMessage);
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_zzG54XvL, 1, m, NULL);
}

void Heavy_WSTD_DL3Y::cDelay_7o17fACz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_7o17fACz, m);
  cMsg_xFmgtCYA_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSwitchcase_ggTZahTv_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x47BE8354: { // "clear"
      cMsg_LT0g5rST_sendMessage(_c, 0, m);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_DL3Y::cBinop_uV1cplIQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_EDl0l517_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::hTable_7x0B2Fxc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_jwmxUnxN_sendMessage(_c, 0, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_Dkc5HOOv, 2, m, &cDelay_Dkc5HOOv_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Zxiko03N_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_EDl0l517_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "resize");
  msg_setElementToFrom(m, 1, n, 0);
  hTable_onMessage(_c, &Context(_c)->hTable_7x0B2Fxc, 0, m, &hTable_7x0B2Fxc_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_7CBl4pYV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 5000.0f, 0, m, &cBinop_uV1cplIQ_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_xFmgtCYA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mirror");
  hTable_onMessage(_c, &Context(_c)->hTable_7x0B2Fxc, 0, m, &hTable_7x0B2Fxc_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_Zxiko03N_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_Dkc5HOOv, 0, m, &cDelay_Dkc5HOOv_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_jwmxUnxN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cDelay_onMessage(_c, &Context(_c)->cDelay_7o17fACz, 2, m, &cDelay_7o17fACz_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_LT0g5rST_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_zzG54XvL, 1, m, NULL);
}

void Heavy_WSTD_DL3Y::cTabhead_Val5Nhh7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_VcH3Y18J, HV_BINOP_SUBTRACT, 0, m, &cBinop_VcH3Y18J_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_hblQ1vuU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_xfi47CFJ_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_xfi47CFJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_b0v58HAo_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_lV6Yu5SE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_w14vx1t8_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cDelay_Cwd9s4Kc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_Cwd9s4Kc, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_DulcciMx, 0, m, &cDelay_DulcciMx_sendMessage);
  sTabread_onMessage(_c, &Context(_c)->sTabread_kJnvbcXU, 0, m, &sTabread_kJnvbcXU_sendMessage);
}

void Heavy_WSTD_DL3Y::cDelay_DulcciMx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_DulcciMx, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_kJnvbcXU, 0, m, &sTabread_kJnvbcXU_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_DulcciMx, 0, m, &cDelay_DulcciMx_sendMessage);
}

void Heavy_WSTD_DL3Y::sTabread_kJnvbcXU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_onMessage(_c, &Context(_c)->cBinop_rShAskdf, HV_BINOP_SUBTRACT, 0, m, &cBinop_rShAskdf_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cBinop_yqebyBIR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_FAETmBqC, HV_BINOP_MAX, 0, m, &cBinop_FAETmBqC_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_b0v58HAo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_yqebyBIR, HV_BINOP_MULTIPLY, 0, m, &cBinop_yqebyBIR_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_VcH3Y18J_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_7wH58li0_sendMessage(_c, 0, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_kJnvbcXU, 0, m, &sTabread_kJnvbcXU_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_ADbwCjao_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_r9s6G3Wq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_rShAskdf, HV_BINOP_SUBTRACT, 1, m, &cBinop_rShAskdf_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_DulcciMx, 2, m, &cDelay_DulcciMx_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_w14vx1t8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(3);
  msg_init(m, 3, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "table");
  msg_setElementToFrom(m, 1, n, 0);
  msg_setSymbol(m, 2, "size");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_r9s6G3Wq_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_7wH58li0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_Cwd9s4Kc, 0, m, &cDelay_Cwd9s4Kc_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_DulcciMx, 0, m, &cDelay_DulcciMx_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_BDnJKOqs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cBinop_onMessage(_c, &Context(_c)->cBinop_FAETmBqC, HV_BINOP_MAX, 1, m, &cBinop_FAETmBqC_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_FAETmBqC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_VcH3Y18J, HV_BINOP_SUBTRACT, 1, m, &cBinop_VcH3Y18J_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_ADbwCjao_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_Cwd9s4Kc, 0, m, &cDelay_Cwd9s4Kc_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_fUsQGipU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_Cwd9s4Kc, 2, m, &cDelay_Cwd9s4Kc_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_rShAskdf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_fUsQGipU_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_mf3Mgrbi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_lV6Yu5SE, 0, m, &cVar_lV6Yu5SE_sendMessage);
  cMsg_hblQ1vuU_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_Val5Nhh7, 0, m, &cTabhead_Val5Nhh7_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_xX7H6hwX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_bn7zjEmi_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_bn7zjEmi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_pX2pXmLJ_sendMessage);
}

void Heavy_WSTD_DL3Y::cDelay_2wsHuuO9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_2wsHuuO9, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_Y0IojV5f, 0, m, &cDelay_Y0IojV5f_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_2wsHuuO9, 0, m, &cDelay_2wsHuuO9_sendMessage);
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_tuJIgAub, 1, m, NULL);
}

void Heavy_WSTD_DL3Y::cDelay_Y0IojV5f_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_Y0IojV5f, m);
  cMsg_L9Jo8mIj_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSwitchcase_UqQIMnqG_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x47BE8354: { // "clear"
      cMsg_T6LG0NWC_sendMessage(_c, 0, m);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_DL3Y::cBinop_cJAuUICh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_RbK8sBK5_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::hTable_I5cfsGR3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_iqahPjlW_sendMessage(_c, 0, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_2wsHuuO9, 2, m, &cDelay_2wsHuuO9_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_5VCESfRz_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_RbK8sBK5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "resize");
  msg_setElementToFrom(m, 1, n, 0);
  hTable_onMessage(_c, &Context(_c)->hTable_I5cfsGR3, 0, m, &hTable_I5cfsGR3_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_pX2pXmLJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 5000.0f, 0, m, &cBinop_cJAuUICh_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_L9Jo8mIj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mirror");
  hTable_onMessage(_c, &Context(_c)->hTable_I5cfsGR3, 0, m, &hTable_I5cfsGR3_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_5VCESfRz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_2wsHuuO9, 0, m, &cDelay_2wsHuuO9_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_iqahPjlW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cDelay_onMessage(_c, &Context(_c)->cDelay_Y0IojV5f, 2, m, &cDelay_Y0IojV5f_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_T6LG0NWC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_tuJIgAub, 1, m, NULL);
}

void Heavy_WSTD_DL3Y::cTabhead_TZiWyNYt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_GukUANOf, HV_BINOP_SUBTRACT, 0, m, &cBinop_GukUANOf_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_hhyjOAd3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_tY7YFyEQ_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_tY7YFyEQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_y7onc338_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_yWl4KRIG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_DuRCcWPt_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cDelay_n1w8audf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_n1w8audf, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_6I8sI1gE, 0, m, &cDelay_6I8sI1gE_sendMessage);
  sTabread_onMessage(_c, &Context(_c)->sTabread_KkngDjR1, 0, m, &sTabread_KkngDjR1_sendMessage);
}

void Heavy_WSTD_DL3Y::cDelay_6I8sI1gE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_6I8sI1gE, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_KkngDjR1, 0, m, &sTabread_KkngDjR1_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_6I8sI1gE, 0, m, &cDelay_6I8sI1gE_sendMessage);
}

void Heavy_WSTD_DL3Y::sTabread_KkngDjR1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_onMessage(_c, &Context(_c)->cBinop_dZWCteqB, HV_BINOP_SUBTRACT, 0, m, &cBinop_dZWCteqB_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cBinop_uDiiH0hO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_yVX6n3Sw, HV_BINOP_MAX, 0, m, &cBinop_yVX6n3Sw_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_y7onc338_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_uDiiH0hO, HV_BINOP_MULTIPLY, 0, m, &cBinop_uDiiH0hO_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_GukUANOf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_KaANe2Xi_sendMessage(_c, 0, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_KkngDjR1, 0, m, &sTabread_KkngDjR1_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_KsKFWNZJ_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_H88L80CZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_dZWCteqB, HV_BINOP_SUBTRACT, 1, m, &cBinop_dZWCteqB_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_6I8sI1gE, 2, m, &cDelay_6I8sI1gE_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_DuRCcWPt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(3);
  msg_init(m, 3, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "table");
  msg_setElementToFrom(m, 1, n, 0);
  msg_setSymbol(m, 2, "size");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_H88L80CZ_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_KaANe2Xi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_n1w8audf, 0, m, &cDelay_n1w8audf_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_6I8sI1gE, 0, m, &cDelay_6I8sI1gE_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_WSdZfs02_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cBinop_onMessage(_c, &Context(_c)->cBinop_yVX6n3Sw, HV_BINOP_MAX, 1, m, &cBinop_yVX6n3Sw_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_yVX6n3Sw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_GukUANOf, HV_BINOP_SUBTRACT, 1, m, &cBinop_GukUANOf_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_KsKFWNZJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_n1w8audf, 0, m, &cDelay_n1w8audf_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_uiu5YACF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_n1w8audf, 2, m, &cDelay_n1w8audf_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_dZWCteqB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_uiu5YACF_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_XDF1Y4qb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_yWl4KRIG, 0, m, &cVar_yWl4KRIG_sendMessage);
  cMsg_hhyjOAd3_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_TZiWyNYt, 0, m, &cTabhead_TZiWyNYt_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_Gfp3cq1g_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_KF6LAt22, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_sSwzKSk1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_HbbFySTt, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_Z9XTCbkG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_2LHj6sON, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_QfKwLLzo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_TLi70L90, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_ASDr0czB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_DZzF4tV1, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_UONza08j_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_3lgQADRC, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_iGDrQQbQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_5X6xXqd8, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_9lgv19Lz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_Sb1FCag7, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cSwitchcase_hG8cuwdi_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x764F1C36: { // "mix"
      cSlice_onMessage(_c, &Context(_c)->cSlice_vhpxAoW8, 0, m, &cSlice_vhpxAoW8_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_DL3Y::cSlice_vhpxAoW8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_pvOwX7lU_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_pvOwX7lU_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cVar_RZS7IiRM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_pvOwX7lU_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSend_pvOwX7lU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_fUAyzHnZ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSwitchcase_4qLxAKUq_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xC8CCFEC1: { // "cross"
      cSlice_onMessage(_c, &Context(_c)->cSlice_O9VblBZy, 0, m, &cSlice_O9VblBZy_sendMessage);
      break;
    }
    default: {
      cSwitchcase_3KpCHIL8_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_DL3Y::cSlice_O9VblBZy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_NJTdVkTw_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_NJTdVkTw_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cVar_tCSYAsV6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_NJTdVkTw_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSend_NJTdVkTw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_AaZVT2lV_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSwitchcase_rTEdjFU0_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x8E55AA5F: { // "time"
      cSlice_onMessage(_c, &Context(_c)->cSlice_TWf10aQb, 0, m, &cSlice_TWf10aQb_sendMessage);
      break;
    }
    default: {
      cSwitchcase_hG8cuwdi_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_DL3Y::cSlice_TWf10aQb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_yLDHWtNJ_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_yLDHWtNJ_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cVar_JTOxxBwX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_yLDHWtNJ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSend_yLDHWtNJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_riZFAJzg_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_kCppn525_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_7zCr0dc2_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_7zCr0dc2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 2.0f, 0, m, &cBinop_NICxhkGc_sendMessage);
}

void Heavy_WSTD_DL3Y::cUnop_81VqCjTU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_okaGHOt4_sendMessage(_c, 0, m);
  cMsg_JbhhowXd_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cUnop_cNItSx2G_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Z3lVaW9s_sendMessage(_c, 0, m);
  cMsg_V1baxdUy_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_NICxhkGc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_dNEmF4DV_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_dNEmF4DV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_LmvOl6TL_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_qyQxpR1g_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_qyQxpR1g_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_hLenI01c_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_LmvOl6TL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_4YIWTx57_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_4YIWTx57_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_csB0iJQs_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_hLenI01c_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_g4XD9s2R_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_g4XD9s2R_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_Ct5pFbNw_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_csB0iJQs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SQRT, m, &cUnop_81VqCjTU_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_Ct5pFbNw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SQRT, m, &cUnop_cNItSx2G_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_IUKaSDWY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_gVPM6Hef_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_gVPM6Hef_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 2.0f, 0, m, &cBinop_NhoqlXDc_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_NhoqlXDc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_PpxZNMFI_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_PpxZNMFI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_XQTjShcJ_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_XcHsH4n4_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_XcHsH4n4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_5SjZsmpa_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_XQTjShcJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_uuD75CcQ_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_uuD75CcQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_pjIydpe2_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_5SjZsmpa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_9ZKLoxXi_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_9ZKLoxXi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_yWTkWCZi_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_yWTkWCZi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_UKHPRwwh_sendMessage(_c, 0, m);
  cMsg_YeE8srqX_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_pjIydpe2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_3Hzz1LSp_sendMessage(_c, 0, m);
  cMsg_N9SfNqcv_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_n2ZduPKG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_yx2OXQBP_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_yx2OXQBP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_P152PN12_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_eXyFLlvv_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_2KOQ69tv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 1.0f, 0, m, &cBinop_8c5TQwex_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_kqcY6zvi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_K4jYjRJJ_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_K4jYjRJJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_CtyhQUb2, HV_BINOP_DIVIDE, 1, m, &cBinop_CtyhQUb2_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_P152PN12_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_t6KNxfRW_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_t6KNxfRW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_4iI4RvEg, m);
}

void Heavy_WSTD_DL3Y::cMsg_gBDUmsYt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_R2YNusLE_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_R2YNusLE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_n2ZduPKG_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_eXyFLlvv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_01hyF3K3, m);
}

void Heavy_WSTD_DL3Y::cBinop_8c5TQwex_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 6.28319f, 0, m, &cBinop_npXcCYls_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_npXcCYls_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_CtyhQUb2, HV_BINOP_DIVIDE, 0, m, &cBinop_CtyhQUb2_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_CtyhQUb2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_gBDUmsYt_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_J7j4ZZ9x_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_Eb7efaTV_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_Eb7efaTV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_BoC2tv5Q_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_FJ3EIHD5_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_PWHgirq6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 1.0f, 0, m, &cBinop_8nKEa9pe_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_oLLjyamk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_qUA8arHS_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_qUA8arHS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_bSk8iR2z, HV_BINOP_DIVIDE, 1, m, &cBinop_bSk8iR2z_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_BoC2tv5Q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_tNxTkXNx_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_tNxTkXNx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_hmcEjZuy, m);
}

void Heavy_WSTD_DL3Y::cMsg_vkT66h8b_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_3GvSdJCc_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_3GvSdJCc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_J7j4ZZ9x_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_FJ3EIHD5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_G6r8JQDK, m);
}

void Heavy_WSTD_DL3Y::cBinop_8nKEa9pe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 6.28319f, 0, m, &cBinop_Pskwim82_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_Pskwim82_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_bSk8iR2z, HV_BINOP_DIVIDE, 0, m, &cBinop_bSk8iR2z_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_bSk8iR2z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_vkT66h8b_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cVar_oycvtVJP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_ow8O1xDd, HV_BINOP_MULTIPLY, 0, m, &cBinop_ow8O1xDd_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_8Mj9qm8T_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_01jOUDcw_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_01jOUDcw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_dY1NlRBD_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_ow8O1xDd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_jbWMNEaO_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_EffXlSAP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_ow8O1xDd, HV_BINOP_MULTIPLY, 1, m, &cBinop_ow8O1xDd_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_dY1NlRBD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 6.28319f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_EffXlSAP_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_jbWMNEaO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_PbzA8eKP_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_PbzA8eKP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_4QNrU8ZB_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_6EUbuRpa, m);
}

void Heavy_WSTD_DL3Y::cBinop_4QNrU8ZB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_Vwah0IL2, m);
}

void Heavy_WSTD_DL3Y::cVar_6bveOwfp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_mGE52jIA, HV_BINOP_MULTIPLY, 0, m, &cBinop_mGE52jIA_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_wnyi5i60_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_L2vFxsXh_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_L2vFxsXh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_004ouoqw_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_mGE52jIA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_LAram3gk_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_lJ53LtiE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_mGE52jIA, HV_BINOP_MULTIPLY, 1, m, &cBinop_mGE52jIA_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_004ouoqw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 6.28319f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_lJ53LtiE_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_LAram3gk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_pwEHXzqQ_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_pwEHXzqQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_Su8Vr2he_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_fgYSlY9V, m);
}

void Heavy_WSTD_DL3Y::cBinop_Su8Vr2he_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_bg7wtqrx, m);
}

void Heavy_WSTD_DL3Y::sEnv_gUwuReQU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_IdCFpbnD_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_2mVYz0px_sendMessage);
}

void Heavy_WSTD_DL3Y::cIf_tSW2bhWQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_VZ3rTCFL_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 485.0f, 0, m, &cBinop_lE23upmy_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cMsg_Hce4Hdew_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 10.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_cgwvja55, HV_BINOP_POW, 0, m, &cBinop_cgwvja55_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_cgwvja55_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_QWEcYN8K_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_TZvNCdHl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 20.0f, 0, m, &cBinop_5y6urSYk_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_2mVYz0px_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_tSW2bhWQ, 0, m, &cIf_tSW2bhWQ_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_IdCFpbnD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_ku1EsxiU_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_ku1EsxiU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_tSW2bhWQ, 1, m, &cIf_tSW2bhWQ_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_lE23upmy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 100.0f, 0, m, &cBinop_TZvNCdHl_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_VZ3rTCFL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cMsg_QWEcYN8K_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_5y6urSYk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_cgwvja55, HV_BINOP_POW, 1, m, &cBinop_cgwvja55_sendMessage);
  cMsg_Hce4Hdew_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cVar_yckCdJYg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_MhVBxCYa, HV_BINOP_MULTIPLY, 0, m, &cBinop_MhVBxCYa_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_7Jw3qIUV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_344ZOeUc_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_344ZOeUc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_vZmk1SkS_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_MhVBxCYa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_wQgl37M1_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_sZuvwfyW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_MhVBxCYa, HV_BINOP_MULTIPLY, 1, m, &cBinop_MhVBxCYa_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_vZmk1SkS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 6.28319f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_sZuvwfyW_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_wQgl37M1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_w799Pbbm_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_w799Pbbm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_IHi8wrDv_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_bIUv0IGp, m);
}

void Heavy_WSTD_DL3Y::cBinop_IHi8wrDv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_p9NAi40S, m);
}

void Heavy_WSTD_DL3Y::cMsg_QWEcYN8K_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_p61YwcOm_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_p61YwcOm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_sAJwsfF7, m);
}

void Heavy_WSTD_DL3Y::sEnv_hzBDacSm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_CN0cz8wF_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_aJMUqJLm_sendMessage);
}

void Heavy_WSTD_DL3Y::cIf_tsPvoHks_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_1FKVnFiB_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 485.0f, 0, m, &cBinop_6KYW1YUL_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cMsg_DNevN5Xo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 10.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_385enrn2, HV_BINOP_POW, 0, m, &cBinop_385enrn2_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_385enrn2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_7m0wqIHV_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_VIivUx9w_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 20.0f, 0, m, &cBinop_gZo0vSq3_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_aJMUqJLm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_tsPvoHks, 0, m, &cIf_tsPvoHks_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_CN0cz8wF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_uLu5dl7Z_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_uLu5dl7Z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_tsPvoHks, 1, m, &cIf_tsPvoHks_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_6KYW1YUL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 100.0f, 0, m, &cBinop_VIivUx9w_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_1FKVnFiB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cMsg_7m0wqIHV_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_gZo0vSq3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_385enrn2, HV_BINOP_POW, 1, m, &cBinop_385enrn2_sendMessage);
  cMsg_DNevN5Xo_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cVar_rOmtiryS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_6O0v284K, HV_BINOP_MULTIPLY, 0, m, &cBinop_6O0v284K_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_uIOylhfC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_IbYfdpoM_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_IbYfdpoM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_q9UC6QsE_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_6O0v284K_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_JuHQaqHx_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_KDjLxk1c_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_6O0v284K, HV_BINOP_MULTIPLY, 1, m, &cBinop_6O0v284K_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_q9UC6QsE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 6.28319f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_KDjLxk1c_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_JuHQaqHx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_ZBpCBiSQ_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_ZBpCBiSQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_7AIdeMKS_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_FzIY2RNJ, m);
}

void Heavy_WSTD_DL3Y::cBinop_7AIdeMKS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_Z4KtHpa4, m);
}

void Heavy_WSTD_DL3Y::cMsg_7m0wqIHV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_FfWZBIOq_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_FfWZBIOq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_xMCqYZ1U, m);
}

void Heavy_WSTD_DL3Y::cSwitchcase_3KpCHIL8_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xF1E7CD16: { // "feedback"
      cSlice_onMessage(_c, &Context(_c)->cSlice_q8AXAQCf, 0, m, &cSlice_q8AXAQCf_sendMessage);
      break;
    }
    default: {
      cSwitchcase_rTEdjFU0_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_DL3Y::cSlice_q8AXAQCf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_1FODeZxf_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_1FODeZxf_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cVar_tVDPxd2z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_1FODeZxf_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSend_1FODeZxf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_VQM9ZWSq_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cMsg_Q84xjcUa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_vZJtmQiU_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_vZJtmQiU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_lwkkSKXu_sendMessage);
}

void Heavy_WSTD_DL3Y::cDelay_kMS6F6e3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_kMS6F6e3, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_5nUSdKE2, 0, m, &cDelay_5nUSdKE2_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_kMS6F6e3, 0, m, &cDelay_kMS6F6e3_sendMessage);
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_os7u61NE, 1, m, NULL);
}

void Heavy_WSTD_DL3Y::cDelay_5nUSdKE2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_5nUSdKE2, m);
  cMsg_w7XJHwZ0_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSwitchcase_WeHOcafB_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x47BE8354: { // "clear"
      cMsg_WH0Haphz_sendMessage(_c, 0, m);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_DL3Y::cBinop_lBjLU20S_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_qKRqVoBC_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::hTable_ow1qv5O7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_HKmsw0kU_sendMessage(_c, 0, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_kMS6F6e3, 2, m, &cDelay_kMS6F6e3_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_fcbzh4hv_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_qKRqVoBC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "resize");
  msg_setElementToFrom(m, 1, n, 0);
  hTable_onMessage(_c, &Context(_c)->hTable_ow1qv5O7, 0, m, &hTable_ow1qv5O7_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_lwkkSKXu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 5000.0f, 0, m, &cBinop_lBjLU20S_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_w7XJHwZ0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mirror");
  hTable_onMessage(_c, &Context(_c)->hTable_ow1qv5O7, 0, m, &hTable_ow1qv5O7_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_fcbzh4hv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_kMS6F6e3, 0, m, &cDelay_kMS6F6e3_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_HKmsw0kU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cDelay_onMessage(_c, &Context(_c)->cDelay_5nUSdKE2, 2, m, &cDelay_5nUSdKE2_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_WH0Haphz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_os7u61NE, 1, m, NULL);
}

void Heavy_WSTD_DL3Y::cTabhead_yOj6zCUq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_utsHsSCz, HV_BINOP_SUBTRACT, 0, m, &cBinop_utsHsSCz_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_4N0cYNjX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_w8hXPl90_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_w8hXPl90_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_TgvfHjJu_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_7BXFbOSu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_JPxufsf5_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cDelay_z592QUMT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_z592QUMT, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_6a36MpoM, 0, m, &cDelay_6a36MpoM_sendMessage);
  sTabread_onMessage(_c, &Context(_c)->sTabread_9U3UNaf4, 0, m, &sTabread_9U3UNaf4_sendMessage);
}

void Heavy_WSTD_DL3Y::cDelay_6a36MpoM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_6a36MpoM, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_9U3UNaf4, 0, m, &sTabread_9U3UNaf4_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_6a36MpoM, 0, m, &cDelay_6a36MpoM_sendMessage);
}

void Heavy_WSTD_DL3Y::sTabread_9U3UNaf4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_onMessage(_c, &Context(_c)->cBinop_1MnTlNtJ, HV_BINOP_SUBTRACT, 0, m, &cBinop_1MnTlNtJ_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cBinop_qCLGO9Ve_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_6ghhxEwN, HV_BINOP_MAX, 0, m, &cBinop_6ghhxEwN_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_TgvfHjJu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_qCLGO9Ve, HV_BINOP_MULTIPLY, 0, m, &cBinop_qCLGO9Ve_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_utsHsSCz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_vI2tI1qq_sendMessage(_c, 0, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_9U3UNaf4, 0, m, &sTabread_9U3UNaf4_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_bLq7NK0F_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_Ua1w6CEt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_1MnTlNtJ, HV_BINOP_SUBTRACT, 1, m, &cBinop_1MnTlNtJ_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_6a36MpoM, 2, m, &cDelay_6a36MpoM_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_JPxufsf5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(3);
  msg_init(m, 3, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "table");
  msg_setElementToFrom(m, 1, n, 0);
  msg_setSymbol(m, 2, "size");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_Ua1w6CEt_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_vI2tI1qq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_z592QUMT, 0, m, &cDelay_z592QUMT_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_6a36MpoM, 0, m, &cDelay_6a36MpoM_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_3rJsrMb5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cBinop_onMessage(_c, &Context(_c)->cBinop_6ghhxEwN, HV_BINOP_MAX, 1, m, &cBinop_6ghhxEwN_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_6ghhxEwN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_utsHsSCz, HV_BINOP_SUBTRACT, 1, m, &cBinop_utsHsSCz_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_bLq7NK0F_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_z592QUMT, 0, m, &cDelay_z592QUMT_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_CSQVUUbJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_z592QUMT, 2, m, &cDelay_z592QUMT_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_1MnTlNtJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_CSQVUUbJ_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_A4vBgq0H_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_7BXFbOSu, 0, m, &cVar_7BXFbOSu_sendMessage);
  cMsg_4N0cYNjX_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_yOj6zCUq, 0, m, &cTabhead_yOj6zCUq_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_ZESufBhy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_e7iw8l5N_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_e7iw8l5N_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_qCWBbKJW_sendMessage);
}

void Heavy_WSTD_DL3Y::cDelay_tH1gKy6k_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_tH1gKy6k, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_ipycJOdv, 0, m, &cDelay_ipycJOdv_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_tH1gKy6k, 0, m, &cDelay_tH1gKy6k_sendMessage);
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_srYT0sgZ, 1, m, NULL);
}

void Heavy_WSTD_DL3Y::cDelay_ipycJOdv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_ipycJOdv, m);
  cMsg_XTWIcc71_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSwitchcase_ixMc5ubU_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x47BE8354: { // "clear"
      cMsg_7qx83jaI_sendMessage(_c, 0, m);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_DL3Y::cBinop_VUf7fQIV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_kn0iLliY_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::hTable_VKt3CZZ8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_5V8c133f_sendMessage(_c, 0, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_tH1gKy6k, 2, m, &cDelay_tH1gKy6k_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_H53q5tFt_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_kn0iLliY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "resize");
  msg_setElementToFrom(m, 1, n, 0);
  hTable_onMessage(_c, &Context(_c)->hTable_VKt3CZZ8, 0, m, &hTable_VKt3CZZ8_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_qCWBbKJW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 5000.0f, 0, m, &cBinop_VUf7fQIV_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_XTWIcc71_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mirror");
  hTable_onMessage(_c, &Context(_c)->hTable_VKt3CZZ8, 0, m, &hTable_VKt3CZZ8_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_H53q5tFt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_tH1gKy6k, 0, m, &cDelay_tH1gKy6k_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_5V8c133f_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cDelay_onMessage(_c, &Context(_c)->cDelay_ipycJOdv, 2, m, &cDelay_ipycJOdv_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_7qx83jaI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_srYT0sgZ, 1, m, NULL);
}

void Heavy_WSTD_DL3Y::cTabhead_xfLdtVPh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_8CSthkTu, HV_BINOP_SUBTRACT, 0, m, &cBinop_8CSthkTu_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_0AFsn13K_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_sqZZyL7m_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_sqZZyL7m_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_BtoFwAwe_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_PMcml0Ud_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_9CnWohTo_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cDelay_uqJ3GMbB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_uqJ3GMbB, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_qtzD9LWm, 0, m, &cDelay_qtzD9LWm_sendMessage);
  sTabread_onMessage(_c, &Context(_c)->sTabread_Dvq8t9cv, 0, m, &sTabread_Dvq8t9cv_sendMessage);
}

void Heavy_WSTD_DL3Y::cDelay_qtzD9LWm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_qtzD9LWm, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_Dvq8t9cv, 0, m, &sTabread_Dvq8t9cv_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_qtzD9LWm, 0, m, &cDelay_qtzD9LWm_sendMessage);
}

void Heavy_WSTD_DL3Y::sTabread_Dvq8t9cv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_onMessage(_c, &Context(_c)->cBinop_G2GOFdn4, HV_BINOP_SUBTRACT, 0, m, &cBinop_G2GOFdn4_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cBinop_C0FcKmSr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_VwAYUUU0, HV_BINOP_MAX, 0, m, &cBinop_VwAYUUU0_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_BtoFwAwe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_C0FcKmSr, HV_BINOP_MULTIPLY, 0, m, &cBinop_C0FcKmSr_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_8CSthkTu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_nXibKowV_sendMessage(_c, 0, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_Dvq8t9cv, 0, m, &sTabread_Dvq8t9cv_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_TCOjaJcg_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_E9LO5VHG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_G2GOFdn4, HV_BINOP_SUBTRACT, 1, m, &cBinop_G2GOFdn4_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_qtzD9LWm, 2, m, &cDelay_qtzD9LWm_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_9CnWohTo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(3);
  msg_init(m, 3, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "table");
  msg_setElementToFrom(m, 1, n, 0);
  msg_setSymbol(m, 2, "size");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_E9LO5VHG_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_nXibKowV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_uqJ3GMbB, 0, m, &cDelay_uqJ3GMbB_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_qtzD9LWm, 0, m, &cDelay_qtzD9LWm_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_2o6LHiAP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cBinop_onMessage(_c, &Context(_c)->cBinop_VwAYUUU0, HV_BINOP_MAX, 1, m, &cBinop_VwAYUUU0_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_VwAYUUU0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_8CSthkTu, HV_BINOP_SUBTRACT, 1, m, &cBinop_8CSthkTu_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_TCOjaJcg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_uqJ3GMbB, 0, m, &cDelay_uqJ3GMbB_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_pquMmtq6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_uqJ3GMbB, 2, m, &cDelay_uqJ3GMbB_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_G2GOFdn4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_pquMmtq6_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_uh6JQ4AM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_PMcml0Ud, 0, m, &cVar_PMcml0Ud_sendMessage);
  cMsg_0AFsn13K_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_xfLdtVPh, 0, m, &cTabhead_xfLdtVPh_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_okaGHOt4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_lG3rgYD3, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_Z3lVaW9s_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_4NLpwP81, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_V1baxdUy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_UHsZQEzP, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_JbhhowXd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_dEN3YcaK, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_N9SfNqcv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_FPo8vF8m, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_UKHPRwwh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_00kD6lPp, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_3Hzz1LSp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_5USDLik8, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_YeE8srqX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_sOPCuOLk, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cSwitchcase_ZgedWkEX_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x764F1C36: { // "mix"
      cSlice_onMessage(_c, &Context(_c)->cSlice_Qd9xMcl5, 0, m, &cSlice_Qd9xMcl5_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_DL3Y::cSlice_Qd9xMcl5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_23n6HoY6_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_23n6HoY6_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cVar_O3SWsKV3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_23n6HoY6_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSend_23n6HoY6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_4ULDuD1x_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSwitchcase_nm4vjRhT_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xC8CCFEC1: { // "cross"
      cSlice_onMessage(_c, &Context(_c)->cSlice_CmiZXgTL, 0, m, &cSlice_CmiZXgTL_sendMessage);
      break;
    }
    default: {
      cSwitchcase_OPXeeo74_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_DL3Y::cSlice_CmiZXgTL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_ejIlJCai_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_ejIlJCai_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cVar_HYHTTl66_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_ejIlJCai_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSend_ejIlJCai_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_nj5fstQ3_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSwitchcase_tEYBcRoD_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x8E55AA5F: { // "time"
      cSlice_onMessage(_c, &Context(_c)->cSlice_14hrt0rU, 0, m, &cSlice_14hrt0rU_sendMessage);
      break;
    }
    default: {
      cSwitchcase_ZgedWkEX_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_DL3Y::cSlice_14hrt0rU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_Yy4Tyw0Y_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_Yy4Tyw0Y_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cVar_sgG0Cozu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_Yy4Tyw0Y_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSend_Yy4Tyw0Y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_FqGBO4JI_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_ml9RiJbb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_CURr8FRb_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_CURr8FRb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 2.0f, 0, m, &cBinop_MuVKzdax_sendMessage);
}

void Heavy_WSTD_DL3Y::cUnop_N2R4SccR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_mOgTeYdZ_sendMessage(_c, 0, m);
  cMsg_dtAhW27G_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cUnop_b08lGPRD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_nqVXzkxg_sendMessage(_c, 0, m);
  cMsg_0A6KnrUN_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_MuVKzdax_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_RecMMboW_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_RecMMboW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_6GyYpHfH_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_H2lXSTpl_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_H2lXSTpl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_vDs2NzuU_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_6GyYpHfH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_qOcxwa1f_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_qOcxwa1f_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_Q2BEmv1E_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_vDs2NzuU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_ChtE435q_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_ChtE435q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_4QDWv7xO_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_Q2BEmv1E_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SQRT, m, &cUnop_N2R4SccR_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_4QDWv7xO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SQRT, m, &cUnop_b08lGPRD_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_DyHG6PTp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_ZALVtxha_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_ZALVtxha_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 2.0f, 0, m, &cBinop_cwMrol8x_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_cwMrol8x_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_8tuUSDQP_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_8tuUSDQP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_OMJO2ouM_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_TGp8kqhQ_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_TGp8kqhQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Q5J2FlPj_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_OMJO2ouM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_5RUIU0me_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_5RUIU0me_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_dfNk3EuK_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_Q5J2FlPj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_5UTCB17i_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_5UTCB17i_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_aQZnEV1n_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_aQZnEV1n_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_3DZOdan0_sendMessage(_c, 0, m);
  cMsg_zAnmedUt_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_dfNk3EuK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_JN2nrkmf_sendMessage(_c, 0, m);
  cMsg_e9PwGiQP_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_acbSyvKa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_3HKzw1Ti_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_3HKzw1Ti_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_SjR9usCl_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_BUFYooSI_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_p9gpRiwY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 1.0f, 0, m, &cBinop_YYzUqEau_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_X3Z1DWtU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_2NCXufhr_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_2NCXufhr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_vDZyFtWU, HV_BINOP_DIVIDE, 1, m, &cBinop_vDZyFtWU_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_SjR9usCl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_cP0OrUki_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_cP0OrUki_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_bz7rz5MB, m);
}

void Heavy_WSTD_DL3Y::cMsg_GJiDTv9o_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_1aY4VhX3_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_1aY4VhX3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_acbSyvKa_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_BUFYooSI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_Nxn0n1oa, m);
}

void Heavy_WSTD_DL3Y::cBinop_YYzUqEau_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 6.28319f, 0, m, &cBinop_ImR8czto_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_ImR8czto_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_vDZyFtWU, HV_BINOP_DIVIDE, 0, m, &cBinop_vDZyFtWU_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_vDZyFtWU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_GJiDTv9o_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_8JgNJjFT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_HmPdMyRe_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_HmPdMyRe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_R0hoW9UM_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_hhARnV3D_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_f5fsM5bC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 1.0f, 0, m, &cBinop_MXf4qcJZ_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_0yH6tCxn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_fVFaxVMB_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_fVFaxVMB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_dteBWwG6, HV_BINOP_DIVIDE, 1, m, &cBinop_dteBWwG6_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_R0hoW9UM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_uj7CdW1q_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_uj7CdW1q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_XjlIYitk, m);
}

void Heavy_WSTD_DL3Y::cMsg_CKhU4fn5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_WP6aq72u_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_WP6aq72u_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_8JgNJjFT_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_hhARnV3D_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_pSVQhfr7, m);
}

void Heavy_WSTD_DL3Y::cBinop_MXf4qcJZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 6.28319f, 0, m, &cBinop_DdhNsFsy_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_DdhNsFsy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_dteBWwG6, HV_BINOP_DIVIDE, 0, m, &cBinop_dteBWwG6_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_dteBWwG6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_CKhU4fn5_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cVar_0NC68WAx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_zvBW6ryn, HV_BINOP_MULTIPLY, 0, m, &cBinop_zvBW6ryn_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_ODRN2cxl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_uAvMiEXX_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_uAvMiEXX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_e2a8LwOM_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_zvBW6ryn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_qZbbW6o7_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_WDQojjOy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_zvBW6ryn, HV_BINOP_MULTIPLY, 1, m, &cBinop_zvBW6ryn_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_e2a8LwOM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 6.28319f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_WDQojjOy_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_qZbbW6o7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_yJVIDW2y_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_yJVIDW2y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_bCllVKdA_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_vnAo5vvj, m);
}

void Heavy_WSTD_DL3Y::cBinop_bCllVKdA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_sWh8fXlY, m);
}

void Heavy_WSTD_DL3Y::cVar_kHK4nvmN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_2ntUgqOq, HV_BINOP_MULTIPLY, 0, m, &cBinop_2ntUgqOq_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_PgT2wnrV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_XTcPhLPs_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_XTcPhLPs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_LQggVhq1_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_2ntUgqOq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_f4WNRCEl_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_fWeebZ2q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_2ntUgqOq, HV_BINOP_MULTIPLY, 1, m, &cBinop_2ntUgqOq_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_LQggVhq1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 6.28319f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_fWeebZ2q_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_f4WNRCEl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_jwO2Px2u_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_jwO2Px2u_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_KzVJRFMj_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_AuPyjV2m, m);
}

void Heavy_WSTD_DL3Y::cBinop_KzVJRFMj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_rSNdaVjm, m);
}

void Heavy_WSTD_DL3Y::sEnv_Fc2FwUTu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_zrFPCNg5_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_TisT6q7f_sendMessage);
}

void Heavy_WSTD_DL3Y::cIf_TIMND7dA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_wwMc8JDp_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 485.0f, 0, m, &cBinop_U1xZogoQ_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cMsg_7bsETjLC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 10.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_Tmo1tkRM, HV_BINOP_POW, 0, m, &cBinop_Tmo1tkRM_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_Tmo1tkRM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_N6sZVsA3_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_HTOt20xc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 20.0f, 0, m, &cBinop_koeJ9Lin_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_zrFPCNg5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_W6vk95Bk_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_TisT6q7f_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_TIMND7dA, 0, m, &cIf_TIMND7dA_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_W6vk95Bk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_TIMND7dA, 1, m, &cIf_TIMND7dA_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_U1xZogoQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 100.0f, 0, m, &cBinop_HTOt20xc_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_wwMc8JDp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cMsg_N6sZVsA3_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_koeJ9Lin_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Tmo1tkRM, HV_BINOP_POW, 1, m, &cBinop_Tmo1tkRM_sendMessage);
  cMsg_7bsETjLC_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cVar_i07OGQvF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_SYsS9lrs, HV_BINOP_MULTIPLY, 0, m, &cBinop_SYsS9lrs_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_P4YmjZAP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_sSFa2ie0_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_sSFa2ie0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_XWO1drVn_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_SYsS9lrs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_yaKqZszS_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_xp2FVi5A_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_SYsS9lrs, HV_BINOP_MULTIPLY, 1, m, &cBinop_SYsS9lrs_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_XWO1drVn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 6.28319f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_xp2FVi5A_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_yaKqZszS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_Jq789yrF_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_Jq789yrF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_PLOLu9Rp_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_p5sKIF0t, m);
}

void Heavy_WSTD_DL3Y::cBinop_PLOLu9Rp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_cm0Aqeru, m);
}

void Heavy_WSTD_DL3Y::cMsg_N6sZVsA3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_x2LrapTU_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_x2LrapTU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_9js6lp04, m);
}

void Heavy_WSTD_DL3Y::sEnv_dgyvxZWQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_cp679j7Q_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_xv8ne2g4_sendMessage);
}

void Heavy_WSTD_DL3Y::cIf_ng40fHrz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_Gde5G1Qq_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 485.0f, 0, m, &cBinop_WIxNL7ua_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cMsg_s3LJeaFa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 10.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_CkY2Xpwr, HV_BINOP_POW, 0, m, &cBinop_CkY2Xpwr_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_CkY2Xpwr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_x9CuCbSA_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_9JGTKj19_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 20.0f, 0, m, &cBinop_5oeMUaxf_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_cp679j7Q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_Juf8ECjr_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_xv8ne2g4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_ng40fHrz, 0, m, &cIf_ng40fHrz_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_Juf8ECjr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_ng40fHrz, 1, m, &cIf_ng40fHrz_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_WIxNL7ua_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 100.0f, 0, m, &cBinop_9JGTKj19_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_Gde5G1Qq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cMsg_x9CuCbSA_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_5oeMUaxf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_CkY2Xpwr, HV_BINOP_POW, 1, m, &cBinop_CkY2Xpwr_sendMessage);
  cMsg_s3LJeaFa_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cVar_Nw1VAyFT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_uXDiHPaY, HV_BINOP_MULTIPLY, 0, m, &cBinop_uXDiHPaY_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_YII4m8h9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_ggmpZs8N_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_ggmpZs8N_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_UAdR4SQW_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_uXDiHPaY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_fM0jmE7H_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_AO9Qzd6k_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_uXDiHPaY, HV_BINOP_MULTIPLY, 1, m, &cBinop_uXDiHPaY_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_UAdR4SQW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 6.28319f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_AO9Qzd6k_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_fM0jmE7H_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_HJLhWT91_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_HJLhWT91_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_vOtcbl56_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_oMwLJBxs, m);
}

void Heavy_WSTD_DL3Y::cBinop_vOtcbl56_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_Jskw2RVu, m);
}

void Heavy_WSTD_DL3Y::cMsg_x9CuCbSA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_noqGab5p_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_noqGab5p_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_Oil0y0OV, m);
}

void Heavy_WSTD_DL3Y::cSwitchcase_OPXeeo74_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xF1E7CD16: { // "feedback"
      cSlice_onMessage(_c, &Context(_c)->cSlice_QXsvNn6o, 0, m, &cSlice_QXsvNn6o_sendMessage);
      break;
    }
    default: {
      cSwitchcase_tEYBcRoD_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_DL3Y::cSlice_QXsvNn6o_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_BfomDmu5_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_BfomDmu5_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cVar_6kgkAgWl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_BfomDmu5_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSend_BfomDmu5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_gCesg3MU_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cMsg_vDpAiXDy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_Adl941zr_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_Adl941zr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_k1GxJLnj_sendMessage);
}

void Heavy_WSTD_DL3Y::cDelay_eya7hvUT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_eya7hvUT, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_RAeUuBFj, 0, m, &cDelay_RAeUuBFj_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_eya7hvUT, 0, m, &cDelay_eya7hvUT_sendMessage);
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_y4gtSZuo, 1, m, NULL);
}

void Heavy_WSTD_DL3Y::cDelay_RAeUuBFj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_RAeUuBFj, m);
  cMsg_9kLVaX5Z_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSwitchcase_GqNuUXm2_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x47BE8354: { // "clear"
      cMsg_HvV8ek6G_sendMessage(_c, 0, m);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_DL3Y::cBinop_2DVq4qbu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_7dvwq1M4_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::hTable_IrqxgK4k_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_vpcXF1Vi_sendMessage(_c, 0, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_eya7hvUT, 2, m, &cDelay_eya7hvUT_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_kVLhovJw_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_7dvwq1M4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "resize");
  msg_setElementToFrom(m, 1, n, 0);
  hTable_onMessage(_c, &Context(_c)->hTable_IrqxgK4k, 0, m, &hTable_IrqxgK4k_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_k1GxJLnj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 5000.0f, 0, m, &cBinop_2DVq4qbu_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_9kLVaX5Z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mirror");
  hTable_onMessage(_c, &Context(_c)->hTable_IrqxgK4k, 0, m, &hTable_IrqxgK4k_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_kVLhovJw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_eya7hvUT, 0, m, &cDelay_eya7hvUT_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_vpcXF1Vi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cDelay_onMessage(_c, &Context(_c)->cDelay_RAeUuBFj, 2, m, &cDelay_RAeUuBFj_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_HvV8ek6G_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_y4gtSZuo, 1, m, NULL);
}

void Heavy_WSTD_DL3Y::cTabhead_YTww5dEa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_zYzmTOnc, HV_BINOP_SUBTRACT, 0, m, &cBinop_zYzmTOnc_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_JdRzeheK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_sQxNz1oe_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_sQxNz1oe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_AsqfAbwW_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_M2Z2Bdn6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_4gl25HI2_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cDelay_xH7p8J9Q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_xH7p8J9Q, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_XQI9J9TW, 0, m, &cDelay_XQI9J9TW_sendMessage);
  sTabread_onMessage(_c, &Context(_c)->sTabread_Ki66563G, 0, m, &sTabread_Ki66563G_sendMessage);
}

void Heavy_WSTD_DL3Y::cDelay_XQI9J9TW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_XQI9J9TW, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_Ki66563G, 0, m, &sTabread_Ki66563G_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_XQI9J9TW, 0, m, &cDelay_XQI9J9TW_sendMessage);
}

void Heavy_WSTD_DL3Y::sTabread_Ki66563G_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_onMessage(_c, &Context(_c)->cBinop_jozbxScZ, HV_BINOP_SUBTRACT, 0, m, &cBinop_jozbxScZ_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cBinop_HPAs9n7R_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_TxkTUEJS, HV_BINOP_MAX, 0, m, &cBinop_TxkTUEJS_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_AsqfAbwW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_HPAs9n7R, HV_BINOP_MULTIPLY, 0, m, &cBinop_HPAs9n7R_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_zYzmTOnc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_ZMOoIMrZ_sendMessage(_c, 0, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_Ki66563G, 0, m, &sTabread_Ki66563G_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_FJfTSA4O_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_VReSsZpe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_jozbxScZ, HV_BINOP_SUBTRACT, 1, m, &cBinop_jozbxScZ_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_XQI9J9TW, 2, m, &cDelay_XQI9J9TW_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_4gl25HI2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(3);
  msg_init(m, 3, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "table");
  msg_setElementToFrom(m, 1, n, 0);
  msg_setSymbol(m, 2, "size");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_VReSsZpe_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_ZMOoIMrZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_xH7p8J9Q, 0, m, &cDelay_xH7p8J9Q_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_XQI9J9TW, 0, m, &cDelay_XQI9J9TW_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_VyzvBsv9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cBinop_onMessage(_c, &Context(_c)->cBinop_TxkTUEJS, HV_BINOP_MAX, 1, m, &cBinop_TxkTUEJS_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_TxkTUEJS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_zYzmTOnc, HV_BINOP_SUBTRACT, 1, m, &cBinop_zYzmTOnc_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_FJfTSA4O_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_xH7p8J9Q, 0, m, &cDelay_xH7p8J9Q_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_EcSjKJoP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_xH7p8J9Q, 2, m, &cDelay_xH7p8J9Q_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_jozbxScZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_EcSjKJoP_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_STNBAAR2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_M2Z2Bdn6, 0, m, &cVar_M2Z2Bdn6_sendMessage);
  cMsg_JdRzeheK_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_YTww5dEa, 0, m, &cTabhead_YTww5dEa_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_Lxy9X2xx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_Z0A8dpKk_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_Z0A8dpKk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_7SiaXQ3a_sendMessage);
}

void Heavy_WSTD_DL3Y::cDelay_ZR4WWq5R_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_ZR4WWq5R, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_sVHWU3FX, 0, m, &cDelay_sVHWU3FX_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_ZR4WWq5R, 0, m, &cDelay_ZR4WWq5R_sendMessage);
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_mx78SL2d, 1, m, NULL);
}

void Heavy_WSTD_DL3Y::cDelay_sVHWU3FX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_sVHWU3FX, m);
  cMsg_wHrn4GQO_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSwitchcase_XVHlzpy6_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x47BE8354: { // "clear"
      cMsg_s9O1VdHj_sendMessage(_c, 0, m);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_DL3Y::cBinop_XfdeoI9p_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_ScRjPuVs_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::hTable_sMKT60V5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_61KJeR4w_sendMessage(_c, 0, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_ZR4WWq5R, 2, m, &cDelay_ZR4WWq5R_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_rvUtrnox_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_ScRjPuVs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "resize");
  msg_setElementToFrom(m, 1, n, 0);
  hTable_onMessage(_c, &Context(_c)->hTable_sMKT60V5, 0, m, &hTable_sMKT60V5_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_7SiaXQ3a_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 5000.0f, 0, m, &cBinop_XfdeoI9p_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_wHrn4GQO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mirror");
  hTable_onMessage(_c, &Context(_c)->hTable_sMKT60V5, 0, m, &hTable_sMKT60V5_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_rvUtrnox_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_ZR4WWq5R, 0, m, &cDelay_ZR4WWq5R_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_61KJeR4w_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cDelay_onMessage(_c, &Context(_c)->cDelay_sVHWU3FX, 2, m, &cDelay_sVHWU3FX_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_s9O1VdHj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_mx78SL2d, 1, m, NULL);
}

void Heavy_WSTD_DL3Y::cTabhead_AB0EoVQC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_lFerc9rX, HV_BINOP_SUBTRACT, 0, m, &cBinop_lFerc9rX_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_VcS3ypjv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_rdDbz4zZ_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_rdDbz4zZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_eLjcpgMF_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_GCGxyoU0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_TlsHi2lu_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cDelay_zhVvmoWd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_zhVvmoWd, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_gnGXyKri, 0, m, &cDelay_gnGXyKri_sendMessage);
  sTabread_onMessage(_c, &Context(_c)->sTabread_eB7Wnq0r, 0, m, &sTabread_eB7Wnq0r_sendMessage);
}

void Heavy_WSTD_DL3Y::cDelay_gnGXyKri_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_gnGXyKri, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_eB7Wnq0r, 0, m, &sTabread_eB7Wnq0r_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_gnGXyKri, 0, m, &cDelay_gnGXyKri_sendMessage);
}

void Heavy_WSTD_DL3Y::sTabread_eB7Wnq0r_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_onMessage(_c, &Context(_c)->cBinop_RYzivXuw, HV_BINOP_SUBTRACT, 0, m, &cBinop_RYzivXuw_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cBinop_xqtIj8qn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_n5l7yLAb, HV_BINOP_MAX, 0, m, &cBinop_n5l7yLAb_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_eLjcpgMF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_xqtIj8qn, HV_BINOP_MULTIPLY, 0, m, &cBinop_xqtIj8qn_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_lFerc9rX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_f0LCE4bC_sendMessage(_c, 0, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_eB7Wnq0r, 0, m, &sTabread_eB7Wnq0r_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_ypT5LtX1_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_NBrRg06u_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_RYzivXuw, HV_BINOP_SUBTRACT, 1, m, &cBinop_RYzivXuw_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_gnGXyKri, 2, m, &cDelay_gnGXyKri_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_TlsHi2lu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(3);
  msg_init(m, 3, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "table");
  msg_setElementToFrom(m, 1, n, 0);
  msg_setSymbol(m, 2, "size");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_NBrRg06u_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_f0LCE4bC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_zhVvmoWd, 0, m, &cDelay_zhVvmoWd_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_gnGXyKri, 0, m, &cDelay_gnGXyKri_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_eMNjziw3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cBinop_onMessage(_c, &Context(_c)->cBinop_n5l7yLAb, HV_BINOP_MAX, 1, m, &cBinop_n5l7yLAb_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_n5l7yLAb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_lFerc9rX, HV_BINOP_SUBTRACT, 1, m, &cBinop_lFerc9rX_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_ypT5LtX1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_zhVvmoWd, 0, m, &cDelay_zhVvmoWd_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_bZo2W32W_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_zhVvmoWd, 2, m, &cDelay_zhVvmoWd_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_RYzivXuw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_bZo2W32W_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_C9srez2x_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_GCGxyoU0, 0, m, &cVar_GCGxyoU0_sendMessage);
  cMsg_VcS3ypjv_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_AB0EoVQC, 0, m, &cTabhead_AB0EoVQC_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_mOgTeYdZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_niE7Roxi, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_nqVXzkxg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_9mRyU1XX, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_0A6KnrUN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_SVK5Lfak, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_dtAhW27G_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_x8L4Bppn, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_e9PwGiQP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_OoW2tnBA, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_3DZOdan0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_RyNHE90j, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_JN2nrkmf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_kaN9YYzc, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_zAnmedUt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_a4uwy9Q6, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cVar_kIXdwy0B_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_DTrGcsSw_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_X76FNiKN_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_NLLXF8su_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_DTrGcsSw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_kIXdwy0B, 1, m, &cVar_kIXdwy0B_sendMessage);
}

void Heavy_WSTD_DL3Y::cIf_4E0mx7xZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cVar_onMessage(_c, &Context(_c)->cVar_9YoovCgO, 0, m, &cVar_9YoovCgO_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cIf_cYbjIEwg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cVar_onMessage(_c, &Context(_c)->cVar_9YoovCgO, 0, m, &cVar_9YoovCgO_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cVar_bygDHTwS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_cYbjIEwg, 0, m, &cIf_cYbjIEwg_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_5OeLi2PR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_4E0mx7xZ, 0, m, &cIf_4E0mx7xZ_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_w0UJb77V_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_5B8SxTP0_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_tIILTXHZ_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_c3VRRKMK_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_5B8SxTP0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_w0UJb77V, 1, m, &cVar_w0UJb77V_sendMessage);
}

void Heavy_WSTD_DL3Y::cIf_UGKlxazr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cVar_onMessage(_c, &Context(_c)->cVar_Oj2gIYut, 0, m, &cVar_Oj2gIYut_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cIf_DRtmG87B_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cVar_onMessage(_c, &Context(_c)->cVar_Oj2gIYut, 0, m, &cVar_Oj2gIYut_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cVar_mBcpjVe2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_DRtmG87B, 0, m, &cIf_DRtmG87B_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_mmbbtOih_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_UGKlxazr, 0, m, &cIf_UGKlxazr_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_cbvDoQC5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_N0fFYN0c_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_D2olcUeV_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_XIWaVrRx_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_N0fFYN0c_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_cbvDoQC5, 1, m, &cVar_cbvDoQC5_sendMessage);
}

void Heavy_WSTD_DL3Y::cIf_gRaeQ2EU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cVar_onMessage(_c, &Context(_c)->cVar_GLlfoVCt, 0, m, &cVar_GLlfoVCt_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cIf_w0pkS7Na_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cVar_onMessage(_c, &Context(_c)->cVar_GLlfoVCt, 0, m, &cVar_GLlfoVCt_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cVar_QtEArDxH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_w0pkS7Na, 0, m, &cIf_w0pkS7Na_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_uIFXUWX6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_gRaeQ2EU, 0, m, &cIf_gRaeQ2EU_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_9TDEEqkB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_jqHJQteq, HV_BINOP_DIVIDE, 0, m, &cBinop_jqHJQteq_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_tUXcndqK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_b7b1yUvH, HV_BINOP_MULTIPLY, 1, m, &cBinop_b7b1yUvH_sendMessage);
}

void Heavy_WSTD_DL3Y::cSwitchcase_HFZJHr4m_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xFFFFFFFF: { // "bang"
      cSlice_onMessage(_c, &Context(_c)->cSlice_UhiVaR2m, 0, m, &cSlice_UhiVaR2m_sendMessage);
      break;
    }
    case 0x3E004DAB: { // "set"
      cSlice_onMessage(_c, &Context(_c)->cSlice_8rUGmXSw, 0, m, &cSlice_8rUGmXSw_sendMessage);
      break;
    }
    default: {
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Hqq2HrN5_sendMessage);
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_hvjBQDHZ_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_DL3Y::cSlice_UhiVaR2m_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cVar_onMessage(_c, &Context(_c)->cVar_wK93Cuqb, 0, m, &cVar_wK93Cuqb_sendMessage);
      break;
    }
    case 1: {
      cVar_onMessage(_c, &Context(_c)->cVar_wK93Cuqb, 0, m, &cVar_wK93Cuqb_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cSlice_8rUGmXSw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cBinop_onMessage(_c, &Context(_c)->cBinop_oQ5TJkgY, HV_BINOP_NEQ, 1, m, &cBinop_oQ5TJkgY_sendMessage);
      cVar_onMessage(_c, &Context(_c)->cVar_wK93Cuqb, 1, m, &cVar_wK93Cuqb_sendMessage);
      break;
    }
    case 1: {
      cBinop_onMessage(_c, &Context(_c)->cBinop_oQ5TJkgY, HV_BINOP_NEQ, 1, m, &cBinop_oQ5TJkgY_sendMessage);
      cVar_onMessage(_c, &Context(_c)->cVar_wK93Cuqb, 1, m, &cVar_wK93Cuqb_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cVar_wK93Cuqb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 5000.0f, 0, m, &cBinop_bZTD4Yge_sendMessage);
}

void Heavy_WSTD_DL3Y::cIf_fNJUTMgA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_gu6LxIdv_sendMessage);
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_6WElTBhF_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cCast_6WElTBhF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_wK93Cuqb, 0, m, &cVar_wK93Cuqb_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_gu6LxIdv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_oQ5TJkgY, HV_BINOP_NEQ, 1, m, &cBinop_oQ5TJkgY_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_oQ5TJkgY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_fNJUTMgA, 1, m, &cIf_fNJUTMgA_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_hvjBQDHZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_fNJUTMgA, 0, m, &cIf_fNJUTMgA_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_Hqq2HrN5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_oQ5TJkgY, HV_BINOP_NEQ, 0, m, &cBinop_oQ5TJkgY_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_RiZ9gdfi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_JAntoa6s_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_ZUzv6jFL_sendMessage);
}

void Heavy_WSTD_DL3Y::cSwitchcase_OGqBDFom_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x0: { // "0.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_oevZuLVP_sendMessage);
      break;
    }
    case 0x3F800000: { // "1.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_lS5DuT51_sendMessage);
      break;
    }
    case 0x40000000: { // "2.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_WLF39j3T_sendMessage);
      break;
    }
    case 0x40400000: { // "3.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_koL0v0Bk_sendMessage);
      break;
    }
    case 0x40800000: { // "4.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_zzW2aME3_sendMessage);
      break;
    }
    case 0x40A00000: { // "5.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_QB3mqeyI_sendMessage);
      break;
    }
    case 0x40C00000: { // "6.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_LdHZzmh0_sendMessage);
      break;
    }
    case 0x40E00000: { // "7.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_mCv6b0zy_sendMessage);
      break;
    }
    case 0x41000000: { // "8.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_ltMMcrte_sendMessage);
      break;
    }
    case 0x41100000: { // "9.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_MttpP8QK_sendMessage);
      break;
    }
    case 0x41200000: { // "10.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_aZevV71s_sendMessage);
      break;
    }
    case 0x41300000: { // "11.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Y6IVNu9D_sendMessage);
      break;
    }
    case 0x41400000: { // "12.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_h3sbIZjr_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_DL3Y::cCast_oevZuLVP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_ZfBB2dbH_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_lS5DuT51_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_BDUphS2Z_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_WLF39j3T_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_5awl5Ig7_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_koL0v0Bk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_ZvKxxthN_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_zzW2aME3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_xZFYT1Fo_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_QB3mqeyI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_pvWsnyPJ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_LdHZzmh0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Jx1TOP1w_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_mCv6b0zy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_y6xNNnE6_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_ltMMcrte_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_GXsWwYky_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_MttpP8QK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_G1MRHWQO_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_aZevV71s_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_8ZcjxtVo_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_Y6IVNu9D_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_q9xS88Vx_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_h3sbIZjr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_DjSkuaut_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_jqHJQteq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_b7b1yUvH, HV_BINOP_MULTIPLY, 0, m, &cBinop_b7b1yUvH_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_b7b1yUvH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_HFZJHr4m_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cCast_ZUzv6jFL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_9TDEEqkB, 0, m, &cVar_9TDEEqkB_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_tUXcndqK, 0, m, &cVar_tUXcndqK_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_JAntoa6s_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_jqHJQteq, HV_BINOP_DIVIDE, 1, m, &cBinop_jqHJQteq_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_wfnSIIoj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_9TDEEqkB, 0, m, &cVar_9TDEEqkB_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_QtK8sRLu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_tUXcndqK, 0, m, &cVar_tUXcndqK_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_ZfBB2dbH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.166667f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_QtK8sRLu_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_wfnSIIoj_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_BDUphS2Z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.2f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_QtK8sRLu_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_wfnSIIoj_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_5awl5Ig7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.25f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_QtK8sRLu_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_wfnSIIoj_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_ZvKxxthN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.333333f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_QtK8sRLu_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_wfnSIIoj_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_xZFYT1Fo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.6f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_QtK8sRLu_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_wfnSIIoj_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_pvWsnyPJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.666667f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_QtK8sRLu_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_wfnSIIoj_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_Jx1TOP1w_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_QtK8sRLu_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_wfnSIIoj_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_y6xNNnE6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.5f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_QtK8sRLu_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_wfnSIIoj_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_GXsWwYky_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 2.0f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_QtK8sRLu_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_wfnSIIoj_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_G1MRHWQO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 3.0f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_QtK8sRLu_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_wfnSIIoj_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_8ZcjxtVo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 4.0f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_QtK8sRLu_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_wfnSIIoj_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_q9xS88Vx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 5.0f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_QtK8sRLu_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_wfnSIIoj_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_DjSkuaut_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 6.0f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_QtK8sRLu_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_wfnSIIoj_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_jYcs3olk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_CuUXefTh, HV_BINOP_DIVIDE, 0, m, &cBinop_CuUXefTh_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_clTJRlkJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_q0bELRkH, HV_BINOP_MULTIPLY, 1, m, &cBinop_q0bELRkH_sendMessage);
}

void Heavy_WSTD_DL3Y::cSwitchcase_NUWr03Ii_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xFFFFFFFF: { // "bang"
      cSlice_onMessage(_c, &Context(_c)->cSlice_duQdGCpt, 0, m, &cSlice_duQdGCpt_sendMessage);
      break;
    }
    case 0x3E004DAB: { // "set"
      cSlice_onMessage(_c, &Context(_c)->cSlice_HhiJU4ZA, 0, m, &cSlice_HhiJU4ZA_sendMessage);
      break;
    }
    default: {
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_07vg6SgT_sendMessage);
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_FjBsRbzL_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_DL3Y::cSlice_duQdGCpt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cVar_onMessage(_c, &Context(_c)->cVar_S2l4jjOH, 0, m, &cVar_S2l4jjOH_sendMessage);
      break;
    }
    case 1: {
      cVar_onMessage(_c, &Context(_c)->cVar_S2l4jjOH, 0, m, &cVar_S2l4jjOH_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cSlice_HhiJU4ZA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cBinop_onMessage(_c, &Context(_c)->cBinop_R0MTo50K, HV_BINOP_NEQ, 1, m, &cBinop_R0MTo50K_sendMessage);
      cVar_onMessage(_c, &Context(_c)->cVar_S2l4jjOH, 1, m, &cVar_S2l4jjOH_sendMessage);
      break;
    }
    case 1: {
      cBinop_onMessage(_c, &Context(_c)->cBinop_R0MTo50K, HV_BINOP_NEQ, 1, m, &cBinop_R0MTo50K_sendMessage);
      cVar_onMessage(_c, &Context(_c)->cVar_S2l4jjOH, 1, m, &cVar_S2l4jjOH_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cVar_S2l4jjOH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 5000.0f, 0, m, &cBinop_IM9skRDO_sendMessage);
}

void Heavy_WSTD_DL3Y::cIf_EweT7bkT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Mh7Vz5mC_sendMessage);
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Ij9tEUJW_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cCast_Mh7Vz5mC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_R0MTo50K, HV_BINOP_NEQ, 1, m, &cBinop_R0MTo50K_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_Ij9tEUJW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_S2l4jjOH, 0, m, &cVar_S2l4jjOH_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_R0MTo50K_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_EweT7bkT, 1, m, &cIf_EweT7bkT_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_FjBsRbzL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_EweT7bkT, 0, m, &cIf_EweT7bkT_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_07vg6SgT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_R0MTo50K, HV_BINOP_NEQ, 0, m, &cBinop_R0MTo50K_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_ZIJljrpu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_gOL5MHyr_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_NgtxQBFK_sendMessage);
}

void Heavy_WSTD_DL3Y::cSwitchcase_qWiRRHUC_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x0: { // "0.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_cvxyPe4X_sendMessage);
      break;
    }
    case 0x3F800000: { // "1.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_8XKQgdvF_sendMessage);
      break;
    }
    case 0x40000000: { // "2.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_D3ZulYEO_sendMessage);
      break;
    }
    case 0x40400000: { // "3.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_g5rOnhIe_sendMessage);
      break;
    }
    case 0x40800000: { // "4.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Ln6RVwDW_sendMessage);
      break;
    }
    case 0x40A00000: { // "5.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_lOGmKlYZ_sendMessage);
      break;
    }
    case 0x40C00000: { // "6.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_H1E05GZv_sendMessage);
      break;
    }
    case 0x40E00000: { // "7.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_NXwQYh6g_sendMessage);
      break;
    }
    case 0x41000000: { // "8.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_JRWaY2Wm_sendMessage);
      break;
    }
    case 0x41100000: { // "9.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_ZiMGSjb0_sendMessage);
      break;
    }
    case 0x41200000: { // "10.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_eJymvTJ3_sendMessage);
      break;
    }
    case 0x41300000: { // "11.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_6HJovPbY_sendMessage);
      break;
    }
    case 0x41400000: { // "12.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_hyaBxfI4_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_DL3Y::cCast_cvxyPe4X_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_NQjq2GQS_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_8XKQgdvF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_2y1kEwS0_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_D3ZulYEO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_ZEFAylI8_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_g5rOnhIe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_SsecaXz5_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_Ln6RVwDW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_spRMEma2_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_lOGmKlYZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_3zUo0POb_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_H1E05GZv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_cYMy228c_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_NXwQYh6g_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_N84DfKcI_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_JRWaY2Wm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Fzt6hpwL_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_ZiMGSjb0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_P3PltmwF_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_eJymvTJ3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_kzSWh55T_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_6HJovPbY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_xWujF6NP_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_hyaBxfI4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_p9nScuKZ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_CuUXefTh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_q0bELRkH, HV_BINOP_MULTIPLY, 0, m, &cBinop_q0bELRkH_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_q0bELRkH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_NUWr03Ii_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cCast_NgtxQBFK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_jYcs3olk, 0, m, &cVar_jYcs3olk_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_clTJRlkJ, 0, m, &cVar_clTJRlkJ_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_gOL5MHyr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_CuUXefTh, HV_BINOP_DIVIDE, 1, m, &cBinop_CuUXefTh_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_q04o8oUR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_jYcs3olk, 0, m, &cVar_jYcs3olk_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_hXDBit5W_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_clTJRlkJ, 0, m, &cVar_clTJRlkJ_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_NQjq2GQS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.166667f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_hXDBit5W_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_q04o8oUR_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_2y1kEwS0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.2f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_hXDBit5W_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_q04o8oUR_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_ZEFAylI8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.25f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_hXDBit5W_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_q04o8oUR_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_SsecaXz5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.333333f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_hXDBit5W_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_q04o8oUR_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_spRMEma2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.6f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_hXDBit5W_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_q04o8oUR_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_3zUo0POb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.666667f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_hXDBit5W_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_q04o8oUR_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_cYMy228c_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_hXDBit5W_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_q04o8oUR_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_N84DfKcI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.5f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_hXDBit5W_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_q04o8oUR_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_Fzt6hpwL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 2.0f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_hXDBit5W_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_q04o8oUR_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_P3PltmwF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 3.0f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_hXDBit5W_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_q04o8oUR_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_kzSWh55T_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 4.0f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_hXDBit5W_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_q04o8oUR_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_xWujF6NP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 5.0f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_hXDBit5W_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_q04o8oUR_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_p9nScuKZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 6.0f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_hXDBit5W_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_q04o8oUR_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_bKxZotT7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_nkyi6NUG, HV_BINOP_DIVIDE, 0, m, &cBinop_nkyi6NUG_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_R61GhKrT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_pJz6ph0a, HV_BINOP_MULTIPLY, 1, m, &cBinop_pJz6ph0a_sendMessage);
}

void Heavy_WSTD_DL3Y::cSwitchcase_V7LedPAb_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xFFFFFFFF: { // "bang"
      cSlice_onMessage(_c, &Context(_c)->cSlice_K0qn4FB5, 0, m, &cSlice_K0qn4FB5_sendMessage);
      break;
    }
    case 0x3E004DAB: { // "set"
      cSlice_onMessage(_c, &Context(_c)->cSlice_D2kzrYKa, 0, m, &cSlice_D2kzrYKa_sendMessage);
      break;
    }
    default: {
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_LQRBidDE_sendMessage);
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Bo3vYWpI_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_DL3Y::cSlice_K0qn4FB5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cVar_onMessage(_c, &Context(_c)->cVar_2Dnnx7oU, 0, m, &cVar_2Dnnx7oU_sendMessage);
      break;
    }
    case 1: {
      cVar_onMessage(_c, &Context(_c)->cVar_2Dnnx7oU, 0, m, &cVar_2Dnnx7oU_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cSlice_D2kzrYKa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cBinop_onMessage(_c, &Context(_c)->cBinop_gtkwbS5i, HV_BINOP_NEQ, 1, m, &cBinop_gtkwbS5i_sendMessage);
      cVar_onMessage(_c, &Context(_c)->cVar_2Dnnx7oU, 1, m, &cVar_2Dnnx7oU_sendMessage);
      break;
    }
    case 1: {
      cBinop_onMessage(_c, &Context(_c)->cBinop_gtkwbS5i, HV_BINOP_NEQ, 1, m, &cBinop_gtkwbS5i_sendMessage);
      cVar_onMessage(_c, &Context(_c)->cVar_2Dnnx7oU, 1, m, &cVar_2Dnnx7oU_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cVar_2Dnnx7oU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 5000.0f, 0, m, &cBinop_KxvYn6Y7_sendMessage);
}

void Heavy_WSTD_DL3Y::cIf_8h2gezBs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_h1OA8B6E_sendMessage);
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_nZ35YKkD_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cCast_h1OA8B6E_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_gtkwbS5i, HV_BINOP_NEQ, 1, m, &cBinop_gtkwbS5i_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_nZ35YKkD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_2Dnnx7oU, 0, m, &cVar_2Dnnx7oU_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_gtkwbS5i_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_8h2gezBs, 1, m, &cIf_8h2gezBs_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_LQRBidDE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_gtkwbS5i, HV_BINOP_NEQ, 0, m, &cBinop_gtkwbS5i_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_Bo3vYWpI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_8h2gezBs, 0, m, &cIf_8h2gezBs_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_5YQWFGru_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_oOsZJUsw_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_JCsdWT19_sendMessage);
}

void Heavy_WSTD_DL3Y::cSwitchcase_sejOqofo_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x0: { // "0.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_IFIHjlmu_sendMessage);
      break;
    }
    case 0x3F800000: { // "1.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_2QFP1RSp_sendMessage);
      break;
    }
    case 0x40000000: { // "2.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_prkoNlKs_sendMessage);
      break;
    }
    case 0x40400000: { // "3.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_bbjNTWLF_sendMessage);
      break;
    }
    case 0x40800000: { // "4.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_aw5L8dZ9_sendMessage);
      break;
    }
    case 0x40A00000: { // "5.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_OygiCnJ9_sendMessage);
      break;
    }
    case 0x40C00000: { // "6.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_eR8zWzaR_sendMessage);
      break;
    }
    case 0x40E00000: { // "7.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_eCNiZAx6_sendMessage);
      break;
    }
    case 0x41000000: { // "8.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Qr3CXROI_sendMessage);
      break;
    }
    case 0x41100000: { // "9.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_N6FJBUKl_sendMessage);
      break;
    }
    case 0x41200000: { // "10.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_aT2s4nAG_sendMessage);
      break;
    }
    case 0x41300000: { // "11.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_gHudJssi_sendMessage);
      break;
    }
    case 0x41400000: { // "12.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_nXzmGYwP_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_DL3Y::cCast_IFIHjlmu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_OwUj0bC8_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_2QFP1RSp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_7g7kJxp2_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_prkoNlKs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_S821ah58_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_bbjNTWLF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_0vYOog98_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_aw5L8dZ9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_SuNUsiS1_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_OygiCnJ9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_879w5B8K_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_eR8zWzaR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_mCP2xx5I_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_eCNiZAx6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_gBnqgnvT_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_Qr3CXROI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_vNiqxMay_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_N6FJBUKl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_QqS8gUxe_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_aT2s4nAG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_skAJWaWn_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_gHudJssi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_dciPU1t7_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_nXzmGYwP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Fso0zIRF_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_nkyi6NUG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_pJz6ph0a, HV_BINOP_MULTIPLY, 0, m, &cBinop_pJz6ph0a_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_pJz6ph0a_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_V7LedPAb_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cCast_JCsdWT19_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_bKxZotT7, 0, m, &cVar_bKxZotT7_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_R61GhKrT, 0, m, &cVar_R61GhKrT_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_oOsZJUsw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_nkyi6NUG, HV_BINOP_DIVIDE, 1, m, &cBinop_nkyi6NUG_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_lHUUIXPZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_bKxZotT7, 0, m, &cVar_bKxZotT7_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_EY7iUzkS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_R61GhKrT, 0, m, &cVar_R61GhKrT_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_OwUj0bC8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.166667f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_EY7iUzkS_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_lHUUIXPZ_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_7g7kJxp2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.2f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_EY7iUzkS_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_lHUUIXPZ_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_S821ah58_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.25f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_EY7iUzkS_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_lHUUIXPZ_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_0vYOog98_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.333333f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_EY7iUzkS_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_lHUUIXPZ_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_SuNUsiS1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.6f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_EY7iUzkS_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_lHUUIXPZ_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_879w5B8K_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.666667f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_EY7iUzkS_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_lHUUIXPZ_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_mCP2xx5I_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_EY7iUzkS_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_lHUUIXPZ_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_gBnqgnvT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.5f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_EY7iUzkS_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_lHUUIXPZ_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_vNiqxMay_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 2.0f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_EY7iUzkS_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_lHUUIXPZ_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_QqS8gUxe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 3.0f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_EY7iUzkS_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_lHUUIXPZ_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_skAJWaWn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 4.0f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_EY7iUzkS_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_lHUUIXPZ_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_dciPU1t7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 5.0f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_EY7iUzkS_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_lHUUIXPZ_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_Fso0zIRF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 6.0f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_EY7iUzkS_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_lHUUIXPZ_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_LhJwYxV7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "highvol");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_Amd4Up9p_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_YIA9jJ1e_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_uxijuReR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "midvol");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_Amd4Up9p_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_YIA9jJ1e_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_C2zxQfrF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "lowvol");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_Amd4Up9p_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_YIA9jJ1e_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_4mpoI0A4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "midfreq");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_Amd4Up9p_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_YIA9jJ1e_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_8iXIUQVu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "midq");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_Amd4Up9p_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_YIA9jJ1e_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_U7AaBDve_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1337.0f);
  cVar_onMessage(_c, &Context(_c)->cVar_RbeHcJn5, 0, m, &cVar_RbeHcJn5_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_9GHcORZj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cVar_onMessage(_c, &Context(_c)->cVar_CAfcGm5J, 0, m, &cVar_CAfcGm5J_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_Nsfw9KW9, 0, m, &cVar_Nsfw9KW9_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_I1b5BD5b, 0, m, &cVar_I1b5BD5b_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_hI6xNjxN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mix");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_PnARe7p9_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_So4MoX0j_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "feedback");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_PnARe7p9_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cBinop_Soq1QVGW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_igu0BTw1, 0, m, &cVar_igu0BTw1_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_uQ8WQmM2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_brJ0rktj, 0, m, &cVar_brJ0rktj_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_Am8UMiWa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_2zFWbvLP, 0, m, &cVar_2zFWbvLP_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_vDyNm3w3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "time");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_PnARe7p9_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_LGwr6hdG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "cross");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_PnARe7p9_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_slgu9tjq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mix");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_4qLxAKUq_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_9kVKMcGz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "feedback");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_4qLxAKUq_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cBinop_5PZvDVrZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_CzXRd8w7, 0, m, &cVar_CzXRd8w7_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_nH0nrTM3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_utldGmWc, 0, m, &cVar_utldGmWc_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_DDRv4WO6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_AgaacGEk, 0, m, &cVar_AgaacGEk_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_WUI9ScYI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "time");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_4qLxAKUq_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_WGmRTWur_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "cross");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_4qLxAKUq_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_5X0sM6NA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mix");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_nm4vjRhT_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_9um9APAF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "feedback");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_nm4vjRhT_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cBinop_b8txIxpG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_RMfHDcbx, 0, m, &cVar_RMfHDcbx_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_wrxTbtYV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_u5wTkiVb, 0, m, &cVar_u5wTkiVb_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_neOZsrdn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_YPtaGY32, 0, m, &cVar_YPtaGY32_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_nfk2HlP0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "time");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_nm4vjRhT_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_i7Y7nMeF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "cross");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_nm4vjRhT_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cBinop_bZTD4Yge_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_5OeLi2PR, 0, m, &cVar_5OeLi2PR_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_NLLXF8su_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_NMyaLAjk_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_2KUvR0zW_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_X76FNiKN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_B2wywmU6_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_cvagazXC_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_cvagazXC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_bygDHTwS, 0, m, &cVar_bygDHTwS_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_B2wywmU6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_cYbjIEwg, 1, m, &cIf_cYbjIEwg_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_NMyaLAjk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_4E0mx7xZ, 1, m, &cIf_4E0mx7xZ_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_2KUvR0zW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_5OeLi2PR, 0, m, &cVar_5OeLi2PR_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_IM9skRDO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_mmbbtOih, 0, m, &cVar_mmbbtOih_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_c3VRRKMK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_viZ66SZI_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_nmrZSeHs_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_tIILTXHZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_QofrgQZl_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_yKJiTyuS_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_yKJiTyuS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_mBcpjVe2, 0, m, &cVar_mBcpjVe2_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_QofrgQZl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_DRtmG87B, 1, m, &cIf_DRtmG87B_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_viZ66SZI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_UGKlxazr, 1, m, &cIf_UGKlxazr_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_nmrZSeHs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_mmbbtOih, 0, m, &cVar_mmbbtOih_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_KxvYn6Y7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_uIFXUWX6, 0, m, &cVar_uIFXUWX6_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_XIWaVrRx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_jgIiBg7A_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_QW7TihLa_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_D2olcUeV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_w4VIGDGM_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_cA0jNcaa_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_cA0jNcaa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_QtEArDxH, 0, m, &cVar_QtEArDxH_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_w4VIGDGM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_w0pkS7Na, 1, m, &cIf_w0pkS7Na_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_QW7TihLa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_uIFXUWX6, 0, m, &cVar_uIFXUWX6_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_jgIiBg7A_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_gRaeQ2EU, 1, m, &cIf_gRaeQ2EU_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_DhnmRIRV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_CAfcGm5J, 0, m, &cVar_CAfcGm5J_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_1UxWgfmE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_Nsfw9KW9, 0, m, &cVar_Nsfw9KW9_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_DxIYaIkG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_I1b5BD5b, 0, m, &cVar_I1b5BD5b_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_8ybRmWrE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_xg37TT1N, 0, m, &cVar_xg37TT1N_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_KNUZbcmp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_4kDXypRM_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_iqSM28aH_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_AmcmQOld_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_CM4syyST_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_CNYnHq3B_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_pQlRLWsr_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_XPf1l4OY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_aD1fRhhh_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_PrcC6E73_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_ro1HN8Vj_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_zn8Hzm46_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Ga9aeSqU_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_vaNngLpu_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_81O73lrT_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_6LRog841_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_6ES6gOO3_sendMessage(_c, 0, m);
  cMsg_4mwT0bWP_sendMessage(_c, 0, m);
  cMsg_t1v1n1Rn_sendMessage(_c, 0, m);
  cMsg_Y9CAuthn_sendMessage(_c, 0, m);
  cMsg_FBuYZNZB_sendMessage(_c, 0, m);
  cMsg_9CzImQ3O_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_ZfiLw1Az, 0, m, &cVar_ZfiLw1Az_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_xg37TT1N, 0, m, &cVar_xg37TT1N_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_eZ0ffdbI, 0, m, &cVar_eZ0ffdbI_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_sQ0Mn5p5, 0, m, &cVar_sQ0Mn5p5_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_QhKAWvsg, 0, m, &cVar_QhKAWvsg_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_JtZDGlrz, 0, m, &cVar_JtZDGlrz_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_FairG79L, 0, m, &cVar_FairG79L_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_p04F4Mlz, 0, m, &cVar_p04F4Mlz_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_mPZrHPlA, 0, m, &cVar_mPZrHPlA_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_GduW3tXB, 0, m, &cVar_GduW3tXB_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_RIr92EVA, 0, m, &cVar_RIr92EVA_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_UZMfdMEz, 0, m, &cVar_UZMfdMEz_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_brksgLME, 0, m, &cVar_brksgLME_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_ZDCxYx3o, 0, m, &cVar_ZDCxYx3o_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_WGfMUszf, 0, m, &cVar_WGfMUszf_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_pwe93PqJ, 0, m, &cVar_pwe93PqJ_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_qkcK6T8f, 0, m, &cVar_qkcK6T8f_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_N3ZDDLnB, 0, m, &cVar_N3ZDDLnB_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_1oFbqSzK, 0, m, &cVar_1oFbqSzK_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_LECxQEL8, 0, m, &cVar_LECxQEL8_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_Rzf9ZZA3, 0, m, &cVar_Rzf9ZZA3_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_ob9UE0Ca, 0, m, &cVar_ob9UE0Ca_sendMessage);
  cMsg_nSEJxKG5_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_WWPjSuvk, 0, m, &cVar_WWPjSuvk_sendMessage);
  cMsg_rjEOSTA6_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_Z8jQ3ioI, 0, m, &cVar_Z8jQ3ioI_sendMessage);
  cMsg_7Jw3qIUV_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_yckCdJYg, 0, m, &cVar_yckCdJYg_sendMessage);
  cMsg_uIOylhfC_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_rOmtiryS, 0, m, &cVar_rOmtiryS_sendMessage);
  cMsg_P4YmjZAP_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_i07OGQvF, 0, m, &cVar_i07OGQvF_sendMessage);
  cMsg_YII4m8h9_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_Nw1VAyFT, 0, m, &cVar_Nw1VAyFT_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_kGqaLbxA, 0, m, &cVar_kGqaLbxA_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_uRDYsgWq, 0, m, &cVar_uRDYsgWq_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_vDfSlMcQ, 0, m, &cVar_vDfSlMcQ_sendMessage);
  cMsg_IWeqdoDW_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_rsqM1cht, 0, m, &cVar_rsqM1cht_sendMessage);
  cMsg_UWjuzYGn_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_lLSy9atD, 0, m, &cVar_lLSy9atD_sendMessage);
  cMsg_UeS28Aw9_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_GkfmpG8l, 0, m, &cVar_GkfmpG8l_sendMessage);
  cMsg_yJ8BrWp2_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_ciq8E9C3, 0, m, &cVar_ciq8E9C3_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_Q7WTkLnO, 0, m, &cVar_Q7WTkLnO_sendMessage);
  cMsg_f1bGUor2_sendMessage(_c, 0, m);
  cMsg_xX7H6hwX_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_RZS7IiRM, 0, m, &cVar_RZS7IiRM_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_tCSYAsV6, 0, m, &cVar_tCSYAsV6_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_JTOxxBwX, 0, m, &cVar_JTOxxBwX_sendMessage);
  cMsg_kqcY6zvi_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_2KOQ69tv, 0, m, &cVar_2KOQ69tv_sendMessage);
  cMsg_oLLjyamk_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_PWHgirq6, 0, m, &cVar_PWHgirq6_sendMessage);
  cMsg_8Mj9qm8T_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_oycvtVJP, 0, m, &cVar_oycvtVJP_sendMessage);
  cMsg_wnyi5i60_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_6bveOwfp, 0, m, &cVar_6bveOwfp_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_tVDPxd2z, 0, m, &cVar_tVDPxd2z_sendMessage);
  cMsg_Q84xjcUa_sendMessage(_c, 0, m);
  cMsg_ZESufBhy_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_O3SWsKV3, 0, m, &cVar_O3SWsKV3_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_HYHTTl66, 0, m, &cVar_HYHTTl66_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_sgG0Cozu, 0, m, &cVar_sgG0Cozu_sendMessage);
  cMsg_X3Z1DWtU_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_p9gpRiwY, 0, m, &cVar_p9gpRiwY_sendMessage);
  cMsg_0yH6tCxn_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_f5fsM5bC, 0, m, &cVar_f5fsM5bC_sendMessage);
  cMsg_ODRN2cxl_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_0NC68WAx, 0, m, &cVar_0NC68WAx_sendMessage);
  cMsg_PgT2wnrV_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_kHK4nvmN, 0, m, &cVar_kHK4nvmN_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_6kgkAgWl, 0, m, &cVar_6kgkAgWl_sendMessage);
  cMsg_vDpAiXDy_sendMessage(_c, 0, m);
  cMsg_Lxy9X2xx_sendMessage(_c, 0, m);
  cMsg_9GHcORZj_sendMessage(_c, 0, m);
  cMsg_U7AaBDve_sendMessage(_c, 0, m);
  cMsg_BDnJKOqs_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_lV6Yu5SE, 0, m, &cVar_lV6Yu5SE_sendMessage);
  cMsg_hblQ1vuU_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_Val5Nhh7, 0, m, &cTabhead_Val5Nhh7_sendMessage);
  cMsg_WSdZfs02_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_yWl4KRIG, 0, m, &cVar_yWl4KRIG_sendMessage);
  cMsg_hhyjOAd3_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_TZiWyNYt, 0, m, &cTabhead_TZiWyNYt_sendMessage);
  cMsg_3rJsrMb5_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_7BXFbOSu, 0, m, &cVar_7BXFbOSu_sendMessage);
  cMsg_4N0cYNjX_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_yOj6zCUq, 0, m, &cTabhead_yOj6zCUq_sendMessage);
  cMsg_2o6LHiAP_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_PMcml0Ud, 0, m, &cVar_PMcml0Ud_sendMessage);
  cMsg_0AFsn13K_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_xfLdtVPh, 0, m, &cTabhead_xfLdtVPh_sendMessage);
  cMsg_VyzvBsv9_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_M2Z2Bdn6, 0, m, &cVar_M2Z2Bdn6_sendMessage);
  cMsg_JdRzeheK_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_YTww5dEa, 0, m, &cTabhead_YTww5dEa_sendMessage);
  cMsg_eMNjziw3_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_GCGxyoU0, 0, m, &cVar_GCGxyoU0_sendMessage);
  cMsg_VcS3ypjv_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_AB0EoVQC, 0, m, &cTabhead_AB0EoVQC_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_XSYU8plZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Nq5h7LD2, HV_BINOP_MULTIPLY, 0, m, &cBinop_Nq5h7LD2_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_TV0wocMk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_wWpu8Kf8_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_Txp41rW8_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_VcPMgCJS_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -2.0f, 0, m, &cBinop_fAcZqEYY_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_gEJSWdty_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_giNEn7A4_sendMessage);
  cMsg_lTxwcg08_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cReceive_tckQtwuy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_kI17YiMS, HV_BINOP_MULTIPLY, 0, m, &cBinop_kI17YiMS_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_bHuX3FnE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -2.0f, 0, m, &cBinop_NewkBQfR_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_wCwVem92_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_kJrp69nj, HV_BINOP_MULTIPLY, 1, m, &cBinop_kJrp69nj_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_YurfGrt3_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_8nXgBrLd_sendMessage);
  cMsg_OZ5cl7l3_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cReceive_7Howap1y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_CZOdrmYS, HV_BINOP_MULTIPLY, 0, m, &cBinop_CZOdrmYS_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_PCs5kunQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_EvHTMKEu_sendMessage(_c, 0, m);
  cMsg_8g09ynOl_sendMessage(_c, 0, m);
  cMsg_mlyejNnr_sendMessage(_c, 0, m);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -2.0f, 0, m, &cBinop_dX2V9rxQ_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_4BmdDKkp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_lPXdikb1_sendMessage);
  cMsg_He8rX0Jt_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cReceive_VaDMT3H0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_QhKAWvsg, 0, m, &cVar_QhKAWvsg_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_b4NkUvVP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_w6gifh4V_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_q5iXHNv5_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_rR0BErhZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_PvyKmKBh_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_BmrZrW5d_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_YP4ZCnIR_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_lFGs1qrT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_IKU40CNa_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_zsZm9StH_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_LkW8Gvby_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_ClgD7JLd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_1ehz1sNW_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_pm2qkVoh_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_TdyOeeA1_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_QEadFXLQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_6IsKqxwJ, HV_BINOP_MULTIPLY, 0, m, &cBinop_6IsKqxwJ_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_9ZHmxuev_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_HQyGWfHH_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_P4CfTBKH_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_wyVZyaiT_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -2.0f, 0, m, &cBinop_iYpRLzNu_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_Jr9PoLQS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_UqgHXaXv_sendMessage);
  cMsg_izeJwmCt_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cReceive_DVuiQCqz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_zUL40tdL, HV_BINOP_MULTIPLY, 0, m, &cBinop_zUL40tdL_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_bHLlHYrN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -2.0f, 0, m, &cBinop_j3tqZgxb_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_vHn8kUZN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_zYbTzzYB, HV_BINOP_MULTIPLY, 1, m, &cBinop_zYbTzzYB_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_VQtpWLPA_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_h4qUCRqY_sendMessage);
  cMsg_L4bQmfDt_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cReceive_deQuS1az_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_OMghttiD, HV_BINOP_MULTIPLY, 0, m, &cBinop_OMghttiD_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_9yWBWtPf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_kS8PDLiy_sendMessage(_c, 0, m);
  cMsg_9ldVb87g_sendMessage(_c, 0, m);
  cMsg_ElG0Rcu9_sendMessage(_c, 0, m);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -2.0f, 0, m, &cBinop_Xt7U4IDL_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_ObnoyJWH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_qOi5ofqH_sendMessage);
  cMsg_cFQ2Yn1j_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cReceive_BxsoSdTy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_RbeHcJn5, 0, m, &cVar_RbeHcJn5_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_CXQe01Wr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 100.0f, 0, m, &cBinop_Soq1QVGW_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_pXqmSSZT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 100.0f, 0, m, &cBinop_uQ8WQmM2_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_rW434mHn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 100.0f, 0, m, &cBinop_Am8UMiWa_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_akd8OWiH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 100.0f, 0, m, &cBinop_5PZvDVrZ_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_m3M5Hrcr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 100.0f, 0, m, &cBinop_nH0nrTM3_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_1aYFykwI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 100.0f, 0, m, &cBinop_b8txIxpG_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_GTcwaMnS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 100.0f, 0, m, &cBinop_wrxTbtYV_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_e4D4sKeu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 100.0f, 0, m, &cBinop_neOZsrdn_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_wTO2NOAl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 100.0f, 0, m, &cBinop_DDRv4WO6_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_hqHZwhBR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_yqebyBIR, HV_BINOP_MULTIPLY, 1, m, &cBinop_yqebyBIR_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_mf3Mgrbi_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_uDiiH0hO, HV_BINOP_MULTIPLY, 1, m, &cBinop_uDiiH0hO_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_XDF1Y4qb_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_gEkbwGam_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_rsnEfAuG, m);
  sVarf_onMessage(_c, &Context(_c)->sVarf_htdgGcY3, m);
}

void Heavy_WSTD_DL3Y::cReceive_oWkHAwNv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_6OCZnXuU_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_ozcDJoBX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_GpKcERsw_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_riZFAJzg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_qCLGO9Ve, HV_BINOP_MULTIPLY, 1, m, &cBinop_qCLGO9Ve_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_A4vBgq0H_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_C0FcKmSr, HV_BINOP_MULTIPLY, 1, m, &cBinop_C0FcKmSr_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_uh6JQ4AM_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_VQM9ZWSq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_UOaBr7wU, m);
  sVarf_onMessage(_c, &Context(_c)->sVarf_jTrTK7X9, m);
}

void Heavy_WSTD_DL3Y::cReceive_fUAyzHnZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_kCppn525_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_AaZVT2lV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_IUKaSDWY_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_FqGBO4JI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_HPAs9n7R, HV_BINOP_MULTIPLY, 1, m, &cBinop_HPAs9n7R_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_STNBAAR2_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_xqtIj8qn, HV_BINOP_MULTIPLY, 1, m, &cBinop_xqtIj8qn_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_C9srez2x_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_gCesg3MU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_cIcOzDUx, m);
  sVarf_onMessage(_c, &Context(_c)->sVarf_HusMana9, m);
}

void Heavy_WSTD_DL3Y::cReceive_4ULDuD1x_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_ml9RiJbb_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_nj5fstQ3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_DyHG6PTp_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_jty99IHw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_bygDHTwS, 0, m, &cVar_bygDHTwS_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_ALH1b96t_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_kIXdwy0B, 0, m, &cVar_kIXdwy0B_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_wmwjU7mo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_w0UJb77V, 0, m, &cVar_w0UJb77V_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_zXvb9OLs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_mBcpjVe2, 0, m, &cVar_mBcpjVe2_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_tDZitFhc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_QtEArDxH, 0, m, &cVar_QtEArDxH_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_Jbt7g7ZB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_cbvDoQC5, 0, m, &cVar_cbvDoQC5_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_PiMhcv4x_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_RiZ9gdfi, 0, m, &cVar_RiZ9gdfi_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_ZIJljrpu, 0, m, &cVar_ZIJljrpu_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_5YQWFGru, 0, m, &cVar_5YQWFGru_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_RXiQNpFQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_qWiRRHUC_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cReceive_nqS75B1s_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_OGqBDFom_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cReceive_bZsHUM84_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_sejOqofo_onMessage(_c, NULL, 0, m, NULL);
}




/*
 * Context Process Implementation
 */

int Heavy_WSTD_DL3Y::process(float **inputBuffers, float **outputBuffers, int n) {
  while (hLp_hasData(&inQueue)) {
    hv_uint32_t numBytes = 0;
    ReceiverMessagePair *p = reinterpret_cast<ReceiverMessagePair *>(hLp_getReadBuffer(&inQueue, &numBytes));
    hv_assert(numBytes >= sizeof(ReceiverMessagePair));
    scheduleMessageForReceiver(p->receiverHash, &p->msg);
    hLp_consume(&inQueue);
  }

  sendBangToReceiver(0xDD21C0EB); // send to __hv_bang~ on next cycle
  const int n4 = n & ~HV_N_SIMD_MASK; // ensure that the block size is a multiple of HV_N_SIMD

  // temporary signal vars
  hv_bufferf_t Bf0, Bf1, Bf2, Bf3, Bf4, Bf5, Bf6, Bf7, Bf8, Bf9, Bf10, Bf11, Bf12, Bf13;

  // input and output vars
  hv_bufferf_t O0, O1;
  hv_bufferf_t I0, I1;

  // declare and init the zero buffer
  hv_bufferf_t ZERO; __hv_zero_f(VOf(ZERO));

  hv_uint32_t nextBlock = blockStartTimestamp;
  for (int n = 0; n < n4; n += HV_N_SIMD) {

    // process all of the messages for this block
    nextBlock += HV_N_SIMD;
    while (mq_hasMessageBefore(&mq, nextBlock)) {
      MessageNode *const node = mq_peek(&mq);
      node->sendMessage(this, node->let, node->m);
      mq_pop(&mq);
    }

    // load input buffers
    __hv_load_f(inputBuffers[0]+n, VOf(I0));
    __hv_load_f(inputBuffers[1]+n, VOf(I1));

    // zero output buffers
    __hv_zero_f(VOf(O0));
    __hv_zero_f(VOf(O1));

    // process all signal functions
    __hv_line_f(&sLine_tjfMe9MM, VOf(Bf0));
    __hv_line_f(&sLine_JszJzhD3, VOf(Bf1));
    __hv_line_f(&sLine_1cY06L9c, VOf(Bf2));
    __hv_line_f(&sLine_odFAHwqt, VOf(Bf3));
    __hv_line_f(&sLine_OADUECBA, VOf(Bf4));
    __hv_biquad_f(&sBiquad_s_j4t94Qad, VIf(I0), VIf(Bf0), VIf(Bf1), VIf(Bf2), VIf(Bf3), VIf(Bf4), VOf(Bf4));
    __hv_varread_f(&sVarf_B5voVTaw, VOf(Bf3));
    __hv_mul_f(VIf(Bf4), VIf(Bf3), VOf(Bf3));
    __hv_line_f(&sLine_UzeoFWxP, VOf(Bf4));
    __hv_zero_f(VOf(Bf2));
    __hv_line_f(&sLine_IQU3wBHz, VOf(Bf1));
    __hv_line_f(&sLine_1LOJxDlL, VOf(Bf0));
    __hv_line_f(&sLine_yL4tFpa4, VOf(Bf5));
    __hv_biquad_f(&sBiquad_s_48Rnkgld, VIf(I0), VIf(Bf4), VIf(Bf2), VIf(Bf1), VIf(Bf0), VIf(Bf5), VOf(Bf5));
    __hv_varread_f(&sVarf_lCe4YhGH, VOf(Bf0));
    __hv_mul_f(VIf(Bf5), VIf(Bf0), VOf(Bf0));
    __hv_line_f(&sLine_TX5FwKcn, VOf(Bf5));
    __hv_line_f(&sLine_h0IeafQ6, VOf(Bf1));
    __hv_line_f(&sLine_MOlsDCY7, VOf(Bf2));
    __hv_line_f(&sLine_8V9qDnPH, VOf(Bf4));
    __hv_line_f(&sLine_eKThul0W, VOf(Bf6));
    __hv_biquad_f(&sBiquad_s_JYhdy2an, VIf(I0), VIf(Bf5), VIf(Bf1), VIf(Bf2), VIf(Bf4), VIf(Bf6), VOf(Bf6));
    __hv_varread_f(&sVarf_WsH2Fj1A, VOf(Bf4));
    __hv_mul_f(VIf(Bf6), VIf(Bf4), VOf(Bf4));
    __hv_line_f(&sLine_e4l34zLo, VOf(Bf6));
    __hv_line_f(&sLine_74OVcwmx, VOf(Bf2));
    __hv_line_f(&sLine_DmJbhTzl, VOf(Bf1));
    __hv_line_f(&sLine_IoxMYnli, VOf(Bf5));
    __hv_line_f(&sLine_8wRhMg5R, VOf(Bf7));
    __hv_biquad_f(&sBiquad_s_qq8kE3iG, VIf(I1), VIf(Bf6), VIf(Bf2), VIf(Bf1), VIf(Bf5), VIf(Bf7), VOf(Bf7));
    __hv_varread_f(&sVarf_6eWypeeA, VOf(Bf5));
    __hv_mul_f(VIf(Bf7), VIf(Bf5), VOf(Bf5));
    __hv_line_f(&sLine_WSbGCUen, VOf(Bf7));
    __hv_zero_f(VOf(Bf1));
    __hv_line_f(&sLine_aiG7Wo9E, VOf(Bf2));
    __hv_line_f(&sLine_GCNwH7nM, VOf(Bf6));
    __hv_line_f(&sLine_uWJ4q7ai, VOf(Bf8));
    __hv_biquad_f(&sBiquad_s_kRYFXd5Z, VIf(I1), VIf(Bf7), VIf(Bf1), VIf(Bf2), VIf(Bf6), VIf(Bf8), VOf(Bf8));
    __hv_varread_f(&sVarf_QiLGSnW6, VOf(Bf6));
    __hv_mul_f(VIf(Bf8), VIf(Bf6), VOf(Bf6));
    __hv_line_f(&sLine_FkpjCQMp, VOf(Bf8));
    __hv_line_f(&sLine_QfM97MBT, VOf(Bf2));
    __hv_line_f(&sLine_ynWr6gfT, VOf(Bf1));
    __hv_line_f(&sLine_GhL00Fps, VOf(Bf7));
    __hv_line_f(&sLine_gF7VB4kZ, VOf(Bf9));
    __hv_biquad_f(&sBiquad_s_GADxgPxw, VIf(I1), VIf(Bf8), VIf(Bf2), VIf(Bf1), VIf(Bf7), VIf(Bf9), VOf(Bf9));
    __hv_varread_f(&sVarf_GtLHt4EO, VOf(Bf7));
    __hv_mul_f(VIf(Bf9), VIf(Bf7), VOf(Bf7));
    __hv_line_f(&sLine_HbbFySTt, VOf(Bf9));
    __hv_tabread_f(&sTabread_kJnvbcXU, VOf(Bf1));
    __hv_var_k_f(VOf(Bf2), 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f);
    __hv_min_f(VIf(Bf1), VIf(Bf2), VOf(Bf2));
    __hv_var_k_f(VOf(Bf8), -1.0f, -1.0f, -1.0f, -1.0f, -1.0f, -1.0f, -1.0f, -1.0f);
    __hv_max_f(VIf(Bf2), VIf(Bf8), VOf(Bf8));
    __hv_line_f(&sLine_KF6LAt22, VOf(Bf2));
    __hv_mul_f(VIf(Bf8), VIf(Bf2), VOf(Bf2));
    __hv_fma_f(VIf(Bf3), VIf(Bf9), VIf(Bf2), VOf(Bf2));
    __hv_line_f(&sLine_2LHj6sON, VOf(Bf9));
    __hv_tabread_f(&sTabread_KkngDjR1, VOf(Bf8));
    __hv_var_k_f(VOf(Bf10), 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f);
    __hv_min_f(VIf(Bf8), VIf(Bf10), VOf(Bf10));
    __hv_var_k_f(VOf(Bf11), -1.0f, -1.0f, -1.0f, -1.0f, -1.0f, -1.0f, -1.0f, -1.0f);
    __hv_max_f(VIf(Bf10), VIf(Bf11), VOf(Bf11));
    __hv_line_f(&sLine_TLi70L90, VOf(Bf10));
    __hv_mul_f(VIf(Bf11), VIf(Bf10), VOf(Bf10));
    __hv_fma_f(VIf(Bf5), VIf(Bf9), VIf(Bf10), VOf(Bf10));
    __hv_varread_f(&sVarf_r2mW0Z2a, VOf(Bf9));
    __hv_add_f(VIf(Bf3), VIf(Bf9), VOf(Bf9));
    __hv_varread_f(&sVarf_Mi1zyoxV, VOf(Bf3));
    __hv_rpole_f(&sRPole_SqhSUZKF, VIf(Bf9), VIf(Bf3), VOf(Bf3));
    __hv_var_k_f(VOf(Bf9), 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f);
    __hv_del1_f(&sDel1_CPcUJVcf, VIf(Bf3), VOf(Bf11));
    __hv_mul_f(VIf(Bf11), VIf(Bf9), VOf(Bf9));
    __hv_sub_f(VIf(Bf3), VIf(Bf9), VOf(Bf9));
    __hv_varread_f(&sVarf_N4HLeqZs, VOf(Bf3));
    __hv_mul_f(VIf(Bf9), VIf(Bf3), VOf(Bf3));
    __hv_tabwrite_f(&sTabwrite_zzG54XvL, VIf(Bf3));
    __hv_varread_f(&sVarf_RdVPLh9F, VOf(Bf3));
    __hv_add_f(VIf(Bf5), VIf(Bf3), VOf(Bf3));
    __hv_varread_f(&sVarf_fWUdcIdS, VOf(Bf5));
    __hv_rpole_f(&sRPole_f0ECCss9, VIf(Bf3), VIf(Bf5), VOf(Bf5));
    __hv_var_k_f(VOf(Bf3), 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f);
    __hv_del1_f(&sDel1_evHjKKSU, VIf(Bf5), VOf(Bf9));
    __hv_mul_f(VIf(Bf9), VIf(Bf3), VOf(Bf3));
    __hv_sub_f(VIf(Bf5), VIf(Bf3), VOf(Bf3));
    __hv_varread_f(&sVarf_6R98Giqd, VOf(Bf5));
    __hv_mul_f(VIf(Bf3), VIf(Bf5), VOf(Bf5));
    __hv_tabwrite_f(&sTabwrite_tuJIgAub, VIf(Bf5));
    __hv_varread_f(&sVarf_rsnEfAuG, VOf(Bf5));
    __hv_mul_f(VIf(Bf1), VIf(Bf5), VOf(Bf5));
    __hv_line_f(&sLine_3lgQADRC, VOf(Bf1));
    __hv_varread_f(&sVarf_htdgGcY3, VOf(Bf3));
    __hv_mul_f(VIf(Bf8), VIf(Bf3), VOf(Bf3));
    __hv_line_f(&sLine_DZzF4tV1, VOf(Bf8));
    __hv_mul_f(VIf(Bf3), VIf(Bf8), VOf(Bf8));
    __hv_fma_f(VIf(Bf5), VIf(Bf1), VIf(Bf8), VOf(Bf8));
    __hv_varread_f(&sVarf_lBmUzBZX, VOf(Bf1));
    __hv_varread_f(&sVarf_wIXjPGFB, VOf(Bf9));
    __hv_mul_f(VIf(Bf1), VIf(Bf9), VOf(Bf9));
    __hv_varread_f(&sVarf_u841L0ya, VOf(Bf1));
    __hv_rpole_f(&sRPole_vYYUGeTX, VIf(Bf9), VIf(Bf1), VOf(Bf1));
    __hv_mul_f(VIf(Bf8), VIf(Bf1), VOf(Bf1));
    sEnv_process(this, &sEnv_nf33n1xb, VIf(Bf8), &sEnv_nf33n1xb_sendMessage);
    __hv_varread_f(&sVarf_5vvyGBBx, VOf(Bf8));
    __hv_mul_f(VIf(Bf1), VIf(Bf8), VOf(Bf8));
    __hv_varread_f(&sVarf_kjuXP6lV, VOf(Bf1));
    __hv_rpole_f(&sRPole_MqvbMT1E, VIf(Bf8), VIf(Bf1), VOf(Bf1));
    __hv_varwrite_f(&sVarf_r2mW0Z2a, VIf(Bf1));
    __hv_line_f(&sLine_Sb1FCag7, VOf(Bf1));
    __hv_line_f(&sLine_5X6xXqd8, VOf(Bf8));
    __hv_mul_f(VIf(Bf5), VIf(Bf8), VOf(Bf8));
    __hv_fma_f(VIf(Bf3), VIf(Bf1), VIf(Bf8), VOf(Bf8));
    __hv_varread_f(&sVarf_eXOR32gl, VOf(Bf1));
    __hv_varread_f(&sVarf_l5ZeRrZt, VOf(Bf3));
    __hv_mul_f(VIf(Bf1), VIf(Bf3), VOf(Bf3));
    __hv_varread_f(&sVarf_StyVyNVt, VOf(Bf1));
    __hv_rpole_f(&sRPole_ZiJtyvuT, VIf(Bf3), VIf(Bf1), VOf(Bf1));
    __hv_mul_f(VIf(Bf8), VIf(Bf1), VOf(Bf1));
    sEnv_process(this, &sEnv_rVYbO1Pz, VIf(Bf8), &sEnv_rVYbO1Pz_sendMessage);
    __hv_varread_f(&sVarf_f9bgea55, VOf(Bf8));
    __hv_mul_f(VIf(Bf1), VIf(Bf8), VOf(Bf8));
    __hv_varread_f(&sVarf_6ABURnfh, VOf(Bf1));
    __hv_rpole_f(&sRPole_LuqvCwv1, VIf(Bf8), VIf(Bf1), VOf(Bf1));
    __hv_varwrite_f(&sVarf_RdVPLh9F, VIf(Bf1));
    __hv_varwrite_f(&sVarf_E3UXRSkI, VIf(Bf2));
    __hv_varread_f(&sVarf_UmstNUUV, VOf(Bf2));
    __hv_varread_f(&sVarf_HPbTXpUq, VOf(Bf1));
    __hv_line_f(&sLine_4NLpwP81, VOf(Bf8));
    __hv_tabread_f(&sTabread_9U3UNaf4, VOf(Bf3));
    __hv_var_k_f(VOf(Bf5), 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f);
    __hv_min_f(VIf(Bf3), VIf(Bf5), VOf(Bf5));
    __hv_var_k_f(VOf(Bf9), -1.0f, -1.0f, -1.0f, -1.0f, -1.0f, -1.0f, -1.0f, -1.0f);
    __hv_max_f(VIf(Bf5), VIf(Bf9), VOf(Bf9));
    __hv_line_f(&sLine_lG3rgYD3, VOf(Bf5));
    __hv_mul_f(VIf(Bf9), VIf(Bf5), VOf(Bf5));
    __hv_fma_f(VIf(Bf2), VIf(Bf8), VIf(Bf5), VOf(Bf5));
    __hv_line_f(&sLine_UHsZQEzP, VOf(Bf8));
    __hv_tabread_f(&sTabread_Dvq8t9cv, VOf(Bf9));
    __hv_var_k_f(VOf(Bf11), 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f);
    __hv_min_f(VIf(Bf9), VIf(Bf11), VOf(Bf11));
    __hv_var_k_f(VOf(Bf12), -1.0f, -1.0f, -1.0f, -1.0f, -1.0f, -1.0f, -1.0f, -1.0f);
    __hv_max_f(VIf(Bf11), VIf(Bf12), VOf(Bf12));
    __hv_line_f(&sLine_dEN3YcaK, VOf(Bf11));
    __hv_mul_f(VIf(Bf12), VIf(Bf11), VOf(Bf11));
    __hv_fma_f(VIf(Bf1), VIf(Bf8), VIf(Bf11), VOf(Bf11));
    __hv_varread_f(&sVarf_39LPmYJg, VOf(Bf8));
    __hv_add_f(VIf(Bf2), VIf(Bf8), VOf(Bf8));
    __hv_varread_f(&sVarf_01hyF3K3, VOf(Bf2));
    __hv_rpole_f(&sRPole_MvllcLAh, VIf(Bf8), VIf(Bf2), VOf(Bf2));
    __hv_var_k_f(VOf(Bf8), 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f);
    __hv_del1_f(&sDel1_46CzA2P5, VIf(Bf2), VOf(Bf12));
    __hv_mul_f(VIf(Bf12), VIf(Bf8), VOf(Bf8));
    __hv_sub_f(VIf(Bf2), VIf(Bf8), VOf(Bf8));
    __hv_varread_f(&sVarf_4iI4RvEg, VOf(Bf2));
    __hv_mul_f(VIf(Bf8), VIf(Bf2), VOf(Bf2));
    __hv_tabwrite_f(&sTabwrite_os7u61NE, VIf(Bf2));
    __hv_varread_f(&sVarf_sRGoMECO, VOf(Bf2));
    __hv_add_f(VIf(Bf1), VIf(Bf2), VOf(Bf2));
    __hv_varread_f(&sVarf_G6r8JQDK, VOf(Bf1));
    __hv_rpole_f(&sRPole_VTvBRWRu, VIf(Bf2), VIf(Bf1), VOf(Bf1));
    __hv_var_k_f(VOf(Bf2), 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f);
    __hv_del1_f(&sDel1_TQ0W0e97, VIf(Bf1), VOf(Bf8));
    __hv_mul_f(VIf(Bf8), VIf(Bf2), VOf(Bf2));
    __hv_sub_f(VIf(Bf1), VIf(Bf2), VOf(Bf2));
    __hv_varread_f(&sVarf_hmcEjZuy, VOf(Bf1));
    __hv_mul_f(VIf(Bf2), VIf(Bf1), VOf(Bf1));
    __hv_tabwrite_f(&sTabwrite_srYT0sgZ, VIf(Bf1));
    __hv_varread_f(&sVarf_UOaBr7wU, VOf(Bf1));
    __hv_mul_f(VIf(Bf3), VIf(Bf1), VOf(Bf1));
    __hv_line_f(&sLine_00kD6lPp, VOf(Bf3));
    __hv_varread_f(&sVarf_jTrTK7X9, VOf(Bf2));
    __hv_mul_f(VIf(Bf9), VIf(Bf2), VOf(Bf2));
    __hv_line_f(&sLine_FPo8vF8m, VOf(Bf9));
    __hv_mul_f(VIf(Bf2), VIf(Bf9), VOf(Bf9));
    __hv_fma_f(VIf(Bf1), VIf(Bf3), VIf(Bf9), VOf(Bf9));
    __hv_varread_f(&sVarf_sAJwsfF7, VOf(Bf3));
    __hv_varread_f(&sVarf_bIUv0IGp, VOf(Bf8));
    __hv_mul_f(VIf(Bf3), VIf(Bf8), VOf(Bf8));
    __hv_varread_f(&sVarf_p9NAi40S, VOf(Bf3));
    __hv_rpole_f(&sRPole_8xOUH3TC, VIf(Bf8), VIf(Bf3), VOf(Bf3));
    __hv_mul_f(VIf(Bf9), VIf(Bf3), VOf(Bf3));
    sEnv_process(this, &sEnv_gUwuReQU, VIf(Bf9), &sEnv_gUwuReQU_sendMessage);
    __hv_varread_f(&sVarf_6EUbuRpa, VOf(Bf9));
    __hv_mul_f(VIf(Bf3), VIf(Bf9), VOf(Bf9));
    __hv_varread_f(&sVarf_Vwah0IL2, VOf(Bf3));
    __hv_rpole_f(&sRPole_SMfPgQoe, VIf(Bf9), VIf(Bf3), VOf(Bf3));
    __hv_varwrite_f(&sVarf_39LPmYJg, VIf(Bf3));
    __hv_line_f(&sLine_sOPCuOLk, VOf(Bf3));
    __hv_line_f(&sLine_5USDLik8, VOf(Bf9));
    __hv_mul_f(VIf(Bf1), VIf(Bf9), VOf(Bf9));
    __hv_fma_f(VIf(Bf2), VIf(Bf3), VIf(Bf9), VOf(Bf9));
    __hv_varread_f(&sVarf_xMCqYZ1U, VOf(Bf3));
    __hv_varread_f(&sVarf_FzIY2RNJ, VOf(Bf2));
    __hv_mul_f(VIf(Bf3), VIf(Bf2), VOf(Bf2));
    __hv_varread_f(&sVarf_Z4KtHpa4, VOf(Bf3));
    __hv_rpole_f(&sRPole_kLF3ennw, VIf(Bf2), VIf(Bf3), VOf(Bf3));
    __hv_mul_f(VIf(Bf9), VIf(Bf3), VOf(Bf3));
    sEnv_process(this, &sEnv_hzBDacSm, VIf(Bf9), &sEnv_hzBDacSm_sendMessage);
    __hv_varread_f(&sVarf_fgYSlY9V, VOf(Bf9));
    __hv_mul_f(VIf(Bf3), VIf(Bf9), VOf(Bf9));
    __hv_varread_f(&sVarf_bg7wtqrx, VOf(Bf3));
    __hv_rpole_f(&sRPole_Y7mHBm8F, VIf(Bf9), VIf(Bf3), VOf(Bf3));
    __hv_varwrite_f(&sVarf_sRGoMECO, VIf(Bf3));
    __hv_varwrite_f(&sVarf_AOOThPd4, VIf(Bf5));
    __hv_varread_f(&sVarf_61cSWSu8, VOf(Bf5));
    __hv_varread_f(&sVarf_CV3Bov5P, VOf(Bf3));
    __hv_line_f(&sLine_9mRyU1XX, VOf(Bf9));
    __hv_tabread_f(&sTabread_Ki66563G, VOf(Bf2));
    __hv_var_k_f(VOf(Bf1), 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f);
    __hv_min_f(VIf(Bf2), VIf(Bf1), VOf(Bf1));
    __hv_var_k_f(VOf(Bf8), -1.0f, -1.0f, -1.0f, -1.0f, -1.0f, -1.0f, -1.0f, -1.0f);
    __hv_max_f(VIf(Bf1), VIf(Bf8), VOf(Bf8));
    __hv_line_f(&sLine_niE7Roxi, VOf(Bf1));
    __hv_mul_f(VIf(Bf8), VIf(Bf1), VOf(Bf1));
    __hv_fma_f(VIf(Bf5), VIf(Bf9), VIf(Bf1), VOf(Bf1));
    __hv_line_f(&sLine_SVK5Lfak, VOf(Bf9));
    __hv_tabread_f(&sTabread_eB7Wnq0r, VOf(Bf8));
    __hv_var_k_f(VOf(Bf12), 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f);
    __hv_min_f(VIf(Bf8), VIf(Bf12), VOf(Bf12));
    __hv_var_k_f(VOf(Bf13), -1.0f, -1.0f, -1.0f, -1.0f, -1.0f, -1.0f, -1.0f, -1.0f);
    __hv_max_f(VIf(Bf12), VIf(Bf13), VOf(Bf13));
    __hv_line_f(&sLine_x8L4Bppn, VOf(Bf12));
    __hv_mul_f(VIf(Bf13), VIf(Bf12), VOf(Bf12));
    __hv_fma_f(VIf(Bf3), VIf(Bf9), VIf(Bf12), VOf(Bf12));
    __hv_varread_f(&sVarf_JrWHm98Q, VOf(Bf9));
    __hv_add_f(VIf(Bf5), VIf(Bf9), VOf(Bf9));
    __hv_varread_f(&sVarf_Nxn0n1oa, VOf(Bf5));
    __hv_rpole_f(&sRPole_Y91ChJN6, VIf(Bf9), VIf(Bf5), VOf(Bf5));
    __hv_var_k_f(VOf(Bf9), 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f);
    __hv_del1_f(&sDel1_dyouIC2W, VIf(Bf5), VOf(Bf13));
    __hv_mul_f(VIf(Bf13), VIf(Bf9), VOf(Bf9));
    __hv_sub_f(VIf(Bf5), VIf(Bf9), VOf(Bf9));
    __hv_varread_f(&sVarf_bz7rz5MB, VOf(Bf5));
    __hv_mul_f(VIf(Bf9), VIf(Bf5), VOf(Bf5));
    __hv_tabwrite_f(&sTabwrite_y4gtSZuo, VIf(Bf5));
    __hv_varread_f(&sVarf_8CgbArhg, VOf(Bf5));
    __hv_add_f(VIf(Bf3), VIf(Bf5), VOf(Bf5));
    __hv_varread_f(&sVarf_pSVQhfr7, VOf(Bf3));
    __hv_rpole_f(&sRPole_szZkRM8a, VIf(Bf5), VIf(Bf3), VOf(Bf3));
    __hv_var_k_f(VOf(Bf5), 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f);
    __hv_del1_f(&sDel1_xSqjcFj9, VIf(Bf3), VOf(Bf9));
    __hv_mul_f(VIf(Bf9), VIf(Bf5), VOf(Bf5));
    __hv_sub_f(VIf(Bf3), VIf(Bf5), VOf(Bf5));
    __hv_varread_f(&sVarf_XjlIYitk, VOf(Bf3));
    __hv_mul_f(VIf(Bf5), VIf(Bf3), VOf(Bf3));
    __hv_tabwrite_f(&sTabwrite_mx78SL2d, VIf(Bf3));
    __hv_varread_f(&sVarf_cIcOzDUx, VOf(Bf3));
    __hv_mul_f(VIf(Bf2), VIf(Bf3), VOf(Bf3));
    __hv_line_f(&sLine_RyNHE90j, VOf(Bf2));
    __hv_varread_f(&sVarf_HusMana9, VOf(Bf5));
    __hv_mul_f(VIf(Bf8), VIf(Bf5), VOf(Bf5));
    __hv_line_f(&sLine_OoW2tnBA, VOf(Bf8));
    __hv_mul_f(VIf(Bf5), VIf(Bf8), VOf(Bf8));
    __hv_fma_f(VIf(Bf3), VIf(Bf2), VIf(Bf8), VOf(Bf8));
    __hv_varread_f(&sVarf_9js6lp04, VOf(Bf2));
    __hv_varread_f(&sVarf_p5sKIF0t, VOf(Bf9));
    __hv_mul_f(VIf(Bf2), VIf(Bf9), VOf(Bf9));
    __hv_varread_f(&sVarf_cm0Aqeru, VOf(Bf2));
    __hv_rpole_f(&sRPole_cmWcM0yl, VIf(Bf9), VIf(Bf2), VOf(Bf2));
    __hv_mul_f(VIf(Bf8), VIf(Bf2), VOf(Bf2));
    sEnv_process(this, &sEnv_Fc2FwUTu, VIf(Bf8), &sEnv_Fc2FwUTu_sendMessage);
    __hv_varread_f(&sVarf_vnAo5vvj, VOf(Bf8));
    __hv_mul_f(VIf(Bf2), VIf(Bf8), VOf(Bf8));
    __hv_varread_f(&sVarf_sWh8fXlY, VOf(Bf2));
    __hv_rpole_f(&sRPole_ljg6sXjS, VIf(Bf8), VIf(Bf2), VOf(Bf2));
    __hv_varwrite_f(&sVarf_JrWHm98Q, VIf(Bf2));
    __hv_line_f(&sLine_a4uwy9Q6, VOf(Bf2));
    __hv_line_f(&sLine_kaN9YYzc, VOf(Bf8));
    __hv_mul_f(VIf(Bf3), VIf(Bf8), VOf(Bf8));
    __hv_fma_f(VIf(Bf5), VIf(Bf2), VIf(Bf8), VOf(Bf8));
    __hv_varread_f(&sVarf_Oil0y0OV, VOf(Bf2));
    __hv_varread_f(&sVarf_oMwLJBxs, VOf(Bf5));
    __hv_mul_f(VIf(Bf2), VIf(Bf5), VOf(Bf5));
    __hv_varread_f(&sVarf_Jskw2RVu, VOf(Bf2));
    __hv_rpole_f(&sRPole_3YeNkbzb, VIf(Bf5), VIf(Bf2), VOf(Bf2));
    __hv_mul_f(VIf(Bf8), VIf(Bf2), VOf(Bf2));
    sEnv_process(this, &sEnv_dgyvxZWQ, VIf(Bf8), &sEnv_dgyvxZWQ_sendMessage);
    __hv_varread_f(&sVarf_AuPyjV2m, VOf(Bf8));
    __hv_mul_f(VIf(Bf2), VIf(Bf8), VOf(Bf8));
    __hv_varread_f(&sVarf_rSNdaVjm, VOf(Bf2));
    __hv_rpole_f(&sRPole_eRdSJTgG, VIf(Bf8), VIf(Bf2), VOf(Bf2));
    __hv_varwrite_f(&sVarf_8CgbArhg, VIf(Bf2));
    __hv_varwrite_f(&sVarf_CygDMB68, VIf(Bf1));
    __hv_varwrite_f(&sVarf_lIBMxhwc, VIf(Bf10));
    __hv_varwrite_f(&sVarf_8zNzq4nt, VIf(Bf11));
    __hv_varwrite_f(&sVarf_6NKVfdrQ, VIf(Bf12));
    __hv_varwrite_f(&sVarf_UmstNUUV, VIf(Bf0));
    __hv_varwrite_f(&sVarf_HPbTXpUq, VIf(Bf6));
    __hv_varwrite_f(&sVarf_61cSWSu8, VIf(Bf4));
    __hv_varwrite_f(&sVarf_CV3Bov5P, VIf(Bf7));
    __hv_varread_f(&sVarf_E3UXRSkI, VOf(Bf7));
    __hv_varread_f(&sVarf_AOOThPd4, VOf(Bf4));
    __hv_varread_f(&sVarf_CygDMB68, VOf(Bf6));
    __hv_add_f(VIf(Bf4), VIf(Bf6), VOf(Bf6));
    __hv_add_f(VIf(Bf7), VIf(Bf6), VOf(Bf6));
    __hv_add_f(VIf(Bf6), VIf(O0), VOf(O0));
    __hv_varread_f(&sVarf_lIBMxhwc, VOf(Bf6));
    __hv_varread_f(&sVarf_8zNzq4nt, VOf(Bf7));
    __hv_varread_f(&sVarf_6NKVfdrQ, VOf(Bf4));
    __hv_add_f(VIf(Bf7), VIf(Bf4), VOf(Bf4));
    __hv_add_f(VIf(Bf6), VIf(Bf4), VOf(Bf4));
    __hv_add_f(VIf(Bf4), VIf(O1), VOf(O1));

    // save output vars to output buffer
    __hv_store_f(outputBuffers[0]+n, VIf(O0));
    __hv_store_f(outputBuffers[1]+n, VIf(O1));
  }

  blockStartTimestamp = nextBlock;

  return n4; // return the number of frames processed

}

int Heavy_WSTD_DL3Y::processInline(float *inputBuffers, float *outputBuffers, int n4) {
  hv_assert(!(n4 & HV_N_SIMD_MASK)); // ensure that n4 is a multiple of HV_N_SIMD

  // define the heavy input buffer for 2 channel(s)
  float **const bIn = reinterpret_cast<float **>(hv_alloca(2*sizeof(float *)));
  bIn[0] = inputBuffers+(0*n4);
  bIn[1] = inputBuffers+(1*n4);

  // define the heavy output buffer for 2 channel(s)
  float **const bOut = reinterpret_cast<float **>(hv_alloca(2*sizeof(float *)));
  bOut[0] = outputBuffers+(0*n4);
  bOut[1] = outputBuffers+(1*n4);

  int n = process(bIn, bOut, n4);
  return n;
}

int Heavy_WSTD_DL3Y::processInlineInterleaved(float *inputBuffers, float *outputBuffers, int n4) {
  hv_assert(n4 & ~HV_N_SIMD_MASK); // ensure that n4 is a multiple of HV_N_SIMD

  // define the heavy input buffer for 2 channel(s), uninterleave
  float *const bIn = reinterpret_cast<float *>(hv_alloca(2*n4*sizeof(float)));
  #if HV_SIMD_SSE || HV_SIMD_AVX
  for (int i = 0, j = 0; j < n4; j += 4, i += 8) {
    __m128 a = _mm_load_ps(inputBuffers+i);                // LRLR
    __m128 b = _mm_load_ps(inputBuffers+4+i);              // LRLR
    __m128 x = _mm_shuffle_ps(a, b, _MM_SHUFFLE(2,0,2,0)); // LLLL
    __m128 y = _mm_shuffle_ps(a, b, _MM_SHUFFLE(3,1,3,1)); // RRRR
    _mm_store_ps(bIn+j, x);
    _mm_store_ps(bIn+n4+j, y);
  }
  #elif HV_SIMD_NEON
  for (int i = 0, j = 0; j < n4; j += 4, i += 8) {
    float32x4x2_t a = vld2q_f32(inputBuffers+i); // load and uninterleave
    vst1q_f32(bIn+j, a.val[0]);
    vst1q_f32(bIn+n4+j, a.val[1]);
  }
  #else // HV_SIMD_NONE
  for (int j = 0; j < n4; ++j) {
    bIn[0*n4+j] = inputBuffers[0+2*j];
    bIn[1*n4+j] = inputBuffers[1+2*j];
  }
  #endif

  // define the heavy output buffer for 2 channel(s)
  float *const bOut = reinterpret_cast<float *>(hv_alloca(2*n4*sizeof(float)));

  int n = processInline(bIn, bOut, n4);

  // interleave the heavy output into the output buffer
  #if HV_SIMD_AVX
  for (int i = 0, j = 0; j < n4; j += 8, i += 16) {
    __m256 x = _mm256_load_ps(bOut+j);    // LLLLLLLL
    __m256 y = _mm256_load_ps(bOut+n4+j); // RRRRRRRR
    __m256 a = _mm256_unpacklo_ps(x, y);  // LRLRLRLR
    __m256 b = _mm256_unpackhi_ps(x, y);  // LRLRLRLR
    _mm256_store_ps(outputBuffers+i, a);
    _mm256_store_ps(outputBuffers+8+i, b);
  }
  #elif HV_SIMD_SSE
  for (int i = 0, j = 0; j < n4; j += 4, i += 8) {
    __m128 x = _mm_load_ps(bOut+j);    // LLLL
    __m128 y = _mm_load_ps(bOut+n4+j); // RRRR
    __m128 a = _mm_unpacklo_ps(x, y);  // LRLR
    __m128 b = _mm_unpackhi_ps(x, y);  // LRLR
    _mm_store_ps(outputBuffers+i, a);
    _mm_store_ps(outputBuffers+4+i, b);
  }
  #elif HV_SIMD_NEON
  // https://community.arm.com/groups/processors/blog/2012/03/13/coding-for-neon--part-5-rearranging-vectors
  for (int i = 0, j = 0; j < n4; j += 4, i += 8) {
    float32x4_t x = vld1q_f32(bOut+j);
    float32x4_t y = vld1q_f32(bOut+n4+j);
    float32x4x2_t z = {x, y};
    vst2q_f32(outputBuffers+i, z); // interleave and store
  }
  #else // HV_SIMD_NONE
  for (int i = 0; i < 2; ++i) {
    for (int j = 0; j < n4; ++j) {
      outputBuffers[i+2*j] = bOut[i*n4+j];
    }
  }
  #endif

  return n;
}
